<?php
// actions/debt/get_payments.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header('Content-Type: application/json');

if (!isset($_GET['debts_id']) || !is_numeric($_GET['debts_id'])) {
    echo json_encode(['success' => false, 'message' => 'Invalid debts ID.']);
    exit;
}

$debts_id = (int) $_GET['debts_id'];

$stmt = $conn->prepare("
    SELECT dp.id as payment_id, dp.pay_amount, dp.pay_date, dp.payment_type, dp.remarks,
           GROUP_CONCAT(CONCAT(dpr.id, '::', dpr.file_path) SEPARATOR '||') as receipts
    FROM debt_payments dp
    LEFT JOIN debt_payment_receipts dpr ON dp.id = dpr.debt_payment_id
    WHERE dp.debts_id = ?
    GROUP BY dp.id
    ORDER BY dp.pay_date ASC
");
$stmt->bind_param("i", $debts_id);
$stmt->execute();
$result = $stmt->get_result();

$payments = [];
while ($row = $result->fetch_assoc()) {
    $receipts = [];
    if (!empty($row['receipts'])) {
        $receiptParts = explode("||", $row['receipts']);
        foreach ($receiptParts as $part) {
            $subParts = explode("::", $part, 2);
            if (count($subParts) == 2) {
                $receipts[] = [
                    'id' => (int)$subParts[0],
                    'file_path' => $subParts[1]
                ];
            }
        }
    }
    $payments[] = [
        'payment_id'   => (int)$row['payment_id'],
        'pay_amount'   => (float)$row['pay_amount'],
        'pay_date'     => $row['pay_date'],
        'payment_type' => $row['payment_type'],
        'remarks'      => $row['remarks'],
        'debts_id'     => $debts_id,
        'receipts'     => $receipts
    ];
}

$stmt->close();
$conn->close();

echo json_encode(['success' => true, 'payments' => $payments]);
