<?php
// actions/fetch_appointments.php

include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Return JSON
header('Content-Type: application/json');

// Basic query: fetch appointment plus patient's name
$query = "
    SELECT
      a.AppointmentID,
      a.PatientID,
      a.AppointmentDate,
      a.AppointmentTime,
      p.first_name,
      p.last_name
    FROM appointments a
    JOIN patients p ON a.PatientID = p.id
    WHERE a.Status <> 'Cancelled'
    ORDER BY a.AppointmentDate, a.AppointmentTime
";

$result = $conn->query($query);

$events = [];

while ($row = $result->fetch_assoc()) {
    $id            = $row['AppointmentID'];
    $patientID     = $row['PatientID'];
    $date          = $row['AppointmentDate']; // e.g. "2025-01-15"
    $time          = $row['AppointmentTime']; // e.g. "10:00:00"
    $patientFName  = trim($row['first_name']);
    $patientLName  = trim($row['last_name']);
    $fullName      = $patientFName . ' ' . $patientLName;

    // Build start datetime string: "2025-01-15T10:00:00"
    $startDateTime = $date . 'T' . $time;

    // Optionally, define an end time for 30 minutes later
    $endDateTime = (new DateTime($startDateTime))
        ->modify('+30 minutes')
        ->format('Y-m-d\TH:i:s');

    // The main calendar event text
    $title = $fullName . ' (' . $time . ')';

    $events[] = [
        'id'    => $id,
        'title' => $title,
        'start' => $startDateTime,
        'end'   => $endDateTime,
        'allDay' => false, // ensures it shows up in timeGrid

        // Data for the modal:
        'extendedProps' => [
            'patientFullName'  => $fullName,
            'patientID'        => $patientID,
            'appointmentTime'  => $time,
        ],
    ];
}

echo json_encode($events);
