<?php

/**
 * add_followup_appointment.php
 * 
 * Called by the "Add Follow-Up" modal form in appointments_section.php:
 *   <form action="actions/followups/add_followup_appointment.php" method="POST">
 *
 * Expects:
 *   $_POST['followup_action'] === 'addFollowUp'
 *   $_POST['patient_id']
 *   $_POST['appointment_id']
 *   $_POST['followup_datetime']  => "YYYY-MM-DDTHH:MM"
 *   $_POST['status_update']
 *   $_POST['followup_type']
 *   $_POST['next_followup_date'] => optional
 *   $_POST['remarks']            => optional
 *
 * Then inserts a new row into `follow_up`.
 */

date_default_timezone_set('Asia/Kuala_Lumpur');

// Load config/db & session checks
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Must have a valid user session
$currentUserID = $_SESSION['user_id'] ?? 0;
if ($currentUserID < 1) {
    // Could redirect with an error message
    $_SESSION['error'] = "No valid user session. Please log in.";
    header("Location: ../../pages/patient/patientList.php");
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && ($_POST['followup_action'] ?? '') === 'addFollowUp') {
    $pID    = (int)($_POST['patient_id'] ?? 0);
    $apptID = (int)($_POST['appointment_id'] ?? 0);
    $fuDT   = $_POST['followup_datetime'] ?? '';
    $statusUpdate = $_POST['status_update'] ?? '';
    $fType  = $_POST['followup_type'] ?? 'Call';
    $nextDate = $_POST['next_followup_date'] ?? null;
    $remarks = $_POST['remarks'] ?? '';

    // Parse "YYYY-MM-DDTHH:MM" => "YYYY-MM-DD HH:MM:00"
    $fuDateStr = date('Y-m-d H:i:s');
    if (strpos($fuDT, 'T') !== false) {
        [$d, $t] = explode('T', $fuDT);
        $fuDateStr = $d . ' ' . $t . ':00';
    }

    // Insert
    $sql = "
      INSERT INTO follow_up (
        PatientID,
        AppointmentID,
        FollowUpDate,
        StatusUpdate,
        FollowUpType,
        NextFollowUpDate,
        Remarks,
        FollowUpStatus,
        CreatedBy,
        UpdatedBy,
        CreatedAt,
        UpdatedAt
      ) VALUES (?, ?, ?, ?, ?, ?, ?, 'Pending', ?, ?, NOW(), NOW())
    ";
    $st = $conn->prepare($sql);
    $st->bind_param(
        "iisssssii",
        $pID,
        $apptID,
        $fuDateStr,
        $statusUpdate,
        $fType,
        $nextDate,
        $remarks,
        $currentUserID,
        $currentUserID
    );
    $st->execute();
    $st->close();

    $_SESSION['success'] = "Follow-Up added for Appointment #{$apptID}.";
    // Redirect back to the patient's Appointments tab
    header("Location: ../../pages/patient/patientProfile.php?id=$pID&appointments-tab=1");
    exit;
} else {
    // If accessed incorrectly, just redirect
    header("Location: ../../pages/patient/patientList.php");
    exit;
}
