<?php
// toggle_followup_status.php
require_once '../../common/config.php';
session_start();

if ($_SERVER['REQUEST_METHOD'] !== 'POST') {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Invalid request method.']);
    exit;
}

$followup_id = isset($_POST['followup_id']) ? (int)$_POST['followup_id'] : 0;
$patient_id  = isset($_POST['patient_id']) ? (int)$_POST['patient_id'] : 0;
$currentUserID = $_SESSION['user_id'] ?? 0;

if ($followup_id <= 0 || $patient_id <= 0 || $currentUserID <= 0) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Invalid parameters.']);
    exit;
}

// Retrieve the follow-up record (including its scheduled date)
$sqlCheck = "SELECT FollowUpStatus, FollowUpDate FROM follow_up WHERE FollowUpID = ? AND PatientID = ? LIMIT 1";
$stmt = $conn->prepare($sqlCheck);
$stmt->bind_param("ii", $followup_id, $patient_id);
$stmt->execute();
$result = $stmt->get_result();
if ($result->num_rows < 1) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Follow-Up not found.']);
    exit;
}
$row = $result->fetch_assoc();
$currentStatus = $row['FollowUpStatus'];
$followUpDate  = $row['FollowUpDate'];
$stmt->close();

// If trying to mark as Done and current time is before the scheduled time, block it.
$currentTime = date("Y-m-d H:i:s");
if ($currentStatus === 'Pending' && strtotime($currentTime) < strtotime($followUpDate)) {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Cannot mark as done before the scheduled follow-up time.']);
    exit;
}

$newStatus = ($currentStatus === 'Pending') ? 'Done' : 'Pending';
$sqlUpdate = "UPDATE follow_up SET FollowUpStatus = ?, UpdatedBy = ?, UpdatedAt = NOW() WHERE FollowUpID = ? AND PatientID = ?";
$stmt2 = $conn->prepare($sqlUpdate);
$stmt2->bind_param("siii", $newStatus, $currentUserID, $followup_id, $patient_id);
if ($stmt2->execute()) {
    header('Content-Type: application/json');
    echo json_encode(['success' => true, 'new_status' => $newStatus]);
} else {
    header('Content-Type: application/json');
    echo json_encode(['success' => false, 'message' => 'Update failed.']);
}
$stmt2->close();
exit;
