<?php
// actions/get_diagnosis_followups.php
include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

$page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
$limit = 5;
$offset = ($page - 1) * $limit;

// 1) Count
$sqlCount = "
  SELECT COUNT(*) AS total
  FROM diagnoses d
  JOIN patients p ON d.PatientID=p.id
  WHERE d.FollowUpDate >= CURDATE()
";
$resCount = $conn->query($sqlCount);
$total = 0;
if ($resCount && $cRow = $resCount->fetch_assoc()) {
    $total = (int)$cRow['total'];
}
$totalPages = max(1, ceil($total / $limit));

// 2) Rows
$sqlData = "
  SELECT d.*, p.first_name, p.last_name
  FROM diagnoses d
  JOIN patients p ON d.PatientID = p.id
  WHERE d.FollowUpDate >= CURDATE()
  ORDER BY d.FollowUpDate ASC
  LIMIT $limit OFFSET $offset
";
$resData = $conn->query($sqlData);
$rows = [];
if ($resData && $resData->num_rows > 0) {
    while ($dg = $resData->fetch_assoc()) {
        $rows[] = $dg;
    }
}

// 3) Build Table
if (!empty($rows)) {
    echo '<div class="table-responsive mb-2">';
    echo '<table class="table table-striped align-middle">';
    echo '<thead>
          <tr>
            <th>Patient</th>
            <th>Follow-Up Date</th>
            <th>Diagnosis</th>
            <th>Link</th>
          </tr>
        </thead>';
    echo '<tbody>';

    foreach ($rows as $dg) {
        $patientName = htmlspecialchars($dg['first_name'] . ' ' . $dg['last_name']);
        $dateStr = date('d M Y', strtotime($dg['FollowUpDate']));
        // Clean up diagnosis
        $rawDiag = $dg['Diagnosis'] ?? '';
        $rawDiag = str_replace(["\r", "\t"], '', $rawDiag);
        $lines = explode("\n", $rawDiag);
        foreach ($lines as &$ln) {
            $ln = preg_replace('/\s+/', ' ', trim($ln));
        }
        unset($ln);
        $cleanDiag = trim(implode(" ", $lines));
        // snippet
        $snippet = mb_strimwidth($cleanDiag, 0, 60, '...');

        echo '<tr>
            <td>' . $patientName . '</td>
            <td>' . $dateStr . '</td>
            <td>' . htmlspecialchars($snippet) . '</td>
            <td>
              <a href="' . $baseURL . 'pages/patient/patientProfile.php?id=' . (int)$dg['PatientID']
            . '&diagnosis-tab=1&diag_id=' . (int)$dg['DiagnosisID'] . '"
                 class="btn btn-sm btn-primary" target="_blank">
                View
              </a>
            </td>
          </tr>';
    }

    echo '</tbody></table>';
    echo '</div>';

    // 4) Pagination
    if ($totalPages > 1) {
        echo '<nav><ul class="pagination justify-content-center flex-wrap">';
        // Prev
        if ($page > 1) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchDiagnosisFollowups(' . ($page - 1) . ')">
                &laquo; Prev
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>';
        }
        // Pages
        for ($p = 1; $p <= $totalPages; $p++) {
            $active = ($p == $page) ? ' active' : '';
            echo '<li class="page-item' . $active . '">
              <button class="page-link"
                      onclick="fetchDiagnosisFollowups(' . $p . ')">
                ' . $p . '
              </button>
            </li>';
        }
        // Next
        if ($page < $totalPages) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchDiagnosisFollowups(' . ($page + 1) . ')">
                Next &raquo;
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>';
        }

        echo '</ul></nav>';
    }
} else {
    echo '<p class="text-muted">No diagnosis-based follow-ups found.</p>';
}
