<?php
// actions/get_overdue_items.php
include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

$page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
$limit = 5;

// 1) Collect ALL overdue items in memory
$items = [];

// Overdue Appointments
$sqlA = "
  SELECT 
    a.AppointmentID as itemID,
    a.PatientID,
    p.first_name,
    p.last_name,
    a.AppointmentDate as dueDate,
    'Appointment' as source
  FROM appointments a
  JOIN patients p ON a.PatientID=p.id
  WHERE a.AppointmentDate < CURDATE()
    AND a.Status<>'Completed'
";
$resA = $conn->query($sqlA);
if ($resA && $resA->num_rows > 0) {
    while ($row = $resA->fetch_assoc()) {
        $items[] = $row;
    }
}

// Overdue Follow-Ups
$sqlF = "
  SELECT
    f.FollowUpID as itemID,
    f.PatientID,
    p.first_name,
    p.last_name,
    f.FollowUpDate as dueDate,
    'Follow-Up' as source
  FROM follow_up f
  JOIN patients p ON f.PatientID=p.id
  WHERE f.FollowUpDate<CURDATE()
    AND f.FollowUpStatus<>'Done'
";
$resF = $conn->query($sqlF);
if ($resF && $resF->num_rows > 0) {
    while ($row = $resF->fetch_assoc()) {
        $items[] = $row;
    }
}

// Overdue Diagnoses
$sqlD = "
  SELECT
    d.DiagnosisID as itemID,
    d.PatientID,
    p.first_name,
    p.last_name,
    d.FollowUpDate as dueDate,
    'Diagnosis' as source
  FROM diagnoses d
  JOIN patients p ON d.PatientID=p.id
  WHERE d.FollowUpDate < CURDATE()
";
$resD = $conn->query($sqlD);
if ($resD && $resD->num_rows > 0) {
    while ($row = $resD->fetch_assoc()) {
        $items[] = $row;
    }
}

// 2) Sort items by dueDate ascending
usort($items, function ($a, $b) {
    return strtotime($a['dueDate']) <=> strtotime($b['dueDate']);
});

// 3) total items
$total = count($items);
$totalPages = max(1, ceil($total / $limit));

// 4) slice for this page
$offset = ($page - 1) * $limit;
$pagedItems = array_slice($items, $offset, $limit);

// 5) build table
if (!empty($pagedItems)) {
    echo '<div class="table-responsive mb-2">';
    echo '<table class="table table-striped align-middle">';
    echo '<thead>
          <tr>
            <th>Patient</th>
            <th>Due Date</th>
            <th>Source</th>
            <th>Link</th>
          </tr>
        </thead>';
    echo '<tbody>';

    foreach ($pagedItems as $od) {
        $patientName = htmlspecialchars($od['first_name'] . ' ' . $od['last_name']);
        $dueStr = $od['dueDate'] ? date('d M Y', strtotime($od['dueDate'])) : '-';
        $src = $od['source'];
        $pID = (int)$od['PatientID'];
        $itemID = (int)$od['itemID'];

        // Build link
        if ($src === 'Appointment') {
            $link = $baseURL . 'pages/patient/patientProfile.php?id=' . $pID . '&appointments-tab=1&appt_id=' . $itemID;
        } elseif ($src === 'Follow-Up') {
            $link = $baseURL . 'pages/patient/patientProfile.php?id=' . $pID . '&followups-tab=1';
        } else {
            // Diagnosis
            $link = $baseURL . 'pages/patient/patientProfile.php?id=' . $pID . '&diagnoses-tab=1&diag_id=' . $itemID;
        }
        echo '<tr>
            <td>' . $patientName . '</td>
            <td>' . $dueStr . '</td>
            <td>' . htmlspecialchars($src) . '</td>
            <td><a href="' . $link . '" class="btn btn-sm btn-primary" target="_blank">Open</a></td>
          </tr>';
    }

    echo '</tbody></table>';
    echo '</div>';

    // 6) pagination
    if ($totalPages > 1) {
        echo '<nav><ul class="pagination justify-content-center flex-wrap">';
        // Prev
        if ($page > 1) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchOverdueItems(' . ($page - 1) . ')">
                &laquo; Prev
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>';
        }
        // page numbers
        for ($p = 1; $p <= $totalPages; $p++) {
            $active = ($p == $page) ? 'active' : '';
            echo '<li class="page-item ' . $active . '">
              <button class="page-link"
                      onclick="fetchOverdueItems(' . $p . ')">
                ' . $p . '
              </button>
            </li>';
        }
        // next
        if ($page < $totalPages) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchOverdueItems(' . ($page + 1) . ')">
                Next &raquo;
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>';
        }
        echo '</ul></nav>';
    }
} else {
    echo '<p class="text-muted">No overdue items found.</p>';
}
