<?php
// actions/get_pending_debts.php
include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// We expect an integer "page" parameter
$page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
$limit = 5;
$offset = ($page - 1) * $limit;

// 1) Count total pending debts
$sqlCount = "
    SELECT COUNT(*) AS total_pending
    FROM debts
    WHERE balance_after_payment > 0
";
$resCount = $conn->query($sqlCount);
$totalPending = 0;
if ($resCount && $countRow = $resCount->fetch_assoc()) {
    $totalPending = (int)$countRow['total_pending'];
}
$totalPages = max(1, ceil($totalPending / $limit));

// 2) Query actual rows, join for patient name
$sqlPend = "
    SELECT 
      d.balance_after_payment,
      d.date_of_debt,
      d.msr_id,
      p.first_name,
      p.last_name,
      m.msr_number
    FROM debts d
    JOIN msr m ON d.msr_id = m.id
    JOIN patients p ON d.patient_id = p.id
    WHERE d.balance_after_payment > 0
    ORDER BY d.date_of_debt DESC
    LIMIT $limit OFFSET $offset
";
$resPend = $conn->query($sqlPend);

$rows = [];
if ($resPend && $resPend->num_rows > 0) {
    while ($pd = $resPend->fetch_assoc()) {
        $rows[] = $pd;
    }
}

// Output the table + pagination
?>
<?php if (!empty($rows)): ?>
    <div class="table-responsive mb-3">
        <table class="table table-striped align-middle">
            <thead>
                <tr>
                    <th>Patient Name</th>
                    <th>Date of Debt</th>
                    <th>MSR</th>
                    <th>Debt (RM)</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($rows as $pd): ?>
                    <tr>
                        <td>
                            <?php echo htmlspecialchars($pd['first_name'] . ' ' . $pd['last_name']); ?>
                        </td>
                        <td>
                            <?php echo date('d M Y', strtotime($pd['date_of_debt'])); ?>
                        </td>
                        <td>
                            <a href="<?php echo $baseURL; ?>pages/msr/viewMsr.php?id=<?php echo urlencode($pd['msr_id']); ?>"
                                target="_blank" class="text-decoration-underline">
                                <?php echo htmlspecialchars($pd['msr_number']); ?>
                            </a>
                        </td>
                        <td>
                            <?php echo number_format($pd['balance_after_payment'], 2); ?>
                        </td>
                    </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <!-- AJAX-based pagination links -->
    <?php if ($totalPages > 1): ?>
        <nav aria-label="Pending Debts Pages">
            <ul class="pagination justify-content-center flex-wrap">
                <?php
                // "Start" link
                if ($page > 1) {
                    echo '<li class="page-item">
                            <button class="page-link" onclick="fetchPendingDebts(1)">
                                Start
                            </button>
                          </li>';
                } else {
                    echo '<li class="page-item disabled">
                            <button class="page-link">Start</button>
                          </li>';
                }

                // "Previous" link
                $prevPage = ($page > 1) ? $page - 1 : 1;
                if ($page > 1) {
                    echo '<li class="page-item">
                            <button class="page-link" onclick="fetchPendingDebts(' . $prevPage . ')">
                                &laquo;
                            </button>
                          </li>';
                } else {
                    echo '<li class="page-item disabled">
                            <button class="page-link">&laquo;</button>
                          </li>';
                }

                // Range of pages around current page
                $range = 2; // how many pages to show on either side
                $start = max(1, $page - $range);
                $end   = min($totalPages, $page + $range);

                // If you want an ellipsis before the page group if $start > 1
                // you could do something like:
                // if ($start > 1) { show a "..." or show page=1 etc. }

                for ($p = $start; $p <= $end; $p++) {
                    if ($p == $page) {
                        // Current page
                        echo '<li class="page-item active">
                                <button class="page-link">' . $p . '</button>
                              </li>';
                    } else {
                        echo '<li class="page-item">
                                <button class="page-link" onclick="fetchPendingDebts(' . $p . ')">
                                    ' . $p . '
                                </button>
                              </li>';
                    }
                }

                // Similarly, if $end < $totalPages
                // you could show an ellipsis, link to $totalPages, etc.

                // "Next" link
                $nextPage = ($page < $totalPages) ? $page + 1 : $totalPages;
                if ($page < $totalPages) {
                    echo '<li class="page-item">
                            <button class="page-link" onclick="fetchPendingDebts(' . $nextPage . ')">
                                &raquo;
                            </button>
                          </li>';
                } else {
                    echo '<li class="page-item disabled">
                            <button class="page-link">&raquo;</button>
                          </li>';
                }

                // "End" link
                if ($page < $totalPages) {
                    echo '<li class="page-item">
                            <button class="page-link" onclick="fetchPendingDebts(' . $totalPages . ')">
                                End
                            </button>
                          </li>';
                } else {
                    echo '<li class="page-item disabled">
                            <button class="page-link">End</button>
                          </li>';
                }
                ?>
            </ul>
        </nav>
    <?php endif; ?>
<?php else: ?>
    <p class="text-muted">No pending debts found.</p>
<?php endif; ?>