<?php
// actions/get_upcoming_appointments.php
include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

$page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
$limit = 5;
$offset = ($page - 1) * $limit;

// 1) Count total upcoming
$sqlCount = "
  SELECT COUNT(*) AS total
  FROM appointments a
  JOIN patients p ON a.PatientID=p.id
  WHERE a.Status NOT IN('Completed','Cancelled')
    AND STR_TO_DATE(CONCAT(a.AppointmentDate, ' ', a.AppointmentTime), '%Y-%m-%d %H:%i:%s') >= NOW()
";
$resCount = $conn->query($sqlCount);
$total = 0;
if ($resCount && $rc = $resCount->fetch_assoc()) {
    $total = (int)$rc['total'];
}
$totalPages = max(1, ceil($total / $limit));

// 2) Query actual rows
$sqlData = "
  SELECT a.*, p.first_name, p.last_name
  FROM appointments a
  JOIN patients p ON a.PatientID=p.id
  WHERE a.Status NOT IN('Completed','Cancelled')
    AND STR_TO_DATE(CONCAT(a.AppointmentDate, ' ', a.AppointmentTime), '%Y-%m-%d %H:%i:%s')>=NOW()
  ORDER BY a.AppointmentDate ASC, a.AppointmentTime ASC
  LIMIT $limit OFFSET $offset
";
$resData = $conn->query($sqlData);
$rows = [];
if ($resData && $resData->num_rows > 0) {
    while ($ap = $resData->fetch_assoc()) {
        $rows[] = $ap;
    }
}

// 3) Build table
if (!empty($rows)) {
    echo '<div class="table-responsive mb-2">';
    echo '<table class="table table-striped align-middle">';
    echo '<thead>
          <tr>
            <th>Patient</th>
            <th>Date</th>
            <th>Time</th>
            <th>Purpose</th>
            <th>Link</th>
          </tr>
        </thead>';
    echo '<tbody>';

    foreach ($rows as $ap) {
        $patientName = htmlspecialchars($ap['first_name'] . ' ' . $ap['last_name']);
        $dateStr = date('d M Y', strtotime($ap['AppointmentDate']));
        $timeStr = substr($ap['AppointmentTime'] ?? '00:00:00', 0, 5);

        // (Optional) collapse spaces in Purpose:
        $rawPurpose = $ap['Purpose'] ?? '';
        $rawPurpose = str_replace(["\r", "\t"], '', $rawPurpose);
        $lines = explode("\n", $rawPurpose);
        foreach ($lines as &$ln) {
            $ln = preg_replace('/\s+/', ' ', trim($ln));
        }
        unset($ln);
        $finalPurpose = trim(implode(' ', $lines));

        echo '<tr>
            <td>' . $patientName . '</td>
            <td>' . $dateStr . '</td>
            <td>' . $timeStr . '</td>
            <td>' . htmlspecialchars($finalPurpose) . '</td>
            <td>
              <a href="' . $baseURL . 'pages/patient/patientProfile.php?id=' . (int)$ap['PatientID']
            . '&appointments-tab=1&appt_id=' . (int)$ap['AppointmentID'] . '"
                 class="btn btn-sm btn-primary"
                 target="_blank">
                View
              </a>
            </td>
          </tr>';
    }

    echo '</tbody></table>';
    echo '</div>';

    // 4) Pagination
    if ($totalPages > 1) {
        echo '<nav><ul class="pagination justify-content-center flex-wrap">';
        // Prev
        if ($page > 1) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchUpcomingAppointments(' . ($page - 1) . ')">
                &laquo; Prev
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>';
        }
        // Page numbers
        for ($p = 1; $p <= $totalPages; $p++) {
            $active = ($p == $page) ? 'active' : '';
            echo '<li class="page-item ' . $active . '">
              <button class="page-link"
                      onclick="fetchUpcomingAppointments(' . $p . ')">
                ' . $p . '
              </button>
            </li>';
        }
        // Next
        if ($page < $totalPages) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchUpcomingAppointments(' . ($page + 1) . ')">
                Next &raquo;
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>';
        }
        echo '</ul></nav>';
    }
} else {
    echo '<p class="text-muted">No upcoming appointments found.</p>';
}
