<?php
// actions/get_upcoming_followups.php
include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// We do pagination
$page = isset($_GET['page']) ? max(1, (int)$_GET['page']) : 1;
$limit = 5;
$offset = ($page - 1) * $limit;

// 1) Count
$sqlCount = "
  SELECT COUNT(*) as total
  FROM follow_up f
  JOIN followup_categories c ON f.followup_category_id=c.id
  WHERE f.FollowUpDate>=NOW()
    AND f.FollowUpStatus<>'Done'
";
$resCount = $conn->query($sqlCount);
$total = 0;
if ($resCount && $rc = $resCount->fetch_assoc()) {
    $total = (int)$rc['total'];
}
$totalPages = max(1, ceil($total / $limit));

// 2) Query actual rows
$sqlRows = "
  SELECT f.*, c.name AS category_name,
         p.first_name, p.last_name
  FROM follow_up f
  JOIN followup_categories c ON f.followup_category_id=c.id
  JOIN patients p ON f.PatientID=p.id
  WHERE f.FollowUpDate>=NOW()
    AND f.FollowUpStatus<>'Done'
  ORDER BY f.FollowUpDate ASC
  LIMIT $limit OFFSET $offset
";
$resRows = $conn->query($sqlRows);
$rows = [];
if ($resRows && $resRows->num_rows > 0) {
    while ($r = $resRows->fetch_assoc()) {
        $rows[] = $r;
    }
}

// 3) Build Table
if (!empty($rows)) {
    echo '<div class="table-responsive mb-2">';
    echo '<table class="table table-striped align-middle">';
    echo '<thead>
          <tr>
            <th>Patient</th>
            <th>Follow-Up Date</th>
            <th>Category</th>
            <th>Status Update</th>
            <th>Link</th>
          </tr>
        </thead>';
    echo '<tbody>';

    foreach ($rows as $fu) {
        $patientName = htmlspecialchars($fu['first_name'] . ' ' . $fu['last_name']);
        $fDate      = $fu['FollowUpDate'] ?? null;
        $catName    = htmlspecialchars($fu['category_name'] ?? '');
        // Collapse spaces in StatusUpdate
        $rawStatus = $fu['StatusUpdate'] ?? '';
        $rawStatus = str_replace(["\r", "\t"], '', $rawStatus);
        $lines = explode("\n", $rawStatus);
        foreach ($lines as &$ln) {
            $ln = preg_replace('/\s+/', ' ', trim($ln));
        }
        unset($ln);
        $statusText = trim(implode("\n", $lines));

        echo '<tr>';
        echo '<td>' . $patientName . '</td>';
        echo '<td>' . ($fDate ? date('d M Y H:i', strtotime($fDate)) : '-') . '</td>';
        echo '<td>' . $catName . '</td>';
        echo '<td style="white-space: pre-wrap;">'
            . nl2br(htmlspecialchars($statusText)) . '</td>';
        echo '<td>
            <a href="' . $baseURL . 'pages/patient/patientProfile.php?id=' . (int)$fu['PatientID']
            . '&followups-tab=1"
               class="btn btn-sm btn-primary"
               target="_blank">
               Open
            </a>
          </td>';
        echo '</tr>';
    }

    echo '</tbody></table>';
    echo '</div>';

    // 4) Pagination
    if ($totalPages > 1) {
        echo '<nav><ul class="pagination justify-content-center flex-wrap">';
        // Prev
        if ($page > 1) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchUpcomingFollowups(' . ($page - 1) . ')">
                &laquo; Prev
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>';
        }
        // Pages
        for ($p = 1; $p <= $totalPages; $p++) {
            $active = ($p == $page) ? 'active' : '';
            echo '<li class="page-item ' . $active . '">
              <button class="page-link"
                      onclick="fetchUpcomingFollowups(' . $p . ')">
                ' . $p . '
              </button>
            </li>';
        }
        // Next
        if ($page < $totalPages) {
            echo '<li class="page-item">
              <button class="page-link"
                      onclick="fetchUpcomingFollowups(' . ($page + 1) . ')">
                Next &raquo;
              </button>
            </li>';
        } else {
            echo '<li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>';
        }
        echo '</ul></nav>';
    }
} else {
    echo '<p class="text-muted">No upcoming follow-ups found.</p>';
}
