<?php
// actions/msr/check_msr.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// (The timezone is now set in config.php.)

header('Content-Type: application/json');

// Ensure a valid session.
if (!isset($_SESSION['user_id'])) {
  echo json_encode(['exists' => false]);
  exit;
}
$user_id  = (int)$_SESSION['user_id'];
$userRole = $_SESSION['role'] ?? 'staff';

if ($userRole === 'staff') {
  // Staff: check if an MSR exists for today for that staff member.
  $sql = "
        SELECT m.id AS msr_id,
               m.msr_number,
               m.date_of_msr,
               m.created_at,
               u.first_name AS user_first_name,
               u.last_name  AS user_last_name
        FROM msr m
        JOIN users u ON m.user_id = u.id
        WHERE m.user_id = ?
          AND m.date_of_msr = CURDATE()
        LIMIT 1
    ";
  $stmt = $conn->prepare($sql);
  $stmt->bind_param("i", $user_id);
  $stmt->execute();
  $res = $stmt->get_result();
  if ($res->num_rows === 0) {
    echo json_encode(['exists' => false]);
    exit;
  }
  $msrRow = $res->fetch_assoc();
  $msr_id = (int)$msrRow['msr_id'];
  $stmt->close();

  // Derive the day name from the date_of_msr.
  $dateOfMSR = $msrRow['date_of_msr'];
  $dtObj = new DateTime($dateOfMSR);
  $dayName = $dtObj->format('l');
  $response = [
    'exists'     => true,
    'date'       => $dateOfMSR,
    'day'        => $dayName,
    'msr_number' => $msrRow['msr_number'] ?? ''
  ];
  echo json_encode($response);
} else {
  // Admin: allow creation at any date – do not block creation.
  echo json_encode(['exists' => false]);
}
