<?php
// actions/msr/update_holiday.php
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header('Content-Type: application/json');

if (!isset($_SESSION['user_id'])) {
    echo json_encode(['success' => false, 'message' => 'No valid session.']);
    exit;
}
$user_role = $_SESSION['role'] ?? 'staff';
if ($user_role !== 'admin') {
    echo json_encode(['success' => false, 'message' => 'Only admin can edit holiday.']);
    exit;
}

// If ?fetch=1 => return holiday data
if (isset($_GET['fetch']) && $_GET['fetch'] == '1') {
    $id = (int)($_GET['id'] ?? 0);
    if ($id < 1) {
        echo json_encode(['success' => false, 'message' => 'Invalid holiday ID.']);
        exit;
    }
    $sql = "SELECT id, date_of_msr, remarks FROM msr WHERE id=? AND holiday=1 LIMIT 1";
    $st = $conn->prepare($sql);
    $st->bind_param('i', $id);
    $st->execute();
    $res = $st->get_result();
    if (!$res || $res->num_rows < 1) {
        echo json_encode(['success' => false, 'message' => 'Holiday record not found.']);
        exit;
    }
    $row = $res->fetch_assoc();
    echo json_encode(['success' => true, 'data' => $row]);
    exit;
}

// else => update
$data = json_decode(file_get_contents('php://input'), true);
if (!$data) {
    echo json_encode(['success' => false, 'message' => 'No input data.']);
    exit;
}
$id      = (int)($data['id'] ?? 0);
$newDate = trim($data['date_of_msr'] ?? '');
$remarks = trim($data['remarks'] ?? '');

if ($id < 1 || !$newDate) {
    echo json_encode(['success' => false, 'message' => 'Invalid or missing fields.']);
    exit;
}

// check collision
$chk = $conn->prepare("
    SELECT id FROM msr
    WHERE date_of_msr=? 
    AND id<>? 
    LIMIT 1
");
$chk->bind_param('si', $newDate, $id);
$chk->execute();
$rc = $chk->get_result();
if ($rc && $rc->num_rows > 0) {
    echo json_encode(['success' => false, 'message' => "There's already an MSR or holiday for {$newDate}."]);
    exit;
}
$chk->close();

// update
$up = $conn->prepare("UPDATE msr SET date_of_msr=?, remarks=? WHERE id=? AND holiday=1");
$up->bind_param('ssi', $newDate, $remarks, $id);
if (!$up->execute()) {
    echo json_encode(['success' => false, 'message' => 'Failed updating: ' . $up->error]);
    exit;
}
if ($up->affected_rows < 1) {
    echo json_encode(['success' => false, 'message' => 'No row updated or not a holiday row.']);
    exit;
}
$up->close();

echo json_encode(['success' => true, 'message' => 'Holiday updated successfully.']);
