<?php
// actions/patient/checkDuplicates.php

header('Content-Type: application/json');

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Read incoming JSON
$raw = file_get_contents('php://input');
$data = json_decode($raw, true);

$icNumber       = $data['icNumber']       ?? '';
$firstName      = $data['firstName']      ?? '';
$lastName       = $data['lastName']       ?? '';
$excludePatient = (int)($data['excludePatientId'] ?? 0);

$response = [
    'icExists' => false,
    'nameMatches' => []
];

// 1) Check IC
if (!empty($icNumber)) {
    $stmt = $conn->prepare("SELECT id FROM patients WHERE identificationNumber = ? AND id != ? LIMIT 1");
    $stmt->bind_param("si", $icNumber, $excludePatient);
    $stmt->execute();
    $res = $stmt->get_result();
    if ($res->num_rows > 0) {
        // Means some other patient uses the same IC
        $response['icExists'] = true;
    }
    $stmt->close();
}

// 2) Check name
if (!empty($firstName) && !empty($lastName)) {
    // exact match: first_name & last_name, ignoring the same record
    $stmt2 = $conn->prepare("
      SELECT id, first_name, last_name, contact, identificationNumber
      FROM patients
      WHERE first_name = ? 
        AND last_name = ?
        AND id != ?
    ");
    $stmt2->bind_param("ssi", $firstName, $lastName, $excludePatient);
    $stmt2->execute();
    $res2 = $stmt2->get_result();
    while ($row = $res2->fetch_assoc()) {
        $response['nameMatches'][] = [
            'id'                  => $row['id'],
            'first_name'          => $row['first_name'],
            'last_name'           => $row['last_name'],
            'contact'             => $row['contact'],
            'identificationNumber' => $row['identificationNumber']
        ];
    }
    $stmt2->close();
}

echo json_encode($response);
exit();
