// assets/js/populateDropdowns.js

$(document).ready(function () {
  const stateSelect = $("#state");
  const citySelect = $("#city");
  const postcodeSelect = $("#postcode");

  // Function to populate dropdowns
  function populateDropdown(selectElement, data, placeholder) {
    selectElement.empty().append(`<option value="">${placeholder}</option>`);
    $.each(data, function (index, item) {
      let value = item.name || item.postcode;
      let text = item.name || item.postcode;
      selectElement.append(`<option value="${value}">${text}</option>`);
    });
  }

  // Populate States on Page Load
  $.ajax({
    url: "actions/get_states.php",
    type: "GET",
    dataType: "json",
    success: function (data) {
      populateDropdown(stateSelect, data, "Select State");
    },
    error: function (xhr, status, error) {
      console.error("Error fetching states:", error);
    },
  });

  // Populate Cities based on Selected State
  stateSelect.on("change", function () {
    const selectedState = $(this).val();
    if (selectedState === "") {
      populateDropdown(citySelect, [], "Select City");
      populateDropdown(postcodeSelect, [], "Select Postcode");
      return;
    }

    $.ajax({
      url: "actions/get_cities.php",
      type: "GET",
      data: { state: selectedState },
      dataType: "json",
      success: function (data) {
        populateDropdown(citySelect, data, "Select City");
        populateDropdown(postcodeSelect, [], "Select Postcode"); // Reset Postcode
      },
      error: function (xhr, status, error) {
        console.error("Error fetching cities:", error);
      },
    });
  });

  // Populate Postcodes based on Selected City
  citySelect.on("change", function () {
    const selectedCity = $(this).val();
    if (selectedCity === "") {
      populateDropdown(postcodeSelect, [], "Select Postcode");
      return;
    }

    $.ajax({
      url: "actions/get_postcodes.php",
      type: "GET",
      data: { city: selectedCity },
      dataType: "json",
      success: function (data) {
        populateDropdown(postcodeSelect, data, "Select Postcode");
      },
      error: function (xhr, status, error) {
        console.error("Error fetching postcodes:", error);
      },
    });
  });
});
