<?php

/**
 * actions/reports/add_report_diagnosis.php
 *
 * Receives:
 *   $_POST['report_action'] => 'addReportForDiagnosis'
 *   $_POST['diagnosis_id']
 *   $_POST['patient_id']
 *   $_POST['report_type'], $_POST['report_date'], ...
 *   $_FILES['report_file'] (optional)
 */

session_start();
date_default_timezone_set('Asia/Kuala_Lumpur');

// Include config, session checks
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

$currentUserID = $_SESSION['user_id'] ?? 0;
if ($currentUserID < 1) {
    $_SESSION['error'] = "No valid user session. Please log in.";
    header("Location: " . $baseURL . "login.php");
    exit;
}

if ($_SERVER['REQUEST_METHOD'] === 'POST' && ($_POST['report_action'] ?? '') === 'addReportForDiagnosis') {
    $diagID   = (int)($_POST['diagnosis_id'] ?? 0);
    $pID      = (int)($_POST['patient_id']   ?? 0);
    $rType    = $_POST['report_type']        ?? 'Other';
    $rDate    = $_POST['report_date']        ?? date('Y-m-d');
    $remarks  = $_POST['remarks']            ?? '';

    // Handle optional file upload
    $reportPath = null;
    if (isset($_FILES['report_file']) && $_FILES['report_file']['error'] === UPLOAD_ERR_OK) {
        // e.g. find patient name => create subdir => move file
        $sqlP = "SELECT first_name, last_name FROM patients WHERE id=? LIMIT 1";
        $stmP = $conn->prepare($sqlP);
        $stmP->bind_param("i", $pID);
        $stmP->execute();
        $rP = $stmP->get_result();
        if ($rP->num_rows < 1) {
            $_SESSION['error'] = "Patient not found for file upload.";
            header("Location: " . $baseURL . "pages/patient/patientProfile.php?id=$pID&diagnoses-tab=1");
            exit;
        }
        $pRow = $rP->fetch_assoc();
        $stmP->close();
        $pName = trim($pRow['first_name'] . ' ' . $pRow['last_name']);
        $safeName = preg_replace('/[^A-Za-z0-9_\-]/', '_', $pName);

        $dirPath = ROOT_PATH . "uploads/reports/$safeName";
        if (!is_dir($dirPath)) {
            mkdir($dirPath, 0777, true);
        }
        $tmpF  = $_FILES['report_file']['tmp_name'];
        $origN = $_FILES['report_file']['name'];
        $origN = preg_replace('/[^A-Za-z0-9_\-\.]/', '_', $origN);
        $destF = $dirPath . '/' . date('YmdHis') . '_' . $origN;
        if (!move_uploaded_file($tmpF, $destF)) {
            $_SESSION['error'] = "Error uploading file for report.";
            header("Location: " . $baseURL . "pages/patient/patientProfile.php?id=$pID&diagnoses-tab=1");
            exit;
        }
        $reportPath = "reports/$safeName/" . basename($destF);
    }

    // Insert row into reports
    $sqlR = "
      INSERT INTO reports (
        PatientID,
        DiagnosisID,
        ReportType,
        ReportDate,
        ReportPath,
        remarks,
        CreatedBy,
        UpdatedBy,
        CreatedAt,
        UpdatedAt
      ) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())
    ";
    $stR = $conn->prepare($sqlR);
    $stR->bind_param(
        "iissssii",
        $pID,
        $diagID,
        $rType,
        $rDate,
        $reportPath,
        $remarks,
        $currentUserID,
        $currentUserID
    );
    $stR->execute();
    $newReportID = $stR->insert_id;
    $stR->close();

    $_SESSION['success'] = "Report #$newReportID added for Diagnosis #$diagID.";
    // e.g. redirect to the same patient's Diagnoses tab
    header("Location: " . $baseURL . "pages/patient/patientProfile.php?id=$pID&diagnoses-tab=1");
    exit;
}

// If accessed incorrectly, just redirect
header("Location: " . $baseURL . "pages/patient/patientList.php");
exit;
