<?php
// actions/user/add_user.php

header('Content-Type: application/json');
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Ensure only admins can add users
if ($_SESSION['role'] !== 'admin') {
    echo json_encode(['success' => false, 'message' => 'Unauthorized access.']);
    exit;
}

// Get the raw POST data
$inputJSON = file_get_contents('php://input');
$input = json_decode($inputJSON, true);

// Validate input
$required_fields = ['first_name', 'last_name', 'username', 'password', 'role'];
foreach ($required_fields as $field) {
    if (empty($input[$field])) {
        echo json_encode(['success' => false, 'message' => ucfirst(str_replace('_', ' ', $field)) . ' is required.']);
        exit;
    }
}

$first_name = trim($input['first_name']);
$last_name = trim($input['last_name']);
$username = trim($input['username']);
$password = trim($input['password']);
$role = trim($input['role']);

// Validate role
if (!in_array($role, ['staff', 'admin'])) {
    echo json_encode(['success' => false, 'message' => 'Invalid role selected.']);
    exit;
}

// Check if username already exists
$stmt = $conn->prepare("SELECT id FROM users WHERE username = ?");
$stmt->bind_param('s', $username);
$stmt->execute();
$stmt->store_result();
if ($stmt->num_rows > 0) {
    echo json_encode(['success' => false, 'message' => 'Username already exists.']);
    $stmt->close();
    exit;
}
$stmt->close();

// Hash the password
$password_hash = password_hash($password, PASSWORD_DEFAULT);

// Insert the new user
$stmt = $conn->prepare("
    INSERT INTO users (first_name, last_name, username, password_hash, role)
    VALUES (?, ?, ?, ?, ?)
");
if (!$stmt) {
    echo json_encode(['success' => false, 'message' => 'Database error: ' . $conn->error]);
    exit;
}

$stmt->bind_param('sssss', $first_name, $last_name, $username, $password_hash, $role);

if ($stmt->execute()) {
    echo json_encode(['success' => true, 'message' => 'User added successfully.']);
} else {
    echo json_encode(['success' => false, 'message' => 'Failed to add user: ' . $stmt->error]);
}

$stmt->close();
?>
