// assets/js/doctorCalendar.js
document.addEventListener('DOMContentLoaded', function () {
    let calendarEl = document.getElementById('doctorCalendar');

    let calendar = new FullCalendar.Calendar(calendarEl, {
        themeSystem: 'bootstrap5', // use Bootstrap 5 theme
        initialView: 'dayGridMonth',
        headerToolbar: {
            left: 'prev,next today',
            center: 'title',
            right: 'dayGridMonth,timeGridWeek,timeGridDay'
        },
        // Make day/week have time slots
        slotMinTime: '08:00:00',
        slotMaxTime: '20:00:00',
        // Display the event's end time as well
        displayEventEnd: true,

        // To handle switching between dayGrid and timeGrid properly
        views: {
            dayGridMonth: {
                // Show a maximum number of events before a "more" link
                dayMaxEventRows: 3
            },
            timeGridWeek: {
                dayMaxEventRows: false
            },
            timeGridDay: {
                dayMaxEventRows: false
            }
        },

        // Event data
        events: {
            url: baseURL + 'actions/fetch_appointments.php', // <-- Adjust path
            method: 'GET',
            failure: function () {
                alert('There was an error fetching appointments!');
            }
        },

        // Format the time label on events (e.g., "10:00 - 10:30")
        eventTimeFormat: {
            hour: '2-digit',
            minute: '2-digit',
            hour12: false
        },

        // On event click, show modal with extra details
        eventClick: function (info) {
            let eventObj = info.event;
            let props = eventObj.extendedProps; // Additional data from the fetch_appointments.php

            // Fill in modal details
            document.getElementById('eventPatientName').textContent = props.patientFullName || '(Unknown)';
            // eventObj.startStr is "YYYY-MM-DDTHH:MM:SS"
            let dateOnly = eventObj.startStr.substring(0, 10); // "YYYY-MM-DD"
            document.getElementById('eventDate').textContent = dateOnly;
            document.getElementById('eventTime').textContent = props.appointmentTime || '(No Time)';

            // Construct link to the patient's diagnosis tab
            // e.g. "patientProfile.php?id=123#diagnoses-tab"
            let link = baseURL + 'pages/patient/patientProfile.php?id=' + props.patientID + '#diagnoses-tab';
            document.getElementById('diagnosisLink').href = link;

            // Show the modal
            let modalEl = document.getElementById('eventDetailsModal');
            let bootstrapModal = new bootstrap.Modal(modalEl);
            bootstrapModal.show();
        }
    });

    calendar.render();
});
