// assets/js/populateDropdowns.js

$(document).ready(function () {
  const stateSelect = $("#state");
  const citySelect = $("#city");
  const postcodeSelect = $("#postcode");

  // Function to populate dropdowns
  function populateDropdown(selectElement, data, placeholder) {
    selectElement.empty().append(`<option value="">${placeholder}</option>`);
    $.each(data, function (index, item) {
      // If your API returns { "name": "..."} or { "postcode": "..." }
      // adjust accordingly. For example, if you store it as "name" or "value"
      let value = item.name || item.postcode;
      let text = item.name || item.postcode;
      selectElement.append(`<option value="${value}">${text}</option>`);
    });
  }

  // --- Utility function to set the selected value from data-* attribute ---
  function setSelectedValue($select, dataAttr) {
    const desiredValue = $select.data(dataAttr);  // e.g. data("selected-state")
    if (desiredValue) {
      $select.val(desiredValue);
    }
  }

  // --- Step 1: Load States on Page Load ---
  $.ajax({
    url: baseURL + "actions/get_states.php",
    type: "GET",
    dataType: "json",
    success: function (data) {
      populateDropdown(stateSelect, data, "Select State");
      // If we're in edit mode, set the state from data-selected-state
      setSelectedValue(stateSelect, "selected-state");
      // If there's a pre-selected state, trigger change => load city
      if (stateSelect.val()) {
        stateSelect.trigger("change");
      }
    },
    error: function (xhr, status, error) {
      console.error("Error fetching states:", error);
    },
  });

  // --- Step 2: Populate Cities when the user changes (or we programmatically change) State ---
  stateSelect.on("change", function () {
    const selectedState = $(this).val();

    if (selectedState === "") {
      populateDropdown(citySelect, [], "Select City");
      populateDropdown(postcodeSelect, [], "Select Postcode");
      return;
    }

    $.ajax({
      url: baseURL + "actions/get_cities.php",
      type: "GET",
      data: { state: selectedState },
      dataType: "json",
      success: function (data) {
        populateDropdown(citySelect, data, "Select City");
        populateDropdown(postcodeSelect, [], "Select Postcode"); // Reset Postcode

        // In edit mode, set city from data-selected-city
        setSelectedValue(citySelect, "selected-city");
        // If city is set, trigger city change => load postcodes
        if (citySelect.val()) {
          citySelect.trigger("change");
        }
      },
      error: function (xhr, status, error) {
        console.error("Error fetching cities:", error);
      },
    });
  });

  // --- Step 3: Populate Postcodes when user changes (or we programmatically change) City ---
  citySelect.on("change", function () {
    const selectedCity = $(this).val();
    if (selectedCity === "") {
      populateDropdown(postcodeSelect, [], "Select Postcode");
      return;
    }

    $.ajax({
      url: baseURL + "actions/get_postcodes.php",
      type: "GET",
      data: { city: selectedCity },
      dataType: "json",
      success: function (data) {
        populateDropdown(postcodeSelect, data, "Select Postcode");

        // In edit mode, set the postcode
        setSelectedValue(postcodeSelect, "selected-postcode");
      },
      error: function (xhr, status, error) {
        console.error("Error fetching postcodes:", error);
      },
    });
  });
});
