$(document).ready(function () {
  // Handle Add User Form Submission
  $("#addUserForm").on("submit", function (e) {
    e.preventDefault();

    // Collect form data
    const formData = {
      first_name: $("#add_first_name").val().trim(),
      last_name: $("#add_last_name").val().trim(),
      username: $("#add_username").val().trim(),
      password: $("#add_password").val().trim(),
      role: $("#add_role").val(),
    };

    // Basic validation
    if (
      !formData.first_name ||
      !formData.last_name ||
      !formData.username ||
      !formData.password ||
      !formData.role
    ) {
      $("#addUserAlert").html(
        '<div class="alert alert-danger">All fields are required.</div>'
      );
      return;
    }

    // Send AJAX request to add_user.php
    $.ajax({
      url: `${baseURL}actions/userManage/add_user.php`,
      type: "POST",
      contentType: "application/json",
      data: JSON.stringify(formData),
      success: function (response) {
        if (response.success) {
          $("#addUserAlert").html(
            '<div class="alert alert-success">User added successfully.</div>'
          );
          // Optionally, refresh the page or append the new user to the table
          setTimeout(() => {
            window.location.reload();
          }, 1000);
        } else {
          $("#addUserAlert").html(
            `<div class="alert alert-danger">${response.message}</div>`
          );
        }
      },
      error: function () {
        $("#addUserAlert").html(
          '<div class="alert alert-danger">An error occurred while adding the user.</div>'
        );
      },
    });
  });

  // Handle Edit User Button Click
  $(".edit-user-btn").on("click", function () {
    const user = $(this).data("user");

    // Populate the edit form with user data
    $("#edit_user_id").val(user.id);
    $("#edit_first_name").val(user.first_name);
    $("#edit_last_name").val(user.last_name);
    $("#edit_username").val(user.username);
    $("#edit_password").val(""); // Leave password blank
    $("#edit_role").val(user.role);

    // Clear previous alerts
    $("#editUserAlert").html("");

    // Show the edit modal
    $("#editUserModal").modal("show");
  });

  // Handle Edit User Form Submission
  $("#editUserForm").on("submit", function (e) {
    e.preventDefault();

    // Collect form data
    const formData = {
      id: $("#edit_user_id").val(),
      first_name: $("#edit_first_name").val().trim(),
      last_name: $("#edit_last_name").val().trim(),
      username: $("#edit_username").val().trim(),
      password: $("#edit_password").val().trim(), // Optional
      role: $("#edit_role").val(),
    };

    // Basic validation
    if (
      !formData.first_name ||
      !formData.last_name ||
      !formData.username ||
      !formData.role
    ) {
      $("#editUserAlert").html(
        '<div class="alert alert-danger">First Name, Last Name, Username, and Role are required.</div>'
      );
      return;
    }

    // Send AJAX request to edit_user.php
    $.ajax({
      url: `${baseURL}actions/userManage/edit_user.php`,
      type: "POST",
      contentType: "application/json",
      data: JSON.stringify(formData),
      success: function (response) {
        if (response.success) {
          $("#editUserAlert").html(
            '<div class="alert alert-success">User updated successfully.</div>'
          );
          // Optionally, refresh the page or update the user row in the table
          setTimeout(() => {
            window.location.reload();
          }, 1000);
        } else {
          $("#editUserAlert").html(
            `<div class="alert alert-danger">${response.message}</div>`
          );
        }
      },
      error: function () {
        $("#editUserAlert").html(
          '<div class="alert alert-danger">An error occurred while updating the user.</div>'
        );
      },
    });
  });
});
