<?php
// pages/appointments/doctor_appointments.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// Determine user role from session or default to 'staff'
$userRole = $_SESSION['role'] ?? 'staff';
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Appointments Calendar | Agasthiar</title>
    <!-- Bootstrap + FontAwesome -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">

    <!-- FullCalendar CSS (Bootstrap 5 theme) -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/index.global.min.css">
    <!-- You can also use the bootstrap 5 theme for FullCalendar -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/bootstrap5.min.css">

    <!-- Your custom CSS -->
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">

    <style>
        /* Container for the calendar */
        #doctorCalendar {
            max-width: 1100px;
            margin: 0 auto;
        }

        /* FullCalendar overrides for better visual match */
        .fc .fc-button {
            background-color: #0d6efd !important;
            /* Bootstrap primary color */
            color: #fff !important;
            border: none;
        }

        .fc .fc-button:hover {
            background-color: #0b5ed7 !important;
        }

        /* Event styling: green background, white text */
        .fc-daygrid-event,
        .fc-timegrid-event {
            background-color: #198754 !important;
            /* Bootstrap success color */
            color: #fff !important;
            border: none;
        }

        /* Make the heading text more prominent */
        .fc-toolbar-title {
            font-size: 1.3rem;
            font-weight: 600;
        }
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- Header Card -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">Agasthiar Siddha Ayurmed Sdn. Bhd</h4>
                        <p class="mb-0">Doctor's Appointments Calendar</p>
                    </div>
                </div>

                <!-- Calendar Card -->
                <div class="card shadow border-0 mb-4">
                    <div class="card-body">
                        <div id="doctorCalendar"></div>
                    </div>
                </div>
            </div>
        </div>
    </div>

    <!-- Hidden user role so we can read it in JS if needed -->
    <input type="hidden" id="userRole" value="<?php echo htmlspecialchars($userRole); ?>">

    <!-- Appointment Details Modal -->
    <div class="modal fade" id="eventDetailsModal" tabindex="-1" aria-labelledby="eventDetailsModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 id="eventDetailsModalLabel" class="modal-title">Appointment Details</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body">
                    <!-- Display fields (populated via JS) -->
                    <div class="mb-3">
                        <label class="form-label fw-bold">Patient:</label>
                        <div id="eventPatientName"></div>
                    </div>
                    <div class="mb-3">
                        <label class="form-label fw-bold">Appointment Date:</label>
                        <div id="eventDate"></div>
                    </div>
                    <div class="mb-3">
                        <label class="form-label fw-bold">Time:</label>
                        <div id="eventTime"></div>
                    </div>
                    <div class="text-center mt-4">
                        <a href="#" id="diagnosisLink" class="btn btn-success" target="_blank">
                            Go to Diagnosis <i class="fas fa-external-link-alt"></i>
                        </a>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">
                        Close
                    </button>
                </div>
            </div>
        </div>
    </div>
    <!-- End Modal -->

    <!-- Provide baseURL for JS scripts -->
    <script>
        const baseURL = "<?php echo $baseURL; ?>";
    </script>

    <!-- JS includes: jQuery, Bootstrap, FullCalendar, etc. -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <!-- FullCalendar JS -->
    <script src="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/index.global.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/bootstrap5.min.js"></script>

    <!-- Custom scripts -->
    <script src="<?php echo $baseURL; ?>assets/js/scripts.js"></script>
    <!-- Our dedicated calendar logic -->
    <script src="<?php echo $baseURL; ?>assets/js/doctorCalendar.js"></script>

    <?php include ROOT_PATH . 'includes/footer.php'; ?>
</body>

</html>