<?php
// pages/patient/dashboard.php

include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// USER + ROLE
$userId    = $_SESSION['user_id']    ?? 0;
$firstName = $_SESSION['first_name'] ?? 'User';
$role      = $_SESSION['role']       ?? 'staff';

// -----------------------------------------
// (A) FETCH HIGH-LEVEL STATS (NO PAGINATION NEEDED)
// -----------------------------------------

// Total Patients
$sqlP = "SELECT COUNT(*) AS total_patients FROM patients";
$resP = $conn->query($sqlP);
$totalPatients = ($resP && $rp = $resP->fetch_assoc()) ? (int)$rp['total_patients'] : 0;

// Total Appointments
$sqlAp = "SELECT COUNT(*) AS total_appts FROM appointments";
$resAp = $conn->query($sqlAp);
$totalAppointments = ($resAp && $ra = $resAp->fetch_assoc()) ? (int)$ra['total_appts'] : 0;

// Total Debts
$sqlDebt = "SELECT IFNULL(SUM(balance_after_payment),0) AS total_debts FROM debts";
$resD = $conn->query($sqlDebt);
$totalDebtsAll = 0.0;
if ($resD && $rd = $resD->fetch_assoc()) {
    $totalDebtsAll = (float)$rd['total_debts'];
}

// Overdue Debts (>30 days)
$sqlOver = "
  SELECT COUNT(DISTINCT patient_id) AS overdue_count
  FROM debts
  WHERE DATEDIFF(CURDATE(),date_of_debt)>30
    AND balance_after_payment>0
";
$resO = $conn->query($sqlOver);
$overdueDebts30 = 0;
if ($resO && $ro = $resO->fetch_assoc()) {
    $overdueDebts30 = (int)$ro['overdue_count'];
}

// Total Reports
$sqlTR = "SELECT COUNT(*) AS total_reports FROM reports";
$resTR = $conn->query($sqlTR);
$totalReportsAll = 0;
if ($resTR && $rtr = $resTR->fetch_assoc()) {
    $totalReportsAll = (int)$rtr['total_reports'];
}

// Reports this Month
$sqlRM = "
  SELECT COUNT(*) AS month_reports
  FROM reports
  WHERE YEAR(ReportDate)=YEAR(CURDATE())
    AND MONTH(ReportDate)=MONTH(CURDATE())
";
$resRM = $conn->query($sqlRM);
$monthReports = 0;
if ($resRM && $rrm = $resRM->fetch_assoc()) {
    $monthReports = (int)$rrm['month_reports'];
}

// Count of upcoming followups
$sqlF = "
  SELECT COUNT(*) AS cnt
  FROM follow_up
  WHERE FollowUpDate>=NOW()
    AND FollowUpStatus<>'Done'
";
$resF = $conn->query($sqlF);
$totalUpcomingFUs = 0;
if ($resF && $rf = $resF->fetch_assoc()) {
    $totalUpcomingFUs = (int)$rf['cnt'];
}
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Dashboard | Example</title>
    <meta name="viewport" content="width=device-width,initial-scale=1.0">
    <!-- Bootstrap + Font Awesome -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet" />
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet" />
    <!-- FullCalendar (Bootstrap 5 theme) -->
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/index.global.min.css" />
    <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/bootstrap5.min.css" />
    <!-- Custom CSS -->
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">

    <style>
        .card-pastel {
            background: #f0f8ff;
            border-radius: 10px;
            transition: transform .2s ease-in-out;
        }

        .card-pastel:hover {
            transform: translateY(-2px);
        }

        .card-pastel-lilac {
            background: #eef3ff;
        }

        .card-pastel-pink {
            background: #fff0f0;
        }

        .card-calendar {
            background: #f9f9ff;
            border-radius: 10px;
        }

        /* FULLCALENDAR OVERRIDES */
        #dashboardCalendar {
            max-width: 900px;
            margin: 0 auto;
        }

        .fc .fc-button {
            background-color: #0d6efd !important;
            color: #fff !important;
            border: none;
        }

        .fc .fc-button:hover {
            background-color: #0b5ed7 !important;
        }

        .fc-daygrid-event,
        .fc-timegrid-event {
            background-color: #198754 !important;
            color: #fff !important;
            border: none;
        }

        .fc-toolbar-title {
            font-size: 1.3rem;
            font-weight: 600;
        }
    </style>
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- Greeting -->
                <div class="mb-4">
                    <h1 class="mb-1">Hello, <?php echo htmlspecialchars($firstName); ?>!</h1>
                    <p class="text-muted">Welcome to your Dashboard (Role: <?php echo htmlspecialchars($role); ?>).</p>
                </div>

                <!-- Row 1: Stats -->
                <div class="row g-4">
                    <!-- Patients -->
                    <div class="col-md-4">
                        <div class="card card-pastel shadow-sm h-100">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fa fa-user-injured me-2"></i>Total Patients</h5>
                                <p class="display-6 text-center mb-0"><?php echo $totalPatients; ?></p>
                            </div>
                        </div>
                    </div>
                    <!-- Appts -->
                    <div class="col-md-4">
                        <div class="card card-pastel-lilac shadow-sm h-100">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fa fa-calendar-check me-2"></i>Total Appointments</h5>
                                <p class="display-6 text-center mb-0"><?php echo $totalAppointments; ?></p>
                            </div>
                        </div>
                    </div>
                    <!-- Debts -->
                    <div class="col-md-4">
                        <div class="card card-pastel shadow-sm h-100" style="background:#e8f6ff;">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fa fa-money-bill-wave me-2"></i>Total Debts So Far</h5>
                                <p class="display-6 text-center mb-0">
                                    RM <?php echo number_format($totalDebtsAll, 2); ?>
                                </p>
                            </div>
                        </div>
                    </div>
                </div><!-- end row1 -->

                <!-- Row 2: more stats -->
                <div class="row g-4 mt-4">
                    <!-- total upcoming followups -->
                    <div class="col-md-4">
                        <div class="card card-pastel shadow-sm h-100" style="background:#f3f9ff;">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fa fa-bell me-2"></i>Total Upcoming Followups</h5>
                                <p class="display-6 text-center mb-0"><?php echo $totalUpcomingFUs; ?></p>
                            </div>
                        </div>
                    </div>
                    <!-- overdue debts -->
                    <div class="col-md-4">
                        <div class="card card-pastel-lilac shadow-sm h-100">
                            <div class="card-body">
                                <h5 class="card-title">
                                    <i class="fa fa-exclamation-triangle me-2"></i>Overdue Debts (>30 Days)
                                </h5>
                                <p class="display-6 text-center mb-0">
                                    <?php echo $overdueDebts30; ?>
                                </p>
                            </div>
                        </div>
                    </div>
                    <!-- total reports -->
                    <div class="col-md-4">
                        <div class="card card-pastel shadow-sm h-100" style="background:#fef9ff;">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fa fa-file-upload me-2"></i>Total Reports</h5>
                                <p class="display-6 text-center mb-1">
                                    <?php echo $totalReportsAll; ?><small>(All Time)</small>
                                </p>
                                <p class="text-center mb-0">
                                    <strong>This Month:</strong> <?php echo $monthReports; ?>
                                </p>
                            </div>
                        </div>
                    </div>
                </div><!-- end row2 -->

                <!-- Row 3: Quick Access Cards (Add Patient, MSR, Unified Overview) -->
                <div class="row g-4 mt-4">
                    <div class="col-md-4">
                        <div class="card card-pastel shadow-sm h-100" style="background:#f3fafe;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-user-plus me-2"></i>Add Patient</h5>
                                <p class="mb-3">Quickly register a new patient.</p>
                                <a href="<?php echo $baseURL; ?>pages/patient/patientAdd.php" class="btn btn-primary mt-auto">
                                    <i class="fa fa-arrow-right"></i> Go
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="card card-pastel-lilac shadow-sm h-100">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-capsules me-2"></i>Manage MSR</h5>
                                <p class="mb-3">Create or update Medicine Sold Report.</p>
                                <a href="<?php echo $baseURL; ?>pages/msr/msrList.php" class="btn btn-primary mt-auto">
                                    <i class="fa fa-arrow-right"></i> Go
                                </a>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-4">
                        <div class="card card-pastel shadow-sm h-100" style="background:#eef3ff;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-table me-2"></i>Unified Overview</h5>
                                <p class="mb-3">See all upcoming items (Appointments, Follow-Ups, Diagnosis) in one place.</p>
                                <a href="<?php echo $baseURL; ?>pages/upcoming/all_items.php?tab=appointments"
                                    class="btn btn-primary mt-auto">
                                    <i class="fa fa-arrow-right"></i> Go
                                </a>
                            </div>
                        </div>
                    </div>
                </div><!-- end row3 -->

                <!-- Row 4: Search & Filters + Pending Debts -->
                <div class="row g-4 mt-4">
                    <div class="col-md-6">
                        <div class="card card-pastel shadow-sm h-100" style="background:#f3f9ff;">
                            <div class="card-body">
                                <h5 class="card-title"><i class="fa fa-search me-2"></i>Search & Filters</h5>
                                <form method="GET" action="<?php echo $baseURL; ?>pages/patient/patientList.php" class="mb-3">
                                    <div class="mb-3">
                                        <label class="form-label">Search by Name</label>
                                        <input type="text" name="patient_name" class="form-control" placeholder="Enter name...">
                                    </div>
                                    <div class="mb-3">
                                        <label class="form-label">Search by IC</label>
                                        <input type="text" name="icNum" class="form-control" placeholder="Enter IC...">
                                    </div>
                                    <button type="submit" class="btn btn-primary">
                                        <i class="fa fa-search"></i> Search
                                    </button>
                                </form>
                                <p class="text-muted mb-0">
                                    <small>
                                        Use the above fields to quickly find patients by Name or IC.
                                        Advanced filters on <a href="<?php echo $baseURL; ?>pages/msr/msrList.php">MSR List</a>.
                                    </small>
                                </p>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="card card-pastel shadow-sm h-100" style="background:#fff0f0;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-exclamation-circle me-2"></i>Pending Debts</h5>
                                <div id="pendingDebtsContainer" class="mt-2"></div>
                            </div>
                        </div>
                    </div>
                </div><!-- end row4 -->

                <!-- Row 5: Upcoming Follow-Ups + Upcoming Appointments -->
                <div class="row g-4 mt-4">
                    <div class="col-md-6">
                        <div class="card shadow-sm h-100" style="background:#f3f9ff;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-bell me-2"></i>Upcoming Follow-Ups</h5>
                                <!-- We'll show "Follow-Up Date" + "Category" + "Status Update" -->
                                <div id="upcomingFollowupsContainer" class="mt-2"></div>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="card shadow-sm h-100" style="background:#f7faff;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-calendar-day me-2"></i>Upcoming Appointments</h5>
                                <!-- We'll show only future + not completed -->
                                <div id="upcomingAppointmentsContainer" class="mt-2"></div>
                            </div>
                        </div>
                    </div>
                </div><!-- end row5 -->

                <!-- Row 6: Diagnosis Follow-Ups + Overdue Items -->
                <div class="row g-4 mt-4">
                    <div class="col-md-6">
                        <div class="card shadow-sm h-100" style="background:#f9fffa;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-stethoscope me-2"></i>Diagnosis-Based Follow-Ups</h5>
                                <div id="diagnosisFollowupsContainer" class="mt-2"></div>
                            </div>
                        </div>
                    </div>
                    <div class="col-md-6">
                        <div class="card shadow-sm h-100" style="background:#ffeceb;">
                            <div class="card-body d-flex flex-column">
                                <h5 class="card-title"><i class="fa fa-exclamation-circle me-2"></i>Overdue / Missed Items</h5>
                                <div id="overdueContainer" class="mt-2"></div>
                            </div>
                        </div>
                    </div>
                </div><!-- end row6 -->

                <!-- Row 7: Calendar -->
                <div class="row g-4 mt-4">
                    <div class="col-12">
                        <div class="card card-calendar shadow-sm">
                            <div class="card-body">
                                <h5 class="card-title mb-3"><i class="fa fa-calendar-alt me-2"></i>Calendar</h5>
                                <div id="dashboardCalendar"></div>
                            </div>
                        </div>
                    </div>
                </div><!-- end row7 -->

            </div><!-- end container-fluid -->
        </div><!-- end #page-content-wrapper -->

        <?php include ROOT_PATH . 'includes/footer.php'; ?>
    </div><!-- end #wrapper -->

    <!-- FullCalendar Modal if needed -->
    <div class="modal fade" id="eventDetailsModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <div class="modal-content">
                <!-- ... -->
            </div>
        </div>
    </div>

    <script>
        const baseURL = "<?php echo $baseURL; ?>";
    </script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/index.global.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/fullcalendar@6.1.4/bootstrap5.min.js"></script>

    <script>
        document.addEventListener('DOMContentLoaded', function() {
            initCalendar();
            // Load each data block
            fetchPendingDebts(1);
            fetchUpcomingFollowups(1);
            fetchUpcomingAppointments(1);
            fetchDiagnosisFollowups(1);
            fetchOverdueItems(1);
        });

        function initCalendar() {
            let calendarEl = document.getElementById('dashboardCalendar');
            let calendar = new FullCalendar.Calendar(calendarEl, {
                themeSystem: 'bootstrap5',
                initialView: 'dayGridMonth',
                headerToolbar: {
                    left: 'prev,next today',
                    center: 'title',
                    right: 'dayGridMonth,timeGridWeek,timeGridDay'
                },
                eventTimeFormat: {
                    hour: '2-digit',
                    minute: '2-digit',
                    hour12: false
                },
                events: {
                    url: baseURL + 'actions/fetch_appointments.php',
                    method: 'GET',
                    failure: function() {
                        alert('Error fetching appointments!');
                    }
                },
                eventClick: function(info) {
                    // show modal or do something
                }
            });
            calendar.render();
        }

        // 1) Pending Debts
        function fetchPendingDebts(page) {
            if (!page) page = 1;
            $('#pendingDebtsContainer').fadeOut(200, function() {
                $.ajax({
                    url: baseURL + 'actions/get_pending_debts.php',
                    data: {
                        page: page
                    },
                    dataType: 'html',
                    success: function(resp) {
                        $('#pendingDebtsContainer').html(resp).fadeIn(200);
                    },
                    error: function() {
                        $('#pendingDebtsContainer')
                            .html('<p class="text-danger">Failed loading pending debts.</p>')
                            .fadeIn(200);
                    }
                });
            });
        }

        // 2) Upcoming Follow-Ups
        function fetchUpcomingFollowups(page) {
            if (!page) page = 1;
            $('#upcomingFollowupsContainer').fadeOut(200, function() {
                $.ajax({
                    url: baseURL + 'actions/get_upcoming_followups.php',
                    data: {
                        page: page
                    },
                    dataType: 'html',
                    success: function(resp) {
                        $('#upcomingFollowupsContainer').html(resp).fadeIn(200);
                    },
                    error: function() {
                        $('#upcomingFollowupsContainer')
                            .html('<p class="text-danger">Failed loading follow-ups.</p>')
                            .fadeIn(200);
                    }
                });
            });
        }

        // 3) Upcoming Appointments
        function fetchUpcomingAppointments(page) {
            if (!page) page = 1;
            $('#upcomingAppointmentsContainer').fadeOut(200, function() {
                $.ajax({
                    url: baseURL + 'actions/get_upcoming_appointments.php',
                    data: {
                        page: page
                    },
                    dataType: 'html',
                    success: function(resp) {
                        $('#upcomingAppointmentsContainer').html(resp).fadeIn(200);
                    },
                    error: function() {
                        $('#upcomingAppointmentsContainer')
                            .html('<p class="text-danger">Failed loading appointments.</p>')
                            .fadeIn(200);
                    }
                });
            });
        }

        // 4) Diagnosis Follow-Ups
        function fetchDiagnosisFollowups(page) {
            if (!page) page = 1;
            $('#diagnosisFollowupsContainer').fadeOut(200, function() {
                $.ajax({
                    url: baseURL + 'actions/get_diagnosis_followups.php',
                    data: {
                        page: page
                    },
                    dataType: 'html',
                    success: function(resp) {
                        $('#diagnosisFollowupsContainer').html(resp).fadeIn(200);
                    },
                    error: function() {
                        $('#diagnosisFollowupsContainer')
                            .html('<p class="text-danger">Failed loading diagnosis follow-ups.</p>')
                            .fadeIn(200);
                    }
                });
            });
        }

        // 5) Overdue Items
        function fetchOverdueItems(page) {
            if (!page) page = 1;
            $('#overdueContainer').fadeOut(200, function() {
                $.ajax({
                    url: baseURL + 'actions/get_overdue_items.php',
                    data: {
                        page: page
                    },
                    dataType: 'html',
                    success: function(resp) {
                        $('#overdueContainer').html(resp).fadeIn(200);
                    },
                    error: function() {
                        $('#overdueContainer')
                            .html('<p class="text-danger">Failed loading overdue items.</p>')
                            .fadeIn(200);
                    }
                });
            });
        }
    </script>

    <script src="<?php echo $baseURL; ?>assets/js/scripts.js"></script>
</body>

</html>