<?php
// pages/diagnosis/editDiagnosis.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    die("Invalid Diagnosis ID.");
}
$diagnosisID = (int) $_GET['id'];

$stmt = $conn->prepare("SELECT * FROM diagnoses WHERE DiagnosisID = ?");
$stmt->bind_param("i", $diagnosisID);
$stmt->execute();
$result = $stmt->get_result();
if ($result->num_rows < 1) {
    die("Diagnosis record not found.");
}
$record = $result->fetch_assoc();
$stmt->close();
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Edit Diagnosis #<?php echo $diagnosisID; ?></title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Quill Snow Theme CSS -->
    <link href="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.snow.css" rel="stylesheet">
    <!-- highlight.js CSS -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.2.0/styles/default.min.css" rel="stylesheet">
    <style>
        .editor-container {
            height: 200px;
            background: #fff;
        }
    </style>
</head>

<body>
    <div class="container mt-5">
        <h2>Edit Diagnosis #<?php echo $diagnosisID; ?></h2>
        <!-- Tabs -->
        <ul class="nav nav-tabs" id="editTabs" role="tablist">
            <li class="nav-item" role="presentation">
                <button class="nav-link active" id="richText-tab" data-bs-toggle="tab" data-bs-target="#richTextTab" type="button" role="tab" aria-controls="richTextTab" aria-selected="true">Diagnosis</button>
            </li>
            <li class="nav-item" role="presentation">
                <button class="nav-link" id="appt-tab" data-bs-toggle="tab" data-bs-target="#apptTab" type="button" role="tab" aria-controls="apptTab" aria-selected="false">Appointment Details</button>
            </li>
        </ul>
        <form id="editDiagnosisForm" method="POST" action="updateDiagnosis.php">
            <input type="hidden" name="id" value="<?php echo $diagnosisID; ?>">
            <!-- Hidden inputs for rich text fields -->
            <input type="hidden" name="diagnosis" id="hidden_diagnosis">
            <input type="hidden" name="treatment_plan" id="hidden_treatment">
            <input type="hidden" name="prescribed_meds" id="hidden_medication">

            <div class="tab-content mt-3" id="editTabsContent">
                <!-- Tab 1: Rich Text Fields -->
                <div class="tab-pane fade show active" id="richTextTab" role="tabpanel" aria-labelledby="richText-tab">
                    <div class="mb-3">
                        <label class="form-label"><strong>Diagnosis</strong></label>
                        <div id="editor-diagnosis" class="editor-container">
                            <?php echo $record['Diagnosis']; ?>
                        </div>
                    </div>
                    <div class="mb-3">
                        <label class="form-label"><strong>Treatment Plan</strong></label>
                        <div id="editor-treatment" class="editor-container">
                            <?php echo $record['TreatmentPlan']; ?>
                        </div>
                    </div>
                    <div class="mb-3">
                        <label class="form-label"><strong>Prescribed Medication</strong></label>
                        <div id="editor-medication" class="editor-container">
                            <?php echo $record['PrescribedMedication']; ?>
                        </div>
                    </div>
                </div>
                <!-- Tab 2: Appointment & Follow-Up Details -->
                <div class="tab-pane fade" id="apptTab" role="tabpanel" aria-labelledby="appt-tab">
                    <div class="mb-3">
                        <label for="appointment_id" class="form-label">Appointment ID</label>
                        <input type="number" class="form-control" name="appointment_id" id="appointment_id" value="<?php echo htmlspecialchars($record['AppointmentID'] ?? ''); ?>">
                    </div>
                    <div class="mb-3">
                        <label for="followup_date" class="form-label">Follow-Up Date</label>
                        <input type="date" class="form-control" name="followup_date" id="followup_date" value="<?php echo htmlspecialchars($record['FollowUpDate'] ?? ''); ?>">
                    </div>
                    <div class="mb-3">
                        <label for="remarks" class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="remarks" rows="3"><?php echo htmlspecialchars($record['Remarks'] ?? ''); ?></textarea>
                    </div>
                    <div class="form-check mb-2">
                        <input class="form-check-input" type="checkbox" name="create_next_appointment" id="create_next_appointment" value="1">
                        <label class="form-check-label" for="create_next_appointment">
                            Create Next Appointment?
                        </label>
                    </div>
                    <div class="border p-2 mb-2 bg-light">
                        <label class="form-label"><strong>Next Appointment Details</strong></label>
                        <div class="mb-2">
                            <label for="next_appt_date" class="form-label">Date</label>
                            <input type="date" class="form-control" name="next_appt_date" id="next_appt_date">
                        </div>
                        <div class="mb-2">
                            <label for="next_appt_time" class="form-label">Time</label>
                            <input type="time" class="form-control" name="next_appt_time" id="next_appt_time">
                        </div>
                        <div class="mb-2">
                            <label for="next_appt_purpose" class="form-label">Purpose</label>
                            <input type="text" class="form-control" name="next_appt_purpose" id="next_appt_purpose" placeholder="e.g. Follow-up Exam">
                        </div>
                    </div>
                    <div class="form-check mb-2">
                        <input class="form-check-input" type="checkbox" name="mark_current_completed" id="mark_current_completed" value="1">
                        <label class="form-check-label" for="mark_current_completed">
                            Mark Current Appointment as Completed?
                        </label>
                    </div>
                    <div class="mb-3">
                        <label for="next_fu_date" class="form-label">Next Follow-Up Date</label>
                        <input type="date" class="form-control" name="next_fu_date" id="next_fu_date">
                        <small class="text-muted">If set, will create a new Follow-Up referencing the new Appointment (if any).</small>
                    </div>
                </div>
            </div>
            <div class="mt-3">
                <button type="submit" class="btn btn-success">Update Diagnosis</button>
                <a href="diagnosisDetails.php?id=<?php echo $diagnosisID; ?>" class="btn btn-secondary">Cancel</a>
            </div>
        </form>
    </div>

    <!-- Include necessary scripts -->
    <script src="https://cdnjs.cloudflare.com/ajax/libs/highlight.js/11.2.0/highlight.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/quill@2.0.3/dist/quill.js"></script>
    <script src="quill-image-resize-module-patched.js"></script>

    <!-- Custom Image Blot to persist inline styles -->
    <script>
        var Image = Quill.import('formats/image');
        class CustomImage extends Image {
            static create(value) {
                let node = super.create(value);
                if (typeof value === 'object' && value.src) {
                    node.setAttribute('src', value.src);
                    if (value.width) node.style.width = value.width;
                    if (value.height) node.style.height = value.height;
                } else {
                    node.setAttribute('src', value);
                }
                return node;
            }
            static formats(domNode) {
                let formats = super.formats(domNode);
                if (domNode.style.width) formats.width = domNode.style.width;
                if (domNode.style.height) formats.height = domNode.style.height;
                return formats;
            }
            format(name, value) {
                if (name === 'width' || name === 'height') {
                    if (value) this.domNode.style[name] = value;
                    else this.domNode.style[name] = '';
                } else {
                    super.format(name, value);
                }
            }
            formats() {
                let formats = super.formats();
                if (this.domNode.style.width) formats.width = this.domNode.style.width;
                if (this.domNode.style.height) formats.height = this.domNode.style.height;
                return formats;
            }
        }
        Quill.register(CustomImage, true);
    </script>

    <script>
        // Common toolbar options for rich text editors.
        var toolbarOptions = [
            [{
                'font': []
            }],
            [{
                'header': [1, 2, 3, 4, 5, 6, false]
            }],
            ['bold', 'italic', 'underline', 'strike'],
            ['blockquote', 'code-block'],
            [{
                'script': 'sub'
            }, {
                'script': 'super'
            }],
            [{
                'list': 'ordered'
            }, {
                'list': 'bullet'
            }],
            [{
                'indent': '-1'
            }, {
                'indent': '+1'
            }],
            [{
                'direction': 'rtl'
            }],
            [{
                'size': ['small', false, 'large', 'huge']
            }],
            [{
                'color': []
            }, {
                'background': []
            }],
            [{
                'align': []
            }],
            ['link', 'image', 'video'],
            ['clean']
        ];

        // Custom image handler
        function imageHandler() {
            var input = document.createElement('input');
            input.setAttribute('type', 'file');
            input.setAttribute('accept', 'image/*');
            input.click();
            input.onchange = function() {
                var file = input.files[0];
                if (file) {
                    var formData = new FormData();
                    formData.append('image', file);
                    fetch('upload_image.php', {
                            method: 'POST',
                            body: formData
                        })
                        .then(response => response.json())
                        .then(result => {
                            if (result.success) {
                                // Insert into the currently focused editor.
                                // Here we assume that if the Diagnosis editor is active, insert there.
                                var range = quillDiagnosis.getSelection();
                                if (range) {
                                    quillDiagnosis.insertEmbed(range.index, 'image', result.image_url);
                                } else {
                                    quillDiagnosis.insertEmbed(quillDiagnosis.getLength(), 'image', result.image_url);
                                }
                            } else {
                                alert("Image upload failed: " + result.error);
                            }
                        })
                        .catch(error => {
                            console.error('Error:', error);
                            alert("Image upload failed.");
                        });
                }
            };
        }

        // Initialize the three Quill editors.
        var quillDiagnosis = new Quill('#editor-diagnosis', {
            theme: 'snow',
            modules: {
                toolbar: {
                    container: toolbarOptions,
                    handlers: {
                        image: imageHandler
                    }
                },
                syntax: true,
                ImageResize: {}
            }
        });
        var quillTreatment = new Quill('#editor-treatment', {
            theme: 'snow',
            modules: {
                toolbar: {
                    container: toolbarOptions,
                    handlers: {
                        image: imageHandler
                    }
                },
                syntax: true,
                ImageResize: {}
            }
        });
        var quillMedication = new Quill('#editor-medication', {
            theme: 'snow',
            modules: {
                toolbar: {
                    container: toolbarOptions,
                    handlers: {
                        image: imageHandler
                    }
                },
                syntax: true,
                ImageResize: {}
            }
        });

        // On form submission, copy each editor's HTML into the hidden inputs.
        document.getElementById('editDiagnosisForm').addEventListener('submit', function(e) {
            document.getElementById('hidden_diagnosis').value = quillDiagnosis.root.innerHTML;
            document.getElementById('hidden_treatment').value = quillTreatment.root.innerHTML;
            document.getElementById('hidden_medication').value = quillMedication.root.innerHTML;
        });
    </script>
</body>

</html>