<?php
// update_diagnosis.php
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';
$currentUserID = $_SESSION['user_id'] ?? 0;

if (isset($_POST['id']) && isset($_POST['diagnosis'])) {
    $id = intval($_POST['id']);
    $diagnosis = $_POST['diagnosis'];
    $treatment_plan = $_POST['treatment_plan'] ?? '';
    $prescribed_meds = $_POST['prescribed_meds'] ?? '';
    $appointment_id = !empty($_POST['appointment_id']) ? intval($_POST['appointment_id']) : null;
    $remarks = $_POST['remarks'] ?? '';
    $next_fu_date = $_POST['next_fu_date'] ?? '';
    $create_next_appt = isset($_POST['create_next_appointment']) && $_POST['create_next_appointment'] === '1' ? 1 : 0;
    $next_appt_date = $_POST['next_appt_date'] ?? '';
    $next_appt_time = $_POST['next_appt_time'] ?? '';
    $next_appt_purpose = $_POST['next_appt_purpose'] ?? '';
    $mark_current_completed = isset($_POST['mark_current_completed']) && $_POST['mark_current_completed'] === '1' ? 1 : 0;

    // Retrieve the old diagnosis content (for image extraction)
    $stmt = $conn->prepare("SELECT Diagnosis FROM diagnoses WHERE DiagnosisID = ? LIMIT 1");
    $stmt->bind_param("i", $id);
    $stmt->execute();
    $result = $stmt->get_result();
    if ($result->num_rows == 0) {
        echo "Diagnosis record not found.";
        exit;
    }
    $row = $result->fetch_assoc();
    $oldDiagnosis = $row['Diagnosis'];
    $stmt->close();

    function extractImages($content)
    {
        $images = [];
        if (preg_match_all('/<img[^>]+src=["\']([^"\']+)["\']/i', $content, $matches)) {
            $images = $matches[1];
        }
        return $images;
    }
    $oldImages = extractImages($oldDiagnosis);
    $newImages = extractImages($diagnosis);
    $removedImages = array_diff($oldImages, $newImages);
    foreach ($removedImages as $imagePath) {
        if (strpos($imagePath, 'uploads/') === 0 && file_exists($imagePath)) {
            unlink($imagePath);
        }
    }

    // Update the diagnosis record with the new rich text content and remarks
    $upd_sql = "UPDATE diagnoses SET AppointmentID = ?, Diagnosis = ?, TreatmentPlan = ?, PrescribedMedication = ?, Remarks = ?, UpdatedBy = ?, UpdatedAt = NOW() WHERE DiagnosisID = ?";
    $stmt = $conn->prepare($upd_sql);
    $stmt->bind_param("issssii", $appointment_id, $diagnosis, $treatment_plan, $prescribed_meds, $remarks, $currentUserID, $id);
    $stmt->execute();
    $stmt->close();

    // Optionally, create the next appointment if requested
    if ($create_next_appt && $next_appt_date && $next_appt_time) {
        // (Add validation as needed)
        $patientID = 0; // Adjust if you have the patient ID available.
        $app_sql = "INSERT INTO appointments (PatientID, AppointmentDate, AppointmentTime, Purpose, Status, Remarks, CreatedBy, UpdatedBy, CreatedAt, UpdatedAt) VALUES (?, ?, ?, ?, ?, ?, ?, ?, NOW(), NOW())";
        $stmtA = $conn->prepare($app_sql);
        $status = "Scheduled";
        $autoRemarks = "Auto-created from Diagnosis update (Next Appt)";
        $stmtA->bind_param("isssssii", $patientID, $next_appt_date, $next_appt_time, $next_appt_purpose, $status, $autoRemarks, $currentUserID, $currentUserID);
        $stmtA->execute();
        $newAppointmentID = $stmtA->insert_id;
        $stmtA->close();
    }

    // Optionally, mark the current appointment as completed if requested
    if ($mark_current_completed && $appointment_id) {
        $comp_sql = "UPDATE appointments SET Status = 'Completed', UpdatedBy = ?, UpdatedAt = NOW() WHERE AppointmentID = ?";
        $stmtComp = $conn->prepare($comp_sql);
        $stmtComp->bind_param("ii", $currentUserID, $appointment_id);
        $stmtComp->execute();
        $stmtComp->close();
    }

    echo "Diagnosis updated successfully.";
} else {
    echo "Invalid request.";
}

$conn->close();
