<?php
// includes/header.php
include '../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");
?>
<!DOCTYPE html>
<html lang="en">
<head>
  <meta charset="UTF-8">
  <title>Doctor's Patient Flow</title>
  <!-- Bootstrap 5 -->
  <link 
    href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" 
    rel="stylesheet"
  />
  <!-- FontAwesome (for icons) -->
  <link 
    href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" 
    rel="stylesheet"
  />
  <!-- Optional: FullCalendar or other libraries for timeline, etc. -->
  <style>
    /* Basic custom styling for layout/timeline, etc. */
    body { background-color: #f2f2f2; }
    #sidebar {
      background: #fff;
      min-height: 100vh;
      border-right: 1px solid #ccc;
    }
    .sidebar-heading { font-weight: 600; margin-top: 1rem; }
    .timeline-container {
      margin: 1rem 0;
      padding-left: 2rem;
      border-left: 2px solid #0d6efd;
    }
    .timeline-item {
      position: relative;
      margin-bottom: 1.5rem;
    }
    .timeline-item::before {
      content: "";
      position: absolute;
      left: -10px;
      width: 20px;
      height: 20px;
      background: #0d6efd;
      border-radius: 50%;
      top: 0;
    }
  </style>
</head>
<body>
<div class="container-fluid">
  <div class="row">
    <!-- SIDEBAR -->
    <div class="col-md-3 col-lg-2" id="sidebar">
      <div class="p-3">
        <h5 class="sidebar-heading">Quick Actions</h5>
        <button class="btn btn-sm btn-primary w-100 mb-2" onclick="showAddAppointment()">
          <i class="fas fa-calendar-plus"></i> Add Appointment
        </button>
        <button class="btn btn-sm btn-success w-100 mb-2" onclick="showAddFollowUp()">
          <i class="fas fa-phone"></i> Add Follow-Up
        </button>
        <button class="btn btn-sm btn-warning w-100 mb-2">
          <i class="fas fa-stethoscope"></i> Add Diagnosis
        </button>
        <button class="btn btn-sm btn-info w-100 mb-2 text-white">
          <i class="fas fa-file-upload"></i> Upload Report
        </button>

        <h5 class="sidebar-heading">Health Overview</h5>
        <div class="bg-light p-2 rounded mb-3">
          <!-- Example vitals info -->
          <p class="mb-1"><strong>BP:</strong> 120/80 mmHg</p>
          <p class="mb-1"><strong>Weight:</strong> 70 kg</p>
          <p class="mb-1"><strong>Glucose:</strong> 95 mg/dL</p>
        </div>

        <h5 class="sidebar-heading">Upcoming Events</h5>
        <div class="bg-light p-2 rounded">
          <ul class="list-group list-group-flush small" id="upcomingEvents">
            <!-- We'll load from AJAX or fill manually -->
            <li class="list-group-item">Loading...</li>
          </ul>
        </div>
      </div>
    </div>
    <!-- END SIDEBAR -->

    <!-- MAIN CONTENT -->
    <div class="col-md-9 col-lg-10">
      <!-- Patient Header -->
      <div class="card mt-3 mb-3 shadow-sm">
        <div class="card-body d-flex align-items-center justify-content-between">
          <div class="d-flex align-items-center">
            <img 
              src="https://via.placeholder.com/60" 
              class="rounded-circle me-3" 
              alt="Profile"
            />
            <div>
              <h5 class="mb-0" id="patientName">John Doe, Age 45</h5>
              <small class="text-muted" id="patientInfo">Male | +1 555-1234</small>
            </div>
          </div>
          <div>
            <button class="btn btn-secondary btn-sm">
              <i class="fas fa-user-edit"></i> Edit Patient
            </button>
          </div>
        </div>
      </div>
      <!-- End Patient Header -->

      <!-- NAV TABS -->
      <ul class="nav nav-tabs" id="flowTabs" role="tablist">
        <li class="nav-item">
          <button class="nav-link active" 
            id="overview-tab"
            data-bs-toggle="tab"
            data-bs-target="#overview"
            role="tab"
            aria-controls="overview"
            aria-selected="true">
            Overview
          </button>
        </li>
        <li class="nav-item">
          <button class="nav-link"
            id="appointments-tab"
            data-bs-toggle="tab"
            data-bs-target="#appointments"
            role="tab"
            aria-controls="appointments"
            aria-selected="false">
            Appointments
          </button>
        </li>
        <li class="nav-item">
          <button class="nav-link"
            id="followups-tab"
            data-bs-toggle="tab"
            data-bs-target="#followups"
            role="tab"
            aria-controls="followups"
            aria-selected="false">
            Follow-Ups
          </button>
        </li>
        <li class="nav-item">
          <button class="nav-link"
            id="diagnosis-tab"
            data-bs-toggle="tab"
            data-bs-target="#diagnosis"
            role="tab"
            aria-controls="diagnosis"
            aria-selected="false">
            Diagnosis
          </button>
        </li>
        <li class="nav-item">
          <button class="nav-link"
            id="reports-tab"
            data-bs-toggle="tab"
            data-bs-target="#reports"
            role="tab"
            aria-controls="reports"
            aria-selected="false">
            Reports
          </button>
        </li>
      </ul>

      <!-- TAB CONTENT -->
      <div class="tab-content p-3 bg-white border border-top-0 rounded-bottom" id="flowTabsContent">
        
        <!-- OVERVIEW TAB -->
        <div class="tab-pane fade show active" 
             id="overview" 
             role="tabpanel" 
             aria-labelledby="overview-tab">
          <h5 class="mb-3"><i class="fas fa-stream me-1"></i> Patient Timeline</h5>
          <div class="timeline-container" id="overviewTimeline">
            <!-- We'll load from AJAX -->
            <p class="text-muted">Loading timeline...</p>
          </div>
        </div>

        <!-- APPOINTMENTS TAB -->
        <div class="tab-pane fade" 
             id="appointments" 
             role="tabpanel" 
             aria-labelledby="appointments-tab">
          <h5 class="mb-3"><i class="fas fa-calendar-alt me-1"></i> Appointments</h5>
          <table class="table table-bordered table-striped" id="appointmentsTable">
            <thead class="table-light">
              <tr>
                <th>ID</th>
                <th>Date</th>
                <th>Time</th>
                <th>Purpose</th>
                <th>Status</th>
                <th>Remarks</th>
              </tr>
            </thead>
            <tbody>
              <tr><td colspan="6">Loading appointments...</td></tr>
            </tbody>
          </table>
        </div>

        <!-- FOLLOW-UPS TAB -->
        <div class="tab-pane fade" 
             id="followups" 
             role="tabpanel" 
             aria-labelledby="followups-tab">
          <h5 class="mb-3"><i class="fas fa-phone me-1"></i> Follow-Ups</h5>
          <table class="table table-bordered table-striped" id="followupsTable">
            <thead class="table-light">
              <tr>
                <th>ID</th>
                <th>Follow-Up Date</th>
                <th>Type</th>
                <th>Status Update</th>
                <th>Next Follow-Up</th>
                <th>Remarks</th>
              </tr>
            </thead>
            <tbody>
              <tr><td colspan="6">Loading follow-ups...</td></tr>
            </tbody>
          </table>
        </div>

        <!-- DIAGNOSIS TAB -->
        <div class="tab-pane fade"
             id="diagnosis" 
             role="tabpanel" 
             aria-labelledby="diagnosis-tab">
          <h5 class="mb-3"><i class="fas fa-notes-medical me-1"></i> Diagnosis</h5>
          <div id="diagnosisContainer">
            <!-- We'll load from AJAX, maybe in card format -->
            <p class="text-muted">Loading diagnoses...</p>
          </div>
        </div>

        <!-- REPORTS TAB -->
        <div class="tab-pane fade"
             id="reports"
             role="tabpanel"
             aria-labelledby="reports-tab">
          <h5 class="mb-3"><i class="fas fa-file-medical me-1"></i> Reports</h5>
          <div id="reportsGrid" class="row">
            <p class="text-muted">Loading reports...</p>
          </div>
        </div>
      </div>
      <!-- END TAB CONTENT -->

    </div> <!-- end col for main content -->
  </div> <!-- end row -->
</div> <!-- end container-fluid -->


<!-- Optional: Appointment / FollowUp modals, etc. -->
<!-- For brevity, we won't show them again if you already have them. -->

<!-- JS Scripts -->
<script 
  src="https://code.jquery.com/jquery-3.6.0.min.js">
</script>
<script 
  src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js">
</script>

<script>
const patientId = 123; // For example, or from PHP:  let patientId = <?php echo $patient_id; ?>;

// On document ready:
$(function() {
  // Load data for each tab by default or on tab show
  loadTimeline();
  loadAppointments();
  loadFollowUps();
  loadDiagnosis();
  loadReports();

  // Could also attach event listeners for tab switching
});

// Example: load timeline
function loadTimeline() {
  $.ajax({
    url: 'apiPatientFlow.php',
    method: 'GET',
    data: { 
      method: 'getTimeline',
      patient_id: patientId
    },
    dataType: 'json',
    success: function(resp) {
      if (resp.success) {
        let timelineHtml = '';
        resp.data.forEach(item => {
          timelineHtml += `
            <div class="timeline-item">
              <h6>${item.date} - ${item.title}</h6>
              <p class="text-muted small">${item.details}</p>
            </div>
          `;
        });
        $('#overviewTimeline').html(timelineHtml);
      } else {
        $('#overviewTimeline').html('<p class="text-danger">Failed to load timeline.</p>');
      }
    },
    error: function() {
      $('#overviewTimeline').html('<p class="text-danger">Error fetching timeline.</p>');
    }
  });
}

// loadAppointments
function loadAppointments() {
  $.ajax({
    url: 'apiPatientFlow.php',
    method: 'GET',
    data: { 
      method: 'getAppointments',
      patient_id: patientId
    },
    dataType: 'json',
    success: function(resp) {
      if (resp.success) {
        let rows = '';
        resp.data.forEach(appt => {
          rows += `
            <tr>
              <td>${appt.AppointmentID}</td>
              <td>${appt.AppointmentDate}</td>
              <td>${appt.AppointmentTime}</td>
              <td>${appt.Purpose}</td>
              <td>${appt.Status}</td>
              <td>${appt.Remarks}</td>
            </tr>
          `;
        });
        $('#appointmentsTable tbody').html(rows);
      } else {
        $('#appointmentsTable tbody').html('<tr><td colspan="6">No appointments found.</td></tr>');
      }
    },
    error: function() {
      $('#appointmentsTable tbody').html('<tr><td colspan="6">Error loading appointments.</td></tr>');
    }
  });
}

// loadFollowUps
function loadFollowUps() {
  $.ajax({
    url: 'apiPatientFlow.php',
    method: 'GET',
    data: {
      method: 'getFollowUps',
      patient_id: patientId
    },
    dataType: 'json',
    success: function(resp) {
      if (resp.success) {
        let rows = '';
        resp.data.forEach(fu => {
          rows += `
            <tr>
              <td>${fu.FollowUpID}</td>
              <td>${fu.FollowUpDate}</td>
              <td>${fu.FollowUpType}</td>
              <td>${fu.StatusUpdate}</td>
              <td>${fu.NextFollowUpDate || '-'}</td>
              <td>${fu.Remarks || ''}</td>
            </tr>
          `;
        });
        $('#followupsTable tbody').html(rows);
      } else {
        $('#followupsTable tbody').html('<tr><td colspan="6">No follow-ups found.</td></tr>');
      }
    },
    error: function() {
      $('#followupsTable tbody').html('<tr><td colspan="6">Error loading follow-ups.</td></tr>');
    }
  });
}

// loadDiagnosis
function loadDiagnosis() {
  $.ajax({
    url: 'apiPatientFlow.php',
    method: 'GET',
    data: {
      method: 'getDiagnosis',
      patient_id: patientId
    },
    dataType: 'json',
    success: function(resp) {
      if (resp.success) {
        let html = '';
        resp.data.forEach(dx => {
          html += `
            <div class="border rounded p-2 mb-3">
              <h6>${dx.DiagnosisDate}: ${dx.Diagnosis}</h6>
              <p><strong>Treatment Plan:</strong> ${dx.TreatmentPlan}</p>
              <p><strong>Meds:</strong> ${dx.PrescribedMedication}</p>
              <p><strong>FollowUpDate:</strong> ${dx.FollowUpDate || '-'}</p>
            </div>
          `;
        });
        $('#diagnosisContainer').html(html);
      } else {
        $('#diagnosisContainer').html('<p class="text-muted">No diagnoses found.</p>');
      }
    },
    error: function() {
      $('#diagnosisContainer').html('<p class="text-danger">Error loading diagnoses.</p>');
    }
  });
}

// loadReports
function loadReports() {
  $.ajax({
    url: 'apiPatientFlow.php',
    method: 'GET',
    data: {
      method: 'getReports',
      patient_id: patientId
    },
    dataType: 'json',
    success: function(resp) {
      if (resp.success) {
        let html = '';
        resp.data.forEach(rp => {
          html += `
            <div class="col-md-4">
              <div class="border p-2 mb-2 bg-white">
                <h6>${rp.ReportType} - ${rp.ReportDate}</h6>
                <p class="small text-muted">${rp.Remarks || ''}</p>
                <button class="btn btn-sm btn-success me-2">
                  <i class="fas fa-download"></i> View
                </button>
                <button class="btn btn-sm btn-danger">
                  <i class="fas fa-trash"></i>
                </button>
              </div>
            </div>
          `;
        });
        $('#reportsGrid').html(html);
      } else {
        $('#reportsGrid').html('<p class="text-muted">No reports found.</p>');
      }
    },
    error: function() {
      $('#reportsGrid').html('<p class="text-danger">Error loading reports.</p>');
    }
  });
}

// Below are example placeholders for "Add" modals or actions
function showAddAppointment() {
  alert("Show add appointment modal here...");
}
function showAddFollowUp() {
  alert("Show add follow-up modal here...");
}
</script>
</body>
</html>
