<?php
// pages/msr/msr.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

$userRole = $_SESSION['role'] ?? 'staff';
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>MSR | Agasthiar</title>
    <!-- Bootstrap + FontAwesome -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <!-- Custom CSS if needed -->
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>
            <div class="container-fluid mt-4">
                <!-- Header Card -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">Agasthiar Siddha Ayurmed Sdn. Bhd</h4>
                        <p class="mb-0">Medicine Sold Report (Create New MSR)</p>
                    </div>
                </div>
                <!-- Row: Date, Day, MSR Number -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-4">
                                <label for="reportDate" class="form-label">Date</label>
                                <!-- staff => locked to “today”; admin => can pick any date up to today -->
                                <input type="date" class="form-control" id="reportDate">
                            </div>
                            <div class="col-md-4">
                                <label for="reportDay" class="form-label">Day</label>
                                <input type="text" class="form-control" id="reportDay" readonly>
                            </div>
                            <div class="col-md-4">
                                <label for="msrNumber" class="form-label">MSR Number</label>
                                <input type="text" class="form-control bg-light" id="msrNumber" readonly>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- Hidden user role -->
                <input type="hidden" id="userRole" value="<?php echo htmlspecialchars($userRole); ?>">
                <!-- TABLE: MSR Rows -->
                <div class="card shadow border-0">
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered text-center align-middle">
                                <thead class="table-light">
                                    <tr>
                                        <th style="width:4%;">No</th>
                                        <th style="width:20%;">Name</th>
                                        <th style="width:10%;">Reference</th>
                                        <th style="width:30%;">Medicines/Notes</th>
                                        <th style="width:20%;">Treatments/Amount</th>
                                        <th style="width:10%;">Discount (RM)</th>
                                        <th style="width:10%;">Balance (RM)</th>
                                        <th style="width:10%;">Actions</th>
                                    </tr>
                                </thead>
                                <tbody id="medicalTable">
                                    <!-- Populated by msr.js -->
                                </tbody>
                            </table>
                        </div>
                        <div class="text-center mt-3">
                            <button id="addRow" class="btn btn-primary btn-sm">
                                <i class="fas fa-plus-circle me-1"></i> Add Row
                            </button>
                        </div>
                    </div>
                </div>
                <div class="text-center mt-4">
                    <button id="submitMSR" class="btn btn-success btn-lg rounded-pill px-4">
                        <i class="fas fa-check-circle me-1"></i> Submit MSR
                    </button>
                </div>
            </div>
        </div>
    </div>

    <!-- Modal: Choose Patient -->
    <div class="modal fade" id="patientModal" tabindex="-1" aria-labelledby="patientModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title">Choose Patient</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Search fields -->
                    <div class="row g-2 mb-3">
                        <div class="col-md-6">
                            <label for="searchName" class="form-label">Search by Name</label>
                            <input type="text" id="searchName" class="form-control" placeholder="Enter name">
                        </div>
                        <div class="col-md-6">
                            <label for="searchIC" class="form-label">Search by IC</label>
                            <input type="text" id="searchIC" class="form-control" placeholder="Enter IC">
                        </div>
                    </div>
                    <button id="searchPatientBtn" class="btn btn-sm btn-info mb-3">Search</button>
                    <div id="patientResults"></div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                </div>
            </div>
        </div>
    </div>


    <script>
        const baseURL = "<?php echo $baseURL; ?>";
    </script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="<?php echo $baseURL; ?>assets/js/msr.js"></script>
    <script src="<?php echo $baseURL; ?>assets/js/scripts.js"></script>
    <?php include ROOT_PATH . 'includes/footer.php'; ?>
</body>

</html>