<?php
// pages/msr/msrList.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

$user_role  = $_SESSION['role'] ?? 'staff';

// (A) FILTERS
$start_date = $_GET['start_date'] ?? '';
$end_date   = $_GET['end_date']   ?? '';
$date_filter = '';
if (
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $start_date) &&
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $end_date)
) {
    $date_filter = "WHERE DATE(msr.created_at) BETWEEN '$start_date' AND '$end_date'";
}

// (B) SORTING FOR DATE
// We add a param "sort_date" which can be "asc" or "desc"
$sort_date = $_GET['sort_date'] ?? 'desc';
$sort_date = ($sort_date === 'asc') ? 'asc' : 'desc'; // default 'desc' if invalid

// (C) PAGINATION
$records_per_page = 10;
$current_pg       = isset($_GET['pg']) ? max(1, (int)$_GET['pg']) : 1;
$offset           = ($current_pg - 1) * $records_per_page;

// (D) COUNT
$count_sql = "SELECT COUNT(msr.id) AS total FROM msr $date_filter";
$count_res = $conn->query($count_sql);
$total_msrs = $count_res->fetch_assoc()['total'] ?? 0;
$total_pages = max(1, ceil($total_msrs / $records_per_page));

// (E) MAIN QUERY
$sql = "
    SELECT 
        msr.*,
        users.first_name AS creator_first_name,
        users.last_name  AS creator_last_name,
        approver.first_name AS approver_first_name,
        approver.last_name  AS approver_last_name
    FROM msr
    JOIN users ON msr.user_id = users.id
    LEFT JOIN users AS approver ON msr.approved_by = approver.id
    $date_filter
    ORDER BY msr.date_of_msr $sort_date
    LIMIT $records_per_page OFFSET $offset
";
$result = $conn->query($sql);
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>MSR List</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">MSR List</h4>
                    </div>
                </div>

                <!-- (1) Filter Form -->
                <form class="row g-3 mb-3">
                    <div class="col-md-4">
                        <label class="form-label">Start Date</label>
                        <input type="date" class="form-control" name="start_date"
                            value="<?php echo htmlspecialchars($start_date); ?>">
                    </div>
                    <div class="col-md-4">
                        <label class="form-label">End Date</label>
                        <input type="date" class="form-control" name="end_date"
                            value="<?php echo htmlspecialchars($end_date); ?>">
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <button class="btn btn-primary w-100">
                            <i class="fas fa-filter"></i> Filter
                        </button>
                    </div>
                    <div class="col-md-2 d-flex align-items-end">
                        <a class="btn btn-secondary w-100" href="?page=msrList">
                            <i class="fas fa-times"></i> Clear
                        </a>
                    </div>
                    <!-- We'll keep the current sort_date in a hidden field so it stays across filtering -->
                    <input type="hidden" name="sort_date" value="<?php echo htmlspecialchars($sort_date); ?>">
                </form>

                <!-- (2) "Add Holiday" button (admin only) -->
                <?php if ($user_role === 'admin'): ?>
                    <button class="btn btn-danger mb-3" data-bs-toggle="modal" data-bs-target="#addHolidayModal">
                        <i class="fas fa-calendar-day me-1"></i> Add Holiday
                    </button>
                <?php endif; ?>

                <!-- (3) MSR Table -->
                <div class="table-responsive">
                    <table class="table table-bordered text-center align-middle">
                        <thead class="table-light">
                            <tr>
                                <th>MSR/Holiday</th>
                                <th>
                                    Date
                                    <?php
                                    // We build a toggle link: if current is asc => next is desc, else asc
                                    $toggleSort = ($sort_date === 'asc') ? 'desc' : 'asc';
                                    // We'll keep the existing filters, just change sort_date and reset page=1
                                    $queryParams = [
                                        'page' => 'msrList',
                                        'sort_date' => $toggleSort,
                                        'start_date' => $start_date,
                                        'end_date' => $end_date,
                                        'pg' => 1
                                    ];
                                    $toggleUrl = '?' . http_build_query($queryParams);
                                    ?>
                                    <a href="<?php echo $toggleUrl; ?>" class="btn btn-sm btn-outline-secondary ms-1">
                                        <i class="fas fa-sort"></i> <?php echo strtoupper($toggleSort); ?>
                                    </a>
                                </th>
                                <th>Status</th>
                                <th>Created By</th>
                                <th>Approved By</th>
                                <th>Actions</th>
                            </tr>
                        </thead>
                        <tbody>
                            <?php if ($result && $result->num_rows > 0): ?>
                                <?php while ($msr = $result->fetch_assoc()):
                                    $isHoliday = ($msr['holiday'] == 1);
                                    $rowClass  = $isHoliday ? 'table-warning' : '';
                                ?>
                                    <tr class="<?php echo $rowClass; ?>">
                                        <td>
                                            <?php if ($isHoliday): ?>
                                                <span class="fw-bold text-danger">Holiday</span><br />
                                                <small>(<?php echo htmlspecialchars($msr['msr_number']); ?>)</small>
                                                <div class="text-muted mt-1">
                                                    <?php echo nl2br(htmlspecialchars($msr['remarks'] ?? '')); ?>
                                                </div>
                                            <?php else: ?>
                                                <?php echo htmlspecialchars($msr['msr_number']); ?>
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo date('d M Y', strtotime($msr['date_of_msr'])); ?></td>
                                        <td>
                                            <?php if ($isHoliday): ?>
                                                <span class="badge bg-info">Holiday</span>
                                            <?php else: ?>
                                                <?php if ($msr['approved'] == 1): ?>
                                                    <span class="badge bg-success">Approved</span>
                                                <?php else: ?>
                                                    <span class="badge bg-warning">Pending</span>
                                                <?php endif; ?>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php
                                            echo htmlspecialchars(
                                                $msr['creator_first_name'] . ' ' . $msr['creator_last_name']
                                            );
                                            ?>
                                        </td>
                                        <td>
                                            <?php if (!$isHoliday && $msr['approved'] == 1 && $msr['approver_first_name']): ?>
                                                <?php echo htmlspecialchars($msr['approver_first_name'] . ' ' . $msr['approver_last_name']); ?>
                                            <?php else: ?>
                                                -
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if ($isHoliday): ?>
                                                <?php if ($user_role === 'admin'): ?>
                                                    <button class="btn btn-sm btn-warning"
                                                        onclick="openEditHoliday(<?php echo (int)$msr['id']; ?>)">
                                                        <i class="fas fa-edit"></i> Edit
                                                    </button>
                                                    <button class="btn btn-sm btn-danger ms-1"
                                                        onclick="deleteHoliday(<?php echo (int)$msr['id']; ?>)">
                                                        <i class="fas fa-trash"></i> Delete
                                                    </button>
                                                <?php endif; ?>
                                            <?php else: ?>
                                                <a class="btn btn-sm btn-primary"
                                                    href="<?php echo $baseURL; ?>pages/msr/viewMsr.php?id=<?php echo (int)$msr['id']; ?>">
                                                    <i class="fas fa-eye"></i> View
                                                </a>
                                                <?php if ($user_role === 'admin' && $msr['approved'] == 0): ?>
                                                    <a class="btn btn-sm btn-success ms-1"
                                                        href="?page=approveMsr&id=<?php echo (int)$msr['id']; ?>"
                                                        onclick="return confirm('Approve MSR?');">
                                                        <i class="fas fa-check"></i> Approve
                                                    </a>
                                                <?php endif; ?>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endwhile; ?>
                            <?php else: ?>
                                <tr>
                                    <td colspan="6" class="text-muted">No MSRs found.</td>
                                </tr>
                            <?php endif; ?>
                        </tbody>
                    </table>
                </div><!-- end table-responsive -->

                <!-- (4) PAGINATION -->
                <?php if ($total_pages > 1): ?>
                    <nav class="mt-3">
                        <ul class="pagination justify-content-center flex-wrap">
                            <!-- FIRST -->
                            <?php if ($current_pg > 1): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?page=msrList&sort_date=<?php echo urlencode($sort_date); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>&pg=1">
                                        <i class="fas fa-angle-double-left"></i> First
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled">
                                    <span class="page-link"><i class="fas fa-angle-double-left"></i> First</span>
                                </li>
                            <?php endif; ?>

                            <!-- PREV -->
                            <?php if ($current_pg > 1): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?page=msrList&sort_date=<?php echo urlencode($sort_date); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>&pg=<?php echo ($current_pg - 1); ?>">
                                        &laquo; Prev
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                            <?php endif; ?>

                            <!-- PAGE NUMBERS -->
                            <?php for ($p = 1; $p <= $total_pages; $p++): ?>
                                <?php $active = ($p == $current_pg) ? 'active' : ''; ?>
                                <li class="page-item <?php echo $active; ?>">
                                    <a class="page-link"
                                        href="?page=msrList&sort_date=<?php echo urlencode($sort_date); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>&pg=<?php echo $p; ?>">
                                        <?php echo $p; ?>
                                    </a>
                                </li>
                            <?php endfor; ?>

                            <!-- NEXT -->
                            <?php if ($current_pg < $total_pages): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?page=msrList&sort_date=<?php echo urlencode($sort_date); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>&pg=<?php echo ($current_pg + 1); ?>">
                                        Next &raquo;
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                            <?php endif; ?>

                            <!-- LAST -->
                            <?php if ($current_pg < $total_pages): ?>
                                <li class="page-item">
                                    <a class="page-link"
                                        href="?page=msrList&sort_date=<?php echo urlencode($sort_date); ?>&start_date=<?php echo urlencode($start_date); ?>&end_date=<?php echo urlencode($end_date); ?>&pg=<?php echo $total_pages; ?>">
                                        Last <i class="fas fa-angle-double-right"></i>
                                    </a>
                                </li>
                            <?php else: ?>
                                <li class="page-item disabled">
                                    <span class="page-link">Last <i class="fas fa-angle-double-right"></i></span>
                                </li>
                            <?php endif; ?>
                        </ul>
                    </nav>
                <?php endif; ?>
            </div><!-- end container-fluid -->
        </div><!-- end page-content-wrapper -->
    </div><!-- end #wrapper -->

    <!-- (5) ADD HOLIDAY MODAL -->
    <div class="modal fade" id="addHolidayModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" id="addHolidayForm">
                <div class="modal-header">
                    <h5 class="modal-title">Add Holiday</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div id="holidayAlert" class="alert alert-danger d-none"></div>
                    <div class="mb-3">
                        <label class="form-label">Date of Holiday</label>
                        <input type="date" class="form-control" name="holiday_date" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="holiday_remarks" rows="3"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button class="btn btn-primary">Save Holiday</button>
                </div>
            </form>
        </div>
    </div>

    <!-- EDIT HOLIDAY MODAL (IF YOU ALLOW EDITING) -->
    <div class="modal fade" id="editHolidayModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" id="editHolidayForm">
                <div class="modal-header">
                    <h5 class="modal-title">Edit Holiday</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div id="editHolidayAlert" class="alert alert-danger d-none"></div>
                    <input type="hidden" name="holiday_id" id="holiday_id">
                    <div class="mb-3">
                        <label class="form-label">Holiday Date</label>
                        <input type="date" class="form-control" name="holiday_date" id="holiday_date_edit" required>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="holiday_remarks" id="holiday_remarks_edit" rows="3"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button class="btn btn-secondary" data-bs-dismiss="modal">Cancel</button>
                    <button class="btn btn-primary">Save Changes</button>
                </div>
            </form>
        </div>
    </div>

    <script>
        const baseURL = "<?php echo $baseURL; ?>";
    </script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

    <script>
        // (A) ADD HOLIDAY
        document.getElementById('addHolidayForm').addEventListener('submit', function(e) {
            e.preventDefault();
            let fd = new FormData(this);
            let payload = {
                holiday: 1,
                msr_date: fd.get('holiday_date'),
                remarks: fd.get('holiday_remarks') || '',
                rows: []
            };
            fetch(baseURL + 'actions/msr/save_msr.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(payload)
                })
                .then(r => r.json())
                .then(resp => {
                    if (!resp.success) {
                        let al = document.getElementById('holidayAlert');
                        al.textContent = resp.message;
                        al.classList.remove('d-none');
                    } else {
                        alert(resp.message);
                        location.reload();
                    }
                })
                .catch(err => console.error('AddHoliday error', err));
        });

        // (B) EDIT HOLIDAY
        function openEditHoliday(msrID) {
            fetch(baseURL + 'actions/msr/update_holiday.php?fetch=1&id=' + msrID)
                .then(r => r.json())
                .then(resp => {
                    if (!resp.success) {
                        alert(resp.message);
                        return;
                    }
                    document.getElementById('holiday_id').value = resp.data.id;
                    document.getElementById('holiday_date_edit').value = resp.data.date_of_msr;
                    document.getElementById('holiday_remarks_edit').value = resp.data.remarks;
                    let mod = new bootstrap.Modal(document.getElementById('editHolidayModal'));
                    mod.show();
                })
                .catch(err => console.error('openEditHoliday error', err));
        }

        document.getElementById('editHolidayForm').addEventListener('submit', function(e) {
            e.preventDefault();
            let fd = new FormData(this);
            let payload = {
                id: fd.get('holiday_id'),
                date_of_msr: fd.get('holiday_date'),
                remarks: fd.get('holiday_remarks')
            };
            fetch(baseURL + 'actions/msr/update_holiday.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(payload)
                })
                .then(r => r.json())
                .then(resp => {
                    if (!resp.success) {
                        let al = document.getElementById('editHolidayAlert');
                        al.textContent = resp.message;
                        al.classList.remove('d-none');
                    } else {
                        alert(resp.message);
                        location.reload();
                    }
                })
                .catch(err => console.error('editHoliday error', err));
        });

        // (C) DELETE HOLIDAY
        function deleteHoliday(msrID) {
            if (!confirm('Are you sure you want to delete this holiday?')) return;
            fetch(baseURL + 'actions/msr/delete_holiday.php?id=' + msrID)
                .then(r => r.json())
                .then(resp => {
                    if (!resp.success) {
                        alert(resp.message);
                    } else {
                        alert(resp.message);
                        location.reload();
                    }
                })
                .catch(err => console.error('deleteHoliday error', err));
        }
    </script>

    <script src="<?php echo $baseURL; ?>assets/js/scripts.js"></script>
</body>

</html>