<?php
// pages/msr/updateMsr.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// Validate MSR ID
if (!isset($_GET['id']) || !is_numeric($_GET['id'])) {
    echo "<script>alert('No valid MSR ID.'); window.location.href='msrList.php';</script>";
    exit;
}
$msr_id = (int)$_GET['id'];

// Fetch MSR header
$stmt = $conn->prepare("
    SELECT
      m.id AS msr_id,
      m.msr_number,
      m.date_of_msr,
      m.created_at,
      m.approved,
      m.user_id,
      u.first_name AS creator_first_name,
      u.last_name AS creator_last_name
    FROM msr m
    JOIN users u ON m.user_id = u.id
    WHERE m.id = ?
    LIMIT 1
");
$stmt->bind_param("i", $msr_id);
$stmt->execute();
$res = $stmt->get_result();
if ($res->num_rows === 0) {
    echo "<script>alert('MSR not found.'); window.location.href='msrList.php';</script>";
    exit;
}
$msrRow = $res->fetch_assoc();
$stmt->close();

$msrDate = $msrRow['date_of_msr'] ?? date('Y-m-d');

// Fetch msr_patients (and optional debts info) – no Prev Debt column included.
$sql = "
SELECT
   mp.id AS msr_patient_id,
   mp.patient_id,
   CONCAT(p.first_name, ' ', p.last_name) AS patient_name,
   mp.reference,
   mp.medicines,
   mp.treatments,
   IFNULL(d.payment_type, 'Cash') AS payment_type,
   IFNULL(d.discount, 0) AS discount,
   0 AS total_paid,
   IFNULL(d.balance_after_payment, 0) AS balance
FROM msr_patients mp
JOIN patients p ON p.id = mp.patient_id
LEFT JOIN debts d ON d.msr_id = mp.msr_id AND d.patient_id = mp.patient_id
WHERE mp.msr_id = ?
ORDER BY mp.id ASC
";
$stmt2 = $conn->prepare($sql);
$stmt2->bind_param("i", $msr_id);
$stmt2->execute();
$res2 = $stmt2->get_result();

$msrData = [];
while ($row = $res2->fetch_assoc()) {
    $msrData[] = [
        'msr_id'         => (int)$msrRow['msr_id'],
        'msr_number'     => $msrRow['msr_number'],
        'date_of_msr'    => $msrRow['date_of_msr'],
        'created_at'     => $msrRow['created_at'],
        'msr_patient_id' => (int)$row['msr_patient_id'],
        'patient_id'     => (int)$row['patient_id'],
        'patient_name'   => $row['patient_name'] ?? '',
        'reference'      => $row['reference'] ?? '',
        'medicines'      => $row['medicines'] ?? '',
        'treatments'     => $row['treatments'] ?? '[]',
        'payment_type'   => $row['payment_type'] ?? 'Cash',
        'discount'       => (float)$row['discount'],
        'total_paid'     => 0,
        'balance'        => (float)$row['balance']
    ];
}
$stmt2->close();
$conn->close();
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Update MSR</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>
            <div class="container-fluid mt-4">
                <!-- Header Card -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body text-center bg-primary text-white rounded">
                        <h4 class="card-title mb-1">Update Medicine Sold Report (MSR)</h4>
                    </div>
                </div>
                <!-- MSR Info -->
                <div class="card mb-4 shadow border-0">
                    <div class="card-body">
                        <div class="row g-3">
                            <div class="col-md-4">
                                <label for="reportDate" class="form-label">Date</label>
                                <input type="date" class="form-control" id="reportDate">
                            </div>
                            <div class="col-md-4">
                                <label for="reportDay" class="form-label">Day</label>
                                <input type="text" class="form-control" id="reportDay" readonly>
                            </div>
                            <div class="col-md-4">
                                <label for="msrNumber" class="form-label">MSR Number</label>
                                <input type="text" class="form-control bg-light" id="msrNumber" readonly>
                            </div>
                        </div>
                    </div>
                </div>
                <!-- Editable MSR Table (No Prev Debt Column) -->
                <div class="card shadow border-0">
                    <div class="card-body">
                        <div class="table-responsive">
                            <table class="table table-bordered text-center align-middle">
                                <thead class="table-light">
                                    <tr>
                                        <th style="width:4%;">No</th>
                                        <th style="width:20%;">Name</th>
                                        <th style="width:10%;">Reference</th>
                                        <th style="width:30%;">Medicines/Notes</th>
                                        <th style="width:20%;">Treatments/Amount</th>
                                        <th style="width:10%;">Discount (RM)</th>
                                        <th style="width:10%;">Balance (RM)</th>
                                        <th style="width:10%;">Actions</th>
                                    </tr>
                                </thead>
                                <tbody id="medicalTable">
                                    <!-- Rows will be populated by updateMsr.js -->
                                </tbody>
                            </table>
                        </div>
                        <div class="text-center mt-3">
                            <button id="addRow" class="btn btn-primary btn-sm">
                                <i class="fas fa-plus-circle me-1"></i> Add Row
                            </button>
                        </div>
                    </div>
                </div>
                <div class="text-center mt-4">
                    <button id="submitMSR" class="btn btn-success btn-lg rounded-pill px-4">
                        <i class="fas fa-save me-1"></i> Update MSR
                    </button>
                </div>
            </div>
        </div>
    </div>
    <script>
        const baseURL = "<?php echo $baseURL; ?>";
        // Encode msrData safely
        const msrData = <?php echo json_encode($msrData, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT | JSON_HEX_AMP); ?>;
        console.log("msrData:", msrData);
    </script>
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <script src="<?php echo $baseURL; ?>assets/js/updateMsr.js"></script>
    <?php include ROOT_PATH . 'includes/footer.php'; ?>
</body>

</html>