<?php
/**
 * appointments_fetch.php
 *
 * Fetches appointment records for a specific patient, with optional filters:
 *   - appt_start, appt_end   (YYYY-MM-DD)
 *   - appt_status            (Scheduled, Completed, Cancelled)
 *   - appt_id (int)          (If you want to filter by a single Appointment ID)
 *   - Pagination via apg in $_GET
 *
 * Outputs:
 *   - $appointments    : an array of appointment records
 *   - $apPg            : current page
 *   - $apTotalPages    : total pages
 */

// 1. Grab filters from $_GET
$filterApptID = isset($_GET['appt_id']) ? (int)$_GET['appt_id'] : 0;
$appt_start   = $_GET['appt_start'] ?? '';
$appt_end     = $_GET['appt_end'] ?? '';
$appt_status  = $_GET['appt_status'] ?? '';

// 2. Build WHERE clauses (be cautious about SQL injection in production code)
$apClauses = ["a.PatientID = {$patient_id}"];

if ($filterApptID > 0) {
    $apClauses[] = "a.AppointmentID = {$filterApptID}";
}

if (
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_start) &&
    preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_end)
) {
    $apClauses[] = "DATE(a.AppointmentDate) BETWEEN '{$appt_start}' AND '{$appt_end}'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_start)) {
    $apClauses[] = "DATE(a.AppointmentDate) >= '{$appt_start}'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $appt_end)) {
    $apClauses[] = "DATE(a.AppointmentDate) <= '{$appt_end}'";
}

if (in_array($appt_status, ['Scheduled', 'Completed', 'Cancelled'], true)) {
    $apClauses[] = "a.Status = '{$appt_status}'";
}

$apWhere = "WHERE " . implode(' AND ', $apClauses);

// 3. Pagination
$apPerPage = 5;
$apPg = isset($_GET['apg']) ? (int)$_GET['apg'] : 1;
if ($apPg < 1) {
    $apPg = 1;
}
$apOffset = ($apPg - 1) * $apPerPage;

// 4. Count total appointments
$sqlCountAp = "SELECT COUNT(a.AppointmentID) AS total FROM appointments a {$apWhere}";
$resCountAp = $conn->query($sqlCountAp);
if (!$resCountAp) {
    error_log("Error in appointments_fetch.php: " . $conn->error);
    $apTotal = 0;
} else {
    $countRow = $resCountAp->fetch_assoc();
    $apTotal = (int)($countRow['total'] ?? 0);
    $resCountAp->free();
}
$apTotalPages = ($apTotal > 0) ? ceil($apTotal / $apPerPage) : 1;

// 5. Fetch the appointments
$sqlAp = "
  SELECT
    a.AppointmentID,
    a.AppointmentDate,
    a.AppointmentTime,
    a.PatientID,
    a.Purpose,
    a.Status,
    a.Remarks,
    CASE WHEN COUNT(d.DiagnosisID) > 0 THEN 1 ELSE 0 END AS has_diagnosis
  FROM appointments a
  LEFT JOIN diagnoses d
         ON d.AppointmentID = a.AppointmentID
        AND d.PatientID     = a.PatientID
  {$apWhere}
  GROUP BY a.AppointmentID
  ORDER BY a.AppointmentDate DESC, a.AppointmentTime DESC
  LIMIT {$apPerPage} OFFSET {$apOffset}
";

$resAp = $conn->query($sqlAp);
if (!$resAp) {
    error_log("Error in appointments_fetch.php: " . $conn->error);
    $appointments = [];
} else {
    $appointments = $resAp->fetch_all(MYSQLI_ASSOC);
    $resAp->free();
}
?>
