<?php

/**
 * appointments_section.php
 *
 * Renders the appointment table + filter form + modals for
 * "Add" and "Edit" appointments for a given $patient_id.
 *
 * Requirements:
 *   - $appointments (array) from appointments_fetch.php
 *   - $patient_id (int)
 *   - $userRole ('staff'|'admin')
 *   - $apPg, $apTotalPages (pagination)
 */

// Example: If you also rely on session messages like $_SESSION['error'] or $_SESSION['success'],
// they might be displayed in the main "patientProfile.php", so not repeated here.
?>

<div class="card p-3 shadow-sm border-0">
    <h5 class="mb-3">Appointments (Patient #<?php echo (int)$patient_id; ?>)</h5>

    <!-- Filter Form -->
    <form class="row g-3 mb-3" method="GET">
        <input type="hidden" name="id" value="<?php echo (int)$patient_id; ?>">
        <input type="hidden" name="appointments-tab" value="1">

        <div class="col-md-3">
            <label class="form-label fw-bold">Start Date</label>
            <input type="date" class="form-control" name="appt_start"
                value="<?php echo htmlspecialchars($_GET['appt_start'] ?? ''); ?>">
        </div>
        <div class="col-md-3">
            <label class="form-label fw-bold">End Date</label>
            <input type="date" class="form-control" name="appt_end"
                value="<?php echo htmlspecialchars($_GET['appt_end'] ?? ''); ?>">
        </div>
        <div class="col-md-3">
            <label class="form-label fw-bold">Status</label>
            <select class="form-select" name="appt_status">
                <option value="">All</option>
                <option value="Scheduled"
                    <?php if (($_GET['appt_status'] ?? '') === 'Scheduled') echo 'selected'; ?>>
                    Scheduled
                </option>
                <option value="Completed"
                    <?php if (($_GET['appt_status'] ?? '') === 'Completed') echo 'selected'; ?>>
                    Completed
                </option>
                <option value="Cancelled"
                    <?php if (($_GET['appt_status'] ?? '') === 'Cancelled') echo 'selected'; ?>>
                    Cancelled
                </option>
            </select>
        </div>
        <div class="col-md-3 d-flex align-items-end">
            <button type="submit" class="btn btn-primary">
                <i class="fas fa-filter me-1"></i> Filter
            </button>
        </div>
    </form>

    <!-- ADD APPOINTMENT BUTTON (Visible to staff/admin) -->
    <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
        <button class="btn btn-primary mb-3"
            data-bs-toggle="modal"
            data-bs-target="#addAppointmentModal">
            <i class="fas fa-plus"></i> Add Appointment
        </button>
    <?php endif; ?>

    <?php if (!empty($appointments)): ?>
        <div class="table-responsive">
            <table class="table table-bordered align-middle text-center">
                <thead class="table-light">
                    <tr>
                        <th>ID</th>
                        <th>Date/Time</th>
                        <th>Purpose</th>
                        <th>Status</th>
                        <th>Remarks</th>
                        <th style="width:210px;">Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($appointments as $apt):
                        $aptID = (int)$apt['AppointmentID'];
                        // Build data for the "Edit" modal
                        $aptData = [
                            'AppointmentID'   => $aptID,
                            'AppointmentDate' => $apt['AppointmentDate'] ?? '',
                            'AppointmentTime' => substr($apt['AppointmentTime'] ?? '09:00:00', 0, 5),
                            'Purpose'         => $apt['Purpose'] ?? '',
                            'Status'          => $apt['Status'] ?? 'Scheduled',
                            'Remarks'         => $apt['Remarks'] ?? ''
                        ];
                        $hasDiagnosis = !empty($apt['has_diagnosis']);
                    ?>
                        <tr>
                            <td><?php echo $aptID; ?></td>
                            <td>
                                <?php echo htmlspecialchars($apt['AppointmentDate'] ?? '-'); ?>
                                <br>
                                <?php
                                echo (!empty($apt['AppointmentTime']))
                                    ? substr($apt['AppointmentTime'], 0, 5)
                                    : '--:--';
                                ?>
                            </td>
                            <td><?php echo htmlspecialchars($apt['Purpose'] ?? '-'); ?></td>
                            <td>
                                <?php if ($apt['Status'] === 'Completed'): ?>
                                    <span class="badge bg-success">Completed</span>
                                <?php elseif ($apt['Status'] === 'Cancelled'): ?>
                                    <span class="badge bg-danger">Cancelled</span>
                                <?php else: ?>
                                    <span class="badge bg-warning text-dark">Scheduled</span>
                                <?php endif; ?>
                            </td>
                            <td style="white-space: pre-wrap;">
                                <?php echo nl2br(htmlspecialchars($apt['Remarks'] ?? '')); ?>
                            </td>
                            <td>
                                <div class="d-flex flex-wrap justify-content-center gap-1">
                                    <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
                                        <!-- EDIT -->
                                        <button class="btn btn-warning btn-sm"
                                            data-bs-toggle="modal"
                                            data-bs-target="#editAppointmentModal"
                                            data-appointment='<?php echo json_encode($aptData); ?>'
                                            data-bs-toggle="tooltip"
                                            title="Edit Appointment">
                                            <i class="fas fa-edit"></i>
                                        </button>
                                    <?php endif; ?>

                                    <!-- ADD/VIEW DIAGNOSIS -->
                                    <span id="diagBtn-<?php echo $aptID; ?>">
                                        <?php if (!$hasDiagnosis): ?>
                                            <button class="btn btn-info btn-sm"
                                                onclick="addDiagnosis(<?php echo (int)$patient_id; ?>, <?php echo $aptID; ?>)"
                                                data-bs-toggle="tooltip"
                                                title="Add Diagnosis">
                                                <i class="fas fa-plus"></i>
                                            </button>
                                        <?php else: ?>
                                            <a class="btn btn-info btn-sm"
                                                href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&diagnoses-tab=1&appt_id=<?php echo $aptID; ?>"
                                                data-bs-toggle="tooltip"
                                                title="View Diagnosis">
                                                <i class="fas fa-stethoscope"></i>
                                            </a>
                                        <?php endif; ?>
                                    </span>

                                    <!-- VIEW FOLLOW-UPS -->
                                    <button class="btn btn-secondary btn-sm"
                                        onclick="viewFollowUps(<?php echo $aptID; ?>)"
                                        data-bs-toggle="tooltip"
                                        title="View Follow-Ups">
                                        <i class="fas fa-eye"></i>
                                    </button>

                                    <!-- DELETE (admin only) -->
                                    <?php if ($userRole === 'admin'): ?>
                                        <form method="POST" class="d-inline"
                                            onsubmit="return confirm('Delete appointment #<?php echo $aptID; ?>?');">
                                            <input type="hidden" name="appt_action" value="deleteAppointment">
                                            <input type="hidden" name="appointment_id" value="<?php echo $aptID; ?>">
                                            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                                            <button class="btn btn-danger btn-sm"
                                                data-bs-toggle="tooltip"
                                                title="Delete Appointment">
                                                <i class="fas fa-trash"></i>
                                            </button>
                                        </form>
                                    <?php endif; ?>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- PAGINATION -->
        <?php if ($apTotalPages > 1): ?>
            <nav class="mt-3">
                <ul class="pagination justify-content-center">
                    <!-- Prev -->
                    <?php if ($apPg > 1): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo ($apPg - 1); ?>">
                                « Prev
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">« Prev</span></li>
                    <?php endif; ?>

                    <?php for ($i = 1; $i <= $apTotalPages; $i++): ?>
                        <li class="page-item <?php if ($i === $apPg) echo 'active'; ?>">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo $i; ?>">
                                <?php echo $i; ?>
                            </a>
                        </li>
                    <?php endfor; ?>

                    <?php if ($apPg < $apTotalPages): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&apg=<?php echo ($apPg + 1); ?>">
                                Next »
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">Next »</span></li>
                    <?php endif; ?>
                </ul>
            </nav>
        <?php endif; ?>

    <?php else: ?>
        <p>No appointments found for this patient.</p>
    <?php endif; ?>
</div>

<!-- (A) ADD APPOINTMENT MODAL -->
<div class="modal fade" id="addAppointmentModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="appt_action" value="addAppointment">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

            <div class="modal-header">
                <h5 class="modal-title">Add Appointment</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="mb-3">
                    <label class="form-label">Appointment Date</label>
                    <input type="date" class="form-control" name="appointment_date"
                        value="<?php echo date('Y-m-d'); ?>" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Appointment Time</label>
                    <input type="time" class="form-control" name="appointment_time"
                        value="09:00" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Purpose</label>
                    <input type="text" class="form-control" name="purpose" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Status</label>
                    <select class="form-select" name="status">
                        <option value="Scheduled">Scheduled</option>
                        <option value="Completed">Completed</option>
                        <option value="Cancelled">Cancelled</option>
                    </select>
                </div>
                <div class="mb-3">
                    <label class="form-label">Remarks</label>
                    <textarea class="form-control" name="remarks"></textarea>
                </div>

                <div class="form-check mb-3">
                    <input class="form-check-input" type="checkbox"
                        name="auto_schedule_followups" id="auto_schedule_followups">
                    <label class="form-check-label" for="auto_schedule_followups">
                        Auto Schedule Follow-Ups (1wk, 3d, 1d prior)
                    </label>
                </div>
                <div class="form-check mb-3">
                    <input class="form-check-input" type="checkbox"
                        name="auto_create_diagnosis" id="auto_create_diagnosis">
                    <label class="form-check-label" for="auto_create_diagnosis">
                        Also Create Diagnosis?
                    </label>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary"
                    data-bs-dismiss="modal">Close</button>
                <button class="btn btn-primary">Add Appointment</button>
            </div>
        </form>
    </div>
</div>

<!-- (B) EDIT APPOINTMENT MODAL -->
<div class="modal fade" id="editAppointmentModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="appt_action" value="editAppointment">
            <input type="hidden" name="appointment_id" id="appointment_id_edit">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

            <div class="modal-header">
                <h5 class="modal-title">Edit Appointment</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div class="mb-3">
                    <label class="form-label">Appointment Date</label>
                    <input type="date" class="form-control" name="appointment_date"
                        id="appointment_date_edit" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Appointment Time</label>
                    <input type="time" class="form-control" name="appointment_time"
                        id="appointment_time_edit" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Purpose</label>
                    <input type="text" class="form-control" name="purpose"
                        id="purpose_edit" required>
                </div>
                <div class="mb-3">
                    <label class="form-label">Status</label>
                    <select class="form-select" name="status" id="status_edit" required>
                        <option value="Scheduled">Scheduled</option>
                        <option value="Completed">Completed</option>
                        <option value="Cancelled">Cancelled</option>
                    </select>
                    <small class="text-muted">
                        Remarks are recommended if status is Cancelled or Completed.
                    </small>
                </div>
                <div class="mb-3">
                    <label class="form-label">Remarks</label>
                    <textarea class="form-control" name="remarks"
                        id="remarks_edit_appt"></textarea>
                </div>
                <div class="form-check mb-3">
                    <input class="form-check-input" type="checkbox"
                        name="auto_update_followups"
                        id="auto_update_followups">
                    <label class="form-check-label" for="auto_update_followups">
                        Auto-Update Follow-Ups (Remove &amp; Recreate)
                    </label>
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary"
                    data-bs-dismiss="modal">Close</button>
                <button class="btn btn-warning">Update Appointment</button>
            </div>
        </form>
    </div>
</div>

<!-- (C) VIEW FOLLOW-UPS MODAL -->
<div class="modal fade" id="viewFollowUpsModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Follow-Ups for This Appointment</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">
                <div id="followUpsContainer">Loading...</div>
            </div>
            <div class="modal-footer">
                <button class="btn btn-secondary"
                    data-bs-dismiss="modal">Close</button>
            </div>
        </div>
    </div>
</div>

<script>
    // (A) "Add Diagnosis" via a quick AJAX call (if desired)
    function addDiagnosis(patientID, appointmentID) {
        const url = "<?php echo $baseURL ?? ''; ?>actions/diagnosis/quick_add_diagnosis.php";
        const payload = {
            patient_id: patientID,
            appointment_id: appointmentID
        };
        fetch(url, {
                method: "POST",
                headers: {
                    "Content-Type": "application/json"
                },
                body: JSON.stringify(payload)
            })
            .then(r => r.json())
            .then(resp => {
                if (!resp.success) {
                    alert("Error: " + resp.message);
                    return;
                }
                const diagContainer = document.getElementById("diagBtn-" + appointmentID);
                if (diagContainer) {
                    diagContainer.innerHTML = `
                    <a class="btn btn-sm btn-info"
                       href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&diagnoses-tab=1&appt_id=${appointmentID}"
                       data-bs-toggle="tooltip" title="View Diagnosis">
                        <i class="fas fa-stethoscope"></i>
                    </a>`;
                }
            })
            .catch(err => {
                console.error("addDiagnosis error:", err);
                alert("Failed to add diagnosis. Check console.");
            });
    }

    // (B) "View Follow-Ups" => open a modal and fetch data
    function viewFollowUps(appointmentID) {
        const url = "<?php echo $baseURL ?? ''; ?>actions/followups/get_followups_by_appointment.php?appointment_id=" + appointmentID;
        const container = document.getElementById("followUpsContainer");
        container.innerHTML = "Loading...";

        fetch(url)
            .then(r => r.json())
            .then(data => {
                if (!Array.isArray(data) || data.length < 1) {
                    container.innerHTML = "<p>No follow-ups found for this appointment.</p>";
                } else {
                    let html = `
                        <table class="table table-bordered align-middle">
                            <thead>
                                <tr>
                                    <th>ID</th>
                                    <th>Date/Time</th>
                                    <th>Category</th>
                                    <th>Type</th>
                                    <th>Status</th>
                                    <th>Remarks</th>
                                </tr>
                            </thead>
                            <tbody>
                    `;
                    data.forEach(fu => {
                        let dtStr = fu.FollowUpDate ?
                            new Date(fu.FollowUpDate).toLocaleString() :
                            "-";
                        let cat = fu.category_name || "Manual";
                        html += `
                            <tr>
                                <td>${fu.FollowUpID}</td>
                                <td>${dtStr}</td>
                                <td>${cat}</td>
                                <td>${fu.FollowUpType || ""}</td>
                                <td>${fu.FollowUpStatus || ""}</td>
                                <td style="white-space:pre-wrap;">${fu.Remarks || ""}</td>
                            </tr>
                        `;
                    });
                    html += "</tbody></table>";
                    container.innerHTML = html;
                }
                let modal = new bootstrap.Modal(document.getElementById("viewFollowUpsModal"));
                modal.show();
            })
            .catch(err => {
                console.error("viewFollowUps error:", err);
                container.innerHTML = "<p class='text-danger'>Error loading follow-ups. Check console.</p>";
                let modal = new bootstrap.Modal(document.getElementById("viewFollowUpsModal"));
                modal.show();
            });
    }

    // (C) Populate "Edit Appointment" modal with JSON data
    document.addEventListener("DOMContentLoaded", function() {
        const editApptModalEl = document.getElementById("editAppointmentModal");
        if (editApptModalEl) {
            editApptModalEl.addEventListener("show.bs.modal", function(evt) {
                const btn = evt.relatedTarget;
                if (!btn) return;
                const apptData = JSON.parse(btn.getAttribute("data-appointment") || "{}");

                document.getElementById("appointment_id_edit").value = apptData.AppointmentID || "";
                document.getElementById("appointment_date_edit").value = apptData.AppointmentDate || "";
                document.getElementById("appointment_time_edit").value = apptData.AppointmentTime || "09:00";
                document.getElementById("purpose_edit").value = apptData.Purpose || "";
                document.getElementById("status_edit").value = apptData.Status || "Scheduled";
                document.getElementById("remarks_edit_appt").value = apptData.Remarks || "";
            });
        }
    });
</script>