<?php

/**
 * debts_fetch.php
 *
 * Fetches debts for a specific patient. Filtered by optional date range from $_GET:
 *   - deb_start (YYYY-MM-DD)
 *   - deb_end   (YYYY-MM-DD)
 *
 * Outputs:
 *   - $debts    : an array of debt rows (plus partial_payments sub-array)
 */

// 1. Collect filters from $_GET
$debStart = $_GET['deb_start'] ?? '';
$debEnd   = $_GET['deb_end']   ?? '';

// 2. Build the WHERE clauses
$debClauses = ["d.patient_id = {$patient_id}"];

if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $debStart) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $debEnd)) {
    $debClauses[] = "DATE(m.date_of_msr) BETWEEN '$debStart' AND '$debEnd'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $debStart)) {
    $debClauses[] = "DATE(m.date_of_msr) >= '$debStart'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $debEnd)) {
    $debClauses[] = "DATE(m.date_of_msr) <= '$debEnd'";
}

$debWhere = 'WHERE ' . implode(' AND ', $debClauses);

// 3. Query the debts
$sqlDebt = "
  SELECT
    d.*,
    m.id AS msr_main_id,
    m.msr_number,
    DATE_FORMAT(m.date_of_msr, '%d %b %Y') AS msr_date_formatted
  FROM debts d
  JOIN msr m ON d.msr_id = m.id
  $debWhere
  ORDER BY m.date_of_msr ASC, d.id ASC
";

$debRes = $conn->query($sqlDebt);

$debts    = [];
$debtIDs  = [];

while ($rowD = $debRes->fetch_assoc()) {
    $rowD['partial_payments'] = [];
    $debts[] = $rowD;
    $debtIDs[] = (int)$rowD['id'];
}
$debRes->close();

// 4. Fetch partial payments for these debts (if any)
$paymentsByDebt = [];
if (!empty($debtIDs)) {
    // We'll build a dynamic placeholder list for the IN(...) clause
    $placeholders = implode(',', array_fill(0, count($debtIDs), '?'));
    $types        = str_repeat('i', count($debtIDs));

    $sqlPP = "
      SELECT *
      FROM debt_payments
      WHERE debts_id IN ($placeholders)
      ORDER BY pay_date ASC, id ASC
    ";
    $stPP = $conn->prepare($sqlPP);
    if ($stPP) {
        $stPP->bind_param($types, ...$debtIDs);
        $stPP->execute();
        $pRes = $stPP->get_result();
        while ($pRow = $pRes->fetch_assoc()) {
            $did = (int)$pRow['debts_id'];
            $paymentsByDebt[$did][] = $pRow;
        }
        $stPP->close();
    }
}

// 5. Attach partial payments back to each debt row
foreach ($debts as &$dRef) {
    $dID = (int)$dRef['id'];
    $dRef['partial_payments'] = $paymentsByDebt[$dID] ?? [];
}
unset($dRef); // good practice to avoid accidental references
