<?php

/**
 * diagnosis_section.php
 *
 * Renders the Diagnoses overview table for the current patient using minimal fields:
 *   - Diagnosis Date, Follow‑Up Date, Created At, Created By, Updated By.
 * Action Buttons:
 *   - Edit: Opens a modal to edit only the Diagnosis Date and Follow‑Up Date.
 *   - Details: Redirects to diagnosisDetails.php (with a "ref" parameter).
 *   - Reports: Redirects to the Reports tab for this diagnosis.
 *   - Add Report: Opens a modal to add a report for that diagnosis.
 *
 * Assumes variables: $diagnoses (fetched from diagnoses_fetch.php), $patient_id,
 * $dgPg, $dgPerPage, $dgTotalPages, $order_by_param, $currentOrder, and $userRole.
 */
?>
<style>
    .btn-action {
        min-width: 40px;
        padding: .375rem .75rem;
        font-size: 0.875rem;
    }
</style>

<div class="card p-3 shadow-sm border-0">
    <h5>Diagnoses for Patient (ID: <?php echo (int)$patient_id; ?>)</h5>
    <?php if ($userRole === 'admin'): ?>
        <div class="mb-3 text-end">
            <button class="btn btn-sm btn-primary btn-action" data-bs-toggle="modal" data-bs-target="#addDiagnosisModal">
                <i class="fas fa-plus"></i> Add Diagnosis
            </button>
        </div>
    <?php endif; ?>

    <?php if (!empty($diagnoses)): ?>
        <div class="table-responsive">
            <table class="table table-bordered align-middle text-center">
                <thead class="table-light">
                    <tr>
                        <th>No</th>
                        <th>Diagnosis Date</th>
                        <th>Follow‑Up Date</th>
                        <th>Created At</th>
                        <th>Created By</th>
                        <th>Updated By</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $startNo = ($dgPg - 1) * $dgPerPage + 1;
                    foreach ($diagnoses as $index => $diag):
                        $diagID = (int)$diag['DiagnosisID'];
                        $diagDate = (!empty($diag['DiagnosisDate']) && $diag['DiagnosisDate'] !== '0000-00-00')
                            ? date('d M Y', strtotime($diag['DiagnosisDate']))
                            : "N/A";
                        $followUpDate = (!empty($diag['FollowUpDate']) && $diag['FollowUpDate'] !== '0000-00-00')
                            ? date('d M Y', strtotime($diag['FollowUpDate']))
                            : "N/A";
                        $createdAt = (!empty($diag['CreatedAt'])) ? date('d M Y', strtotime($diag['CreatedAt'])) : "N/A";
                    ?>
                        <tr>
                            <td><?php echo $startNo + $index; ?></td>
                            <td><?php echo $diagDate; ?></td>
                            <td><?php echo $followUpDate; ?></td>
                            <td><?php echo $createdAt; ?></td>
                            <td><?php echo htmlspecialchars($diag['created_by_name'] ?? '', ENT_QUOTES, 'UTF-8'); ?></td>
                            <td><?php echo htmlspecialchars($diag['updated_by_name'] ?? '', ENT_QUOTES, 'UTF-8'); ?></td>
                            <td>
                                <div class="d-flex flex-wrap justify-content-center gap-1">
                                    <?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
                                        <button class="btn btn-warning btn-sm btn-action"
                                            data-bs-toggle="modal"
                                            data-bs-target="#editDiagnosisModal"
                                            data-diagnosis='<?php echo json_encode([
                                                                "DiagnosisID" => $diagID,
                                                                "DiagnosisDate" => $diag['DiagnosisDate'] ?? "",
                                                                "FollowUpDate" => $diag['FollowUpDate'] ?? ""
                                                            ], JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT | JSON_HEX_AMP); ?>'
                                            title="Edit Diagnosis">
                                            <i class="fas fa-edit"></i>
                                        </button>
                                    <?php endif; ?>
                                    <a class="btn btn-secondary btn-sm btn-action"
                                        href="<?php echo $baseURL; ?>pages/diagnosis/diagnosisDetails.php?id=<?php echo $diagID; ?>&ref=<?php echo urlencode($_SERVER['REQUEST_URI']); ?>"
                                        title="Details">
                                        <i class="fas fa-eye"></i> Details
                                    </a>
                                    <a class="btn btn-secondary btn-sm btn-action"
                                        href="<?php echo $baseURL; ?>pages/patient/patientProfile.php?id=<?php echo (int)$patient_id; ?>&reports-tab=1&diag_id=<?php echo $diagID; ?>"
                                        title="View Reports">
                                        <i class="fas fa-file-alt"></i> Reports
                                    </a>
                                    <?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
                                        <!-- New Add Report button -->
                                        <button class="btn btn-success btn-sm btn-action"
                                            data-bs-toggle="modal"
                                            data-bs-target="#addReportModal"
                                            data-diagnosis-id="<?php echo $diagID; ?>"
                                            title="Add Report">
                                            <i class="fas fa-plus"></i> Add Report
                                        </button>
                                    <?php endif; ?>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        <?php if ($dgTotalPages > 1): ?>
            <nav class="mt-3">
                <ul class="pagination justify-content-center">
                    <?php if ($dgPg > 1): ?>
                        <li class="page-item">
                            <a class="page-link" href="?id=<?php echo $patient_id; ?>&diagnoses-tab=1&dgpg=<?php echo ($dgPg - 1); ?>&order_by=<?php echo urlencode($order_by_param); ?>&order=<?php echo urlencode($currentOrder); ?>">
                                &laquo; Prev
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                    <?php endif; ?>
                    <?php for ($i = 1; $i <= $dgTotalPages; $i++): ?>
                        <li class="page-item <?php if ($i == $dgPg) echo 'active'; ?>">
                            <a class="page-link" href="?id=<?php echo $patient_id; ?>&diagnoses-tab=1&dgpg=<?php echo $i; ?>&order_by=<?php echo urlencode($order_by_param); ?>&order=<?php echo urlencode($currentOrder); ?>">
                                <?php echo $i; ?>
                            </a>
                        </li>
                    <?php endfor; ?>
                    <?php if ($dgPg < $dgTotalPages): ?>
                        <li class="page-item">
                            <a class="page-link" href="?id=<?php echo $patient_id; ?>&diagnoses-tab=1&dgpg=<?php echo ($dgPg + 1); ?>&order_by=<?php echo urlencode($order_by_param); ?>&order=<?php echo urlencode($currentOrder); ?>">
                                Next &raquo;
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                    <?php endif; ?>
                </ul>
            </nav>
        <?php endif; ?>
    <?php else: ?>
        <p>No diagnoses found for this patient.</p>
    <?php endif; ?>
</div>

<!-- Add Diagnosis Modal (Admin Only) -->
<?php if ($userRole === 'admin'): ?>
    <div class="modal fade" id="addDiagnosisModal" tabindex="-1" aria-labelledby="addDiagnosisModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <form class="modal-content" method="POST" action="<?php echo $baseURL; ?>pages/patient/diagnoses_logic.php">
                <input type="hidden" name="diag_action" value="addDiagnosis">
                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                <div class="modal-header">
                    <h5 class="modal-title" id="addDiagnosisModalLabel">Add Diagnosis</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Minimal input: only Diagnosis Date and optional Follow‑Up Date -->
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label for="diagnosis_date_add" class="form-label">Diagnosis Date</label>
                            <input type="date" class="form-control" name="diagnosis_date" id="diagnosis_date_add" required>
                        </div>
                        <div class="col-md-6 mb-3">
                            <label for="followup_date_add" class="form-label">Follow‑Up Date (optional)</label>
                            <input type="date" class="form-control" name="followup_date" id="followup_date_add">
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary btn-action">Add Diagnosis</button>
                </div>
            </form>
        </div>
    </div>
<?php endif; ?>

<!-- Edit Diagnosis Modal (Admin or Doctor) -->
<?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
    <div class="modal fade" id="editDiagnosisModal" tabindex="-1" aria-labelledby="editDiagnosisModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <form class="modal-content" method="POST" action="<?php echo $baseURL; ?>pages/patient/diagnoses_logic.php">
                <input type="hidden" name="diag_action" value="editDiagnosis">
                <input type="hidden" name="diagnosis_id" id="diagnosis_id_edit">
                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                <div class="modal-header">
                    <h5 class="modal-title" id="editDiagnosisModalLabel">Edit Diagnosis Date</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Only allow editing of Diagnosis Date and Follow‑Up Date -->
                    <div class="row">
                        <div class="col-md-6 mb-3">
                            <label for="diagnosis_date_edit" class="form-label">Diagnosis Date</label>
                            <input type="date" class="form-control" name="diagnosis_date" id="diagnosis_date_edit" required>
                        </div>
                        <div class="col-md-6 mb-3">
                            <label for="followup_date_edit" class="form-label">Follow‑Up Date (optional)</label>
                            <input type="date" class="form-control" name="followup_date" id="followup_date_edit">
                        </div>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-warning btn-action">Update Diagnosis</button>
                </div>
            </form>
        </div>
    </div>
<?php endif; ?>

<!-- Add Report Modal (Admin/Doctor Only) -->
<?php if ($userRole === 'admin' || $userRole === 'doctor'): ?>
    <div class="modal fade" id="addReportModal" tabindex="-1" aria-labelledby="addReportModalLabel" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content" method="POST" enctype="multipart/form-data" action="<?php echo $baseURL; ?>pages/diagnosis/diagnosisDetails.php">
                <input type="hidden" name="report_action" value="addReport">
                <!-- The diagnosis id will be set via JavaScript -->
                <input type="hidden" name="diagnosis_id" id="report_diagnosis_id" value="">
                <div class="modal-header">
                    <h5 class="modal-title" id="addReportModalLabel">Add Report</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <div class="mb-3">
                        <label for="report_type_add" class="form-label">Report Type</label>
                        <select name="report_type" class="form-select" id="report_type_add">
                            <option value="Lab Test">Lab Test</option>
                            <option value="Imaging">Imaging</option>
                            <option value="Prescription">Prescription</option>
                            <option value="Other">Other</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label for="report_date_add" class="form-label">Report Date</label>
                        <input type="date" class="form-control" name="report_date" id="report_date_add" value="<?php echo date('Y-m-d'); ?>">
                    </div>
                    <div class="mb-3">
                        <label for="report_file_add" class="form-label">Upload File (optional)</label>
                        <input type="file" class="form-control" name="report_file" id="report_file_add" accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                    </div>
                    <div class="mb-3">
                        <label for="remarks_add_report" class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="remarks_add_report" rows="3"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action" data-bs-dismiss="modal">Close</button>
                    <button type="submit" class="btn btn-primary btn-action">Add Report</button>
                </div>
            </form>
        </div>
    </div>
<?php endif; ?>

<!-- JavaScript to populate the Edit Diagnosis modal -->
<script>
    document.addEventListener("DOMContentLoaded", function() {
        var editModalEl = document.getElementById("editDiagnosisModal");
        if (editModalEl) {
            editModalEl.addEventListener("show.bs.modal", function(event) {
                var button = event.relatedTarget;
                if (!button) return;
                var diagDataStr = button.getAttribute("data-diagnosis");
                try {
                    var data = JSON.parse(diagDataStr);
                    document.getElementById("diagnosis_id_edit").value = data.DiagnosisID || "";
                    document.getElementById("diagnosis_date_edit").value = data.DiagnosisDate || "";
                    document.getElementById("followup_date_edit").value = data.FollowUpDate || "";
                } catch (e) {
                    console.error("Failed to parse diagnosis data:", e);
                }
            });
        }
    });
</script>

<!-- JavaScript to populate the Add Report modal -->
<script>
    // When the Add Report modal is shown, set the hidden diagnosis_id field
    var addReportModal = document.getElementById('addReportModal');
    if (addReportModal) {
        addReportModal.addEventListener('show.bs.modal', function(event) {
            var button = event.relatedTarget;
            var diagId = button.getAttribute('data-diagnosis-id');
            document.getElementById('report_diagnosis_id').value = diagId;
        });
    }
</script>