<?php

/**
 * followups_logic.php
 *
 * Processes CREATE/UPDATE/DELETE for follow_up.
 * Must have:
 *   - $conn (mysqli)
 *   - $currentUserID (int)
 *   - $userRole ('staff','admin')
 * in scope.
 */

$followupAction = $_POST['followup_action'] ?? '';
if (!$followupAction) {
    exit; // No action => do nothing
}

// (A) ADD FOLLOW-UP
if ($followupAction === 'addFollowUp') {
    $pID = (int)($_POST['patient_id'] ?? 0);
    if (!$pID) {
        $_SESSION['error'] = "Invalid or missing patient ID.";
        header("Location: patientProfile.php?followups-tab=1");
        exit;
    }

    // staff => forced now, admin => pick
    $nowStr = date('Y-m-d H:i:s');
    $fuDateTime = '';
    if ($userRole === 'admin') {
        $postedDT = $_POST['followup_datetime'] ?? '';
        if (!empty($postedDT) && strpos($postedDT, 'T') !== false) {
            [$dPart, $tPart] = explode('T', $postedDT);
            $fuDateTime = $dPart . ' ' . $tPart . ':00';
        } else {
            $fuDateTime = $nowStr;
        }
    } else {
        $fuDateTime = $nowStr;
    }

    $statusUpdate   = trim($_POST['status_update']       ?? '');
    $followUpType   = $_POST['followup_type']            ?? 'Call';
    $remarks        = trim($_POST['remarks']             ?? '');
    $nextFUdate     = $_POST['next_followup_date']       ?? '';
    $nextVal        = (!empty($nextFUdate)) ? $nextFUdate : null;
    $fuCategoryID   = (int)($_POST['followup_category_id'] ?? 0);
    $createAppt     = !empty($_POST['create_appointment']);

    if (!$fuCategoryID) {
        $_SESSION['error'] = "Missing follow-up category.";
        header("Location: patientProfile.php?id=$pID&followups-tab=1");
        exit;
    }

    $conn->begin_transaction();
    try {
        // 1) Insert main follow_up row (9 placeholders => "isssssiii")
        $sql = "
          INSERT INTO follow_up (
            PatientID,
            AppointmentID,
            FollowUpDate,
            StatusUpdate,
            FollowUpType,
            NextFollowUpDate,
            Remarks,
            followup_category_id,
            FollowUpStatus,
            linked_followup_id,
            CreatedBy,
            UpdatedBy,
            CreatedAt,
            UpdatedAt
          ) VALUES (
            ?,
            NULL,
            ?,
            ?,
            ?,
            ?,
            ?,
            ?,
            'Pending',
            NULL,
            ?,
            ?,
            NOW(),
            NOW()
          )
        ";
        $st = $conn->prepare($sql);
        $st->bind_param(
            "isssssiii",
            $pID,
            $fuDateTime,
            $statusUpdate,
            $followUpType,
            $nextVal,
            $remarks,
            $fuCategoryID,
            $currentUserID,
            $currentUserID
        );
        $st->execute();
        $newFU = $st->insert_id;
        $st->close();

        // 2) If “Also Create Appointment?”
        if ($createAppt) {
            // Insert the appointment (6 placeholders => "iissii")
            $apptDT = $_POST['appointment_datetime'] ?? '';
            $aDate = date('Y-m-d');
            $aTime = '09:00:00';
            if (!empty($apptDT) && strpos($apptDT, 'T') !== false) {
                [$ad, $at] = explode('T', $apptDT);
                $aDate = $ad;
                $aTime = $at . ':00';
            }
            $sqlAp = "
              INSERT INTO appointments (
                PatientID,
                FollowUpID,
                AppointmentDate,
                AppointmentTime,
                Purpose,
                Status,
                Remarks,
                CreatedBy,
                UpdatedBy,
                CreatedAt,
                UpdatedAt
              ) VALUES (
                ?,
                ?,
                ?,
                ?,
                'Follow-Up Appointment',
                'Scheduled',
                'Auto-created from Follow-Up',
                ?,
                ?,
                NOW(),
                NOW()
              )
            ";
            $stA = $conn->prepare($sqlAp);
            $stA->bind_param(
                "iissii",
                $pID,
                $newFU,
                $aDate,
                $aTime,
                $currentUserID,
                $currentUserID
            );
            $stA->execute();
            $newApptID = $stA->insert_id;
            $stA->close();

            // link that Appt => main follow_up
            $updFU = $conn->prepare("UPDATE follow_up SET AppointmentID=? WHERE FollowUpID=?");
            $updFU->bind_param("ii", $newApptID, $newFU);
            $updFU->execute();
            $updFU->close();

            // auto-create 7/3/1 day prior => forced category=3 => "Appointment"
            $apptTS = strtotime($aDate . ' ' . $aTime);
            $offsets = [-7, -3, -1];
            foreach ($offsets as $days) {
                $ts = $apptTS + ($days * 86400);
                if ($ts < time()) {
                    continue;
                }
                $autoDT = date('Y-m-d H:i:s', $ts);
                // placeholders => 6 => "iisiii"
                $autoSQL = "
                  INSERT INTO follow_up (
                    PatientID,
                    AppointmentID,
                    FollowUpDate,
                    StatusUpdate,
                    FollowUpType,
                    NextFollowUpDate,
                    Remarks,
                    followup_category_id,
                    FollowUpStatus,
                    linked_followup_id,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (
                    ?,
                    ?,
                    ?,
                    'Auto-updated follow-up',
                    'Auto',
                    NULL,
                    CONCAT('Auto follow-up for Appt #', ?),
                    3,
                    'Scheduled',
                    NULL,
                    ?,
                    ?,
                    NOW(),
                    NOW()
                  )
                ";
                $stAuto = $conn->prepare($autoSQL);
                $stAuto->bind_param(
                    "iisiii",
                    $pID,
                    $newApptID,
                    $autoDT,
                    $newApptID,
                    $currentUserID,
                    $currentUserID
                );
                $stAuto->execute();
                $stAuto->close();
            }
        }

        // 3) If nextFUdate => create or update chain
        if (!empty($nextVal)) {
            $chkC = $conn->prepare("SELECT FollowUpID FROM follow_up WHERE linked_followup_id=? LIMIT 1");
            $chkC->bind_param("i", $newFU);
            $chkC->execute();
            $rc = $chkC->get_result();
            $alreadyChain = $rc->fetch_assoc();
            $chkC->close();

            if ($alreadyChain) {
                $chID = (int)$alreadyChain['FollowUpID'];
                $updC = $conn->prepare("UPDATE follow_up SET FollowUpDate=?, UpdatedBy=?, UpdatedAt=NOW() WHERE FollowUpID=?");
                $updC->bind_param("sii", $nextVal, $currentUserID, $chID);
                $updC->execute();
                $updC->close();
            } else {
                // placeholders => 8 => "isiiiiii"
                $chSQL = "
                  INSERT INTO follow_up (
                    PatientID,
                    AppointmentID,
                    FollowUpDate,
                    StatusUpdate,
                    FollowUpType,
                    NextFollowUpDate,
                    Remarks,
                    followup_category_id,
                    FollowUpStatus,
                    linked_followup_id,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (
                    ?,
                    NULL,
                    ?,
                    CONCAT('Auto-chained from #', ?),
                    'Auto',
                    NULL,
                    CONCAT('Chained from FollowUp #', ?),
                    ?,
                    'Pending',
                    ?,
                    ?,
                    ?,
                    NOW(),
                    NOW()
                  )
                ";
                $stC = $conn->prepare($chSQL);
                $stC->bind_param(
                    "isiiiiii",
                    $pID,
                    $nextVal,
                    $newFU,
                    $newFU,
                    $fuCategoryID,
                    $newFU,
                    $currentUserID,
                    $currentUserID
                );
                $stC->execute();
                $stC->close();
            }
        }

        $conn->commit();
        $_SESSION['success'] = "Follow-Up #$newFU added successfully.";
    } catch (Exception $ex) {
        $conn->rollback();
        $_SESSION['error'] = "Error adding Follow-Up: " . $ex->getMessage();
    }
    header("Location: patientProfile.php?id=$pID&followups-tab=1");
    exit;
}
// =============== (B) EDIT Follow-Up ===============
elseif ($followupAction === 'editFollowUp') {
    $fuID = (int)($_POST['followup_id'] ?? 0);
    $pID  = (int)($_POST['patient_id']  ?? 0);

    if (!$fuID || !$pID) {
        $_SESSION['error'] = "Invalid follow-up or patient ID.";
        header("Location: patientProfile.php?id=$pID&followups-tab=1");
        exit;
    }

    // staff => forced now; admin => can pick
    $nowStr = date('Y-m-d H:i:s');
    $fuDT = '';
    if ($userRole === 'admin') {
        $posted = $_POST['followup_datetime'] ?? '';
        if (!empty($posted) && strpos($posted, 'T') !== false) {
            [$dPart, $tPart] = explode('T', $posted);
            $fuDT = $dPart . ' ' . $tPart . ':00';
        } else {
            $fuDT = $nowStr;
        }
    } else {
        $fuDT = $nowStr;
    }

    $statusUpdate = trim($_POST['status_update'] ?? '');
    $followUpType = $_POST['followup_type']     ?? 'Call';
    $nextDate     = $_POST['next_followup_date'] ?? null;
    $remarks      = trim($_POST['remarks']       ?? '');
    $fuStatus     = $_POST['followup_status']   ?? 'Pending';

    // fetch old row
    $oldSel = $conn->prepare("SELECT * FROM follow_up WHERE FollowUpID=? AND PatientID=? LIMIT 1");
    $oldSel->bind_param("ii", $fuID, $pID);
    $oldSel->execute();
    $oldRes = $oldSel->get_result();
    if ($oldRes->num_rows < 1) {
        $_SESSION['error'] = "Follow-Up not found or invalid for patient #$pID.";
        header("Location: patientProfile.php?id=$pID&followups-tab=1");
        exit;
    }
    $oldRow = $oldRes->fetch_assoc();
    $oldSel->close();

    $fuCategoryID = (int)$oldRow['followup_category_id'];

    $conn->begin_transaction();
    try {
        // update main
        $upSQL = "
          UPDATE follow_up
          SET FollowUpDate=?,
              StatusUpdate=?,
              FollowUpType=?,
              NextFollowUpDate=?,
              Remarks=?,
              FollowUpStatus=?,
              UpdatedBy=?,
              UpdatedAt=NOW()
          WHERE FollowUpID=? AND PatientID=?
        ";
        $stUp = $conn->prepare($upSQL);
        // placeholders => s,s,s,s,s,s,i,i,i => total 9 => "ssssssiii"
        $stUp->bind_param(
            "ssssssiii",
            $fuDT,
            $statusUpdate,
            $followUpType,
            $nextDate,
            $remarks,
            $fuStatus,
            $currentUserID,
            $fuID,
            $pID
        );
        $stUp->execute();
        $stUp->close();

        // If there's a new Next Follow-Up Date => create or update chain
        if (!empty($nextDate)) {
            // check existing chain
            $chkC = $conn->prepare("SELECT FollowUpID FROM follow_up WHERE linked_followup_id=? LIMIT 1");
            $chkC->bind_param("i", $fuID);
            $chkC->execute();
            $rc = $chkC->get_result();
            $existingC = $rc->fetch_assoc();
            $chkC->close();

            if ($existingC) {
                // update chain
                $chainID = (int)$existingC['FollowUpID'];
                $updCh = $conn->prepare("UPDATE follow_up SET FollowUpDate=?, UpdatedBy=?, UpdatedAt=NOW() WHERE FollowUpID=?");
                $updCh->bind_param("sii", $nextDate, $currentUserID, $chainID);
                $updCh->execute();
                $updCh->close();
            } else {
                // create new chain => placeholders => "isiiiiii" => 8 placeholders
                $chSQL = "
                  INSERT INTO follow_up (
                    PatientID,
                    AppointmentID,
                    FollowUpDate,
                    StatusUpdate,
                    FollowUpType,
                    NextFollowUpDate,
                    Remarks,
                    followup_category_id,
                    FollowUpStatus,
                    linked_followup_id,
                    CreatedBy,
                    UpdatedBy,
                    CreatedAt,
                    UpdatedAt
                  ) VALUES (
                    ?,
                    NULL,
                    ?,
                    CONCAT('Auto-chained from #', ?),
                    'Auto',
                    NULL,
                    CONCAT('Chained from FollowUp #', ?),
                    ?,
                    'Pending',
                    ?,
                    ?,
                    ?,
                    NOW(),
                    NOW()
                  )
                ";
                $stCh = $conn->prepare($chSQL);
                $stCh->bind_param(
                    "isiiiiii",
                    $pID,
                    $nextDate,
                    $fuID,        // for StatusUpdate
                    $fuID,        // for Remarks
                    $fuCategoryID,
                    $fuID,        // linked_followup_id
                    $currentUserID,
                    $currentUserID
                );
                $stCh->execute();
                $stCh->close();
            }
        }

        // Quick Add Appointment from Edit (if user checks "edit_create_appointment")
        if (!empty($_POST['edit_create_appointment'])) {
            // parse the date/time
            $apptDT = $_POST['edit_appointment_datetime'] ?? '';
            $aDate = date('Y-m-d');
            $aTime = '09:00:00';
            if (!empty($apptDT) && strpos($apptDT, 'T') !== false) {
                [$ad, $at] = explode('T', $apptDT);
                $aDate = $ad;
                $aTime = $at . ':00';
            }
            // Insert the appointment => 6 placeholders => "iissii"
            $sqlAp2 = "
              INSERT INTO appointments (
                PatientID,
                FollowUpID,
                AppointmentDate,
                AppointmentTime,
                Purpose,
                Status,
                Remarks,
                CreatedBy,
                UpdatedBy,
                CreatedAt,
                UpdatedAt
              ) VALUES (
                ?,
                ?,
                ?,
                ?,
                'Follow-Up Appointment (Quick Edit)',
                'Scheduled',
                'Auto-created from edited Follow-Up',
                ?,
                ?,
                NOW(),
                NOW()
              )
            ";
            $stA2 = $conn->prepare($sqlAp2);
            $stA2->bind_param(
                "iissii",
                $pID,
                $fuID,
                $aDate,
                $aTime,
                $currentUserID,
                $currentUserID
            );
            $stA2->execute();
            $newAppt2 = $stA2->insert_id;
            $stA2->close();

            // link it
            $upd2 = $conn->prepare("UPDATE follow_up SET AppointmentID=? WHERE FollowUpID=?");
            $upd2->bind_param("ii", $newAppt2, $fuID);
            $upd2->execute();
            $upd2->close();

            // If you also want to create 7/3/1 day prior for this new appt, do similarly:
            /*
            $apptTS2 = strtotime($aDate.' '.$aTime);
            $offsets = [-7, -3, -1];
            foreach($offsets as $days) {
               ...
               // category_id=3 => "Appointment"
            }
            */
        }

        $conn->commit();
        $_SESSION['success'] = "Follow-Up #$fuID updated.";
    } catch (Exception $ex) {
        $conn->rollback();
        $_SESSION['error'] = "Error editing Follow-Up: " . $ex->getMessage();
    }

    header("Location: patientProfile.php?id=$pID&followups-tab=1");
    exit;
}

// =============== (C) DELETE Follow-Up ===============
elseif ($followupAction === 'deleteFollowUp') {
    $fuID = (int)($_POST['followup_id'] ?? 0);
    $pID  = (int)($_POST['patient_id']  ?? 0);

    if ($userRole === 'staff') {
        $_SESSION['error'] = "Staff cannot delete follow-ups.";
        header("Location: patientProfile.php?id=$pID&followups-tab=1");
        exit;
    }

    if ($fuID > 0 && $pID > 0) {
        $conn->begin_transaction();
        try {
            $del = $conn->prepare("DELETE FROM follow_up WHERE FollowUpID=? AND PatientID=?");
            $del->bind_param("ii", $fuID, $pID);
            $del->execute();
            $del->close();

            $conn->commit();
            $_SESSION['success'] = "Follow-Up #$fuID deleted.";
        } catch (Exception $ex) {
            $conn->rollback();
            $_SESSION['error'] = "Error deleting Follow-Up: " . $ex->getMessage();
        }
    }
    header("Location: patientProfile.php?id=$pID&followups-tab=1");
    exit;
}

// =============== (D) UPDATE STATUS ===============
elseif ($followupAction === 'updateStatus') {
    $fuID      = (int)($_POST['followup_id'] ?? 0);
    $pID       = (int)($_POST['patient_id']  ?? 0);
    $newStatus = $_POST['new_status']        ?? '';

    if (!in_array($newStatus, ['Pending', 'Done'])) {
        $_SESSION['error'] = "Invalid new status.";
        header("Location: patientProfile.php?id=$pID&followups-tab=1");
        exit;
    }

    // fetch old
    $chk = $conn->prepare("SELECT * FROM follow_up WHERE FollowUpID=? AND PatientID=? LIMIT 1");
    $chk->bind_param("ii", $fuID, $pID);
    $chk->execute();
    $rC = $chk->get_result();
    if ($rC->num_rows < 1) {
        $_SESSION['error'] = "Follow-Up not found for #$fuID.";
        header("Location: patientProfile.php?id=$pID&followups-tab=1");
        exit;
    }
    $oldFU = $rC->fetch_assoc();
    $chk->close();

    $conn->begin_transaction();
    try {
        $up2 = $conn->prepare("UPDATE follow_up SET FollowUpStatus=?, UpdatedBy=?, UpdatedAt=NOW() WHERE FollowUpID=? AND PatientID=?");
        $up2->bind_param("siii", $newStatus, $currentUserID, $fuID, $pID);
        $up2->execute();
        $up2->close();

        $conn->commit();
        $_SESSION['success'] = "Follow-Up #$fuID status changed to $newStatus.";
    } catch (Exception $ex) {
        $conn->rollback();
        $_SESSION['error'] = "Error changing status: " . $ex->getMessage();
    }
    header("Location: patientProfile.php?id=$pID&followups-tab=1");
    exit;
}
