<?php

/**
 * followups_section.php
 *
 * Implements:
 *  1) Group "Appointment" follow-ups (cat=3 or name='Appointment' + AppointmentID>0) in main table => single row.
 *     - Hide "Edit" and "Delete" for these grouped rows in the main table.
 *  2) "View Grouped Follow-Ups" uses a wider modal (modal-xl) with Edit/Delete/Toggle Status + View Linked for each.
 *  3) The "Add" and "Edit" modals have "Close" type="button" => no accidental submissions.
 *  4) Sorting, date filtering, category filtering remain as before.
 */

// ================== (A) SORT + GROUP LOGIC ==================

// 1) Read sorting
$sort_by    = $_GET['sort_by']    ?? 'date';
$sort_order = $_GET['sort_order'] ?? 'desc';

function sortUrl($column)
{
    global $patient_id, $fu_start, $fu_end, $fu_status, $fu_category, $sort_by, $sort_order;
    $newOrder = ($sort_by === $column && strtolower($sort_order) === 'asc') ? 'desc' : 'asc';
    $params   = [
        'id'            => $patient_id,
        'followups-tab' => 1,
        'fu_start'      => $fu_start,
        'fu_end'        => $fu_end,
        'fu_status'     => $fu_status,
        'fu_category'   => $fu_category,
        'sort_by'       => $column,
        'sort_order'    => $newOrder
    ];
    return '?' . http_build_query($params);
}
function sortArrow($column)
{
    global $sort_by, $sort_order;
    if ($sort_by === $column) {
        return (strtolower($sort_order) === 'asc')
            ? ' <i class="fas fa-arrow-up"></i>'
            : ' <i class="fas fa-arrow-down"></i>';
    }
    return '';
}

// 2) Group logic => cat=3 or name='Appointment', plus AppointmentID>0 => single row
$groupedFollowUps    = [];
$individualFollowUps = [];
foreach ($followUps as $fu) {
    $catNameLC = strtolower($fu['category_name'] ?? '');
    $catID     = (int)($fu['followup_category_id'] ?? 0);
    $apptID    = (int)($fu['appointment_id']       ?? 0);
    if (($catNameLC === 'appointment' || $catID === 3) && $apptID > 0) {
        if (!isset($groupedFollowUps[$apptID])) {
            $groupedFollowUps[$apptID] = $fu;
            $groupedFollowUps[$apptID]['group_count'] = 1;
        } else {
            $groupedFollowUps[$apptID]['group_count']++;
        }
    } else {
        $individualFollowUps[] = $fu;
    }
}
$displayFollowUps = array_merge(array_values($groupedFollowUps), $individualFollowUps);
?>

<!-- ============= (B) CSS STYLES FOR HOVER BUTTONS ============= -->
<style>
    .btn-solid-hover-outline {
        transition: all 0.3s ease;
    }

    .btn-solid-hover-outline:hover {
        background-color: transparent !important;
        border: 1px solid currentColor !important;
        color: currentColor !important;
    }
</style>

<div class="card p-3 shadow-sm border-0">
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h5 class="mb-0">Follow-Ups for <?php echo htmlspecialchars($patientFullName); ?></h5>
        <?php if ($userRole === 'staff' || $userRole === 'admin'): ?>
            <button class="btn btn-primary btn-solid-hover-outline"
                data-bs-toggle="modal"
                data-bs-target="#addFollowUpModal">
                <i class="fas fa-plus"></i> Add Follow-Up
            </button>
        <?php endif; ?>
    </div>

    <!-- (C) Filter Form -->
    <form class="row g-3 mb-3" method="GET">
        <input type="hidden" name="id" value="<?php echo (int)$patient_id; ?>">
        <input type="hidden" name="followups-tab" value="1">
        <div class="col-md-2">
            <label class="form-label fw-bold">Start Date</label>
            <input type="date" class="form-control" name="fu_start"
                value="<?php echo htmlspecialchars($fu_start ?? ''); ?>">
        </div>
        <div class="col-md-2">
            <label class="form-label fw-bold">End Date</label>
            <input type="date" class="form-control" name="fu_end"
                value="<?php echo htmlspecialchars($fu_end ?? ''); ?>">
        </div>
        <div class="col-md-2">
            <label class="form-label fw-bold">Status</label>
            <select name="fu_status" class="form-select">
                <option value="">All</option>
                <option value="Pending" <?php if (($fu_status ?? '') === 'Pending') echo 'selected'; ?>>Pending</option>
                <option value="Done" <?php if (($fu_status ?? '') === 'Done') echo 'selected'; ?>>Done</option>
            </select>
        </div>
        <div class="col-md-2">
            <label class="form-label fw-bold">Category</label>
            <select name="fu_category" class="form-select">
                <option value="">All</option>
                <?php
                $catQ = $conn->query("SELECT id,name FROM followup_categories ORDER BY name");
                while ($rc = $catQ->fetch_assoc()) {
                    $selected = ((isset($fu_category) && $fu_category == $rc['id']) ? 'selected' : '');
                    echo '<option value="' . $rc['id'] . '" ' . $selected . '>' . htmlspecialchars($rc['name']) . '</option>';
                }
                ?>
            </select>
        </div>
        <div class="col-md-4 d-flex align-items-end">
            <button type="submit" class="btn btn-primary btn-solid-hover-outline me-2"
                data-bs-toggle="tooltip" title="Apply Filters">
                <i class="fas fa-filter"></i> Filter
            </button>
            <a href="?id=<?php echo (int)$patient_id; ?>&followups-tab=1"
                class="btn btn-secondary btn-solid-hover-outline"
                data-bs-toggle="tooltip" title="Clear Filters">
                <i class="fas fa-undo"></i> Clear
            </a>
        </div>
    </form>

    <?php if (!empty($displayFollowUps)): ?>
        <div class="table-responsive">
            <table class="table table-bordered align-middle text-center">
                <thead class="table-light">
                    <tr>
                        <th>No</th>
                        <th>
                            <a href="<?php echo sortUrl('id'); ?>" class="text-decoration-none text-dark">
                                ID<?php echo sortArrow('id'); ?>
                            </a>
                        </th>
                        <th>
                            <a href="<?php echo sortUrl('date'); ?>" class="text-decoration-none text-dark">
                                Follow-Up Date<?php echo sortArrow('date'); ?>
                            </a>
                        </th>
                        <th>
                            <a href="<?php echo sortUrl('category'); ?>" class="text-decoration-none text-dark">
                                Category<?php echo sortArrow('category'); ?>
                            </a>
                        </th>
                        <th>
                            <a href="<?php echo sortUrl('type'); ?>" class="text-decoration-none text-dark">
                                Type<?php echo sortArrow('type'); ?>
                            </a>
                        </th>
                        <th>Status</th>
                        <th>Status Update</th>
                        <th>Remarks</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $startIndex = ($fuPg - 1) * $fuPerPage + 1;
                    foreach ($displayFollowUps as $index => $fu):
                        $rowNo   = $startIndex + $index;
                        $fid     = (int)($fu['FollowUpID'] ?? 0);
                        $dt      = $fu['FollowUpDate']       ?? '';
                        $catName = $fu['category_name']      ?? 'Unknown';
                        $catID   = (int)($fu['followup_category_id'] ?? 0);
                        $fType   = $fu['FollowUpType']       ?? 'Call';
                        $fStat   = $fu['FollowUpStatus']     ?? 'Pending';
                        $fUpt    = $fu['StatusUpdate']       ?? '';
                        $fRem    = $fu['Remarks']            ?? '';
                        $apptID  = (int)($fu['appointment_id'] ?? 0);
                        $grpCt   = (int)($fu['group_count']  ?? 0);

                        $linkedID   = (int)($fu['linked_id']       ?? 0);
                        $prevLinked = $fu['previous_linked']       ?? '[]';

                        $catNameLC = strtolower($catName);
                        $isGrouped = (($catNameLC === 'appointment' || $catID === 3) && $apptID > 0);
                    ?>
                        <tr>
                            <td><?php echo $rowNo; ?></td>
                            <td><?php echo $fid; ?></td>
                            <td><?php echo (!empty($dt)) ? date('d M Y, H:i', strtotime($dt)) : '-'; ?></td>
                            <td><?php echo htmlspecialchars($catName); ?></td>
                            <td><?php echo htmlspecialchars($fType); ?></td>
                            <td>
                                <span class="status-icon" style="cursor:pointer;"
                                    data-bs-toggle="tooltip"
                                    title="<?php echo ($fStat === 'Pending' ? 'Mark as Done' : 'Mark as Pending'); ?>"
                                    onclick="toggleFollowUpStatus(<?php echo $fid; ?>,<?php echo (int)$patient_id; ?>,this)">
                                    <?php if ($fStat === 'Done'): ?>
                                        <i class="fas fa-check-circle text-success"></i>
                                    <?php else: ?>
                                        <i class="fas fa-hourglass-half text-warning"></i>
                                    <?php endif; ?>
                                </span>
                            </td>
                            <td><?php echo htmlspecialchars($fUpt); ?></td>
                            <td style="white-space: pre-wrap;"><?php echo nl2br(htmlspecialchars($fRem)); ?></td>
                            <td>
                                <div class="d-flex flex-wrap justify-content-center gap-1">
                                    <?php
                                    // If grouped => hide "Edit" + "Delete" 
                                    // (so user manages them in the grouped modal)
                                    if (!$isGrouped): ?>
                                        <!-- EDIT -->
                                        <button class="btn btn-warning btn-solid-hover-outline btn-sm"
                                            data-bs-toggle="modal"
                                            data-bs-target="#editFollowUpModal"
                                            data-followup='<?php
                                                            $fuJSON = [
                                                                "FollowUpID"       => $fid,
                                                                "FollowUpDateTime" => "",
                                                                "FollowUpType"     => $fType,
                                                                "FollowUpStatus"   => $fStat,
                                                                "StatusUpdate"     => $fUpt,
                                                                "NextFollowUpDate" => ($fu["NextFollowUpDate"] ?? ""),
                                                                "Remarks"          => $fRem,
                                                                "followup_category" => $catName,
                                                                "AppointmentID"    => $apptID
                                                            ];
                                                            if (!empty($dt) && strpos($dt, ' ') !== false) {
                                                                [$dPart, $tPart] = explode(' ', $dt);
                                                                $fuJSON["FollowUpDateTime"] = $dPart . 'T' . substr($tPart, 0, 5);
                                                            }
                                                            echo htmlspecialchars(json_encode($fuJSON), ENT_QUOTES);
                                                            ?>'
                                            data-bs-toggle="tooltip" title="Edit Follow-Up">
                                            <i class="fas fa-edit"></i>
                                        </button>

                                        <!-- DELETE if admin -->
                                        <?php if ($userRole === 'admin'): ?>
                                            <form method="POST" class="d-inline" onsubmit="return confirm('Delete follow-up #<?php echo $fid; ?>?');">
                                                <input type="hidden" name="followup_action" value="deleteFollowUp">
                                                <input type="hidden" name="followup_id" value="<?php echo $fid; ?>">
                                                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                                                <button class="btn btn-danger btn-solid-hover-outline btn-sm"
                                                    data-bs-toggle="tooltip" title="Delete Follow-Up">
                                                    <i class="fas fa-trash"></i>
                                                </button>
                                            </form>
                                        <?php endif; ?>
                                    <?php endif; ?>

                                    <!-- Linked -->
                                    <?php if ($linkedID > 0 || $prevLinked !== '[]'): ?>
                                        <button class="btn btn-info btn-solid-hover-outline btn-sm"
                                            data-bs-toggle="modal"
                                            data-bs-target="#viewLinkedModal"
                                            data-linked='<?php echo htmlspecialchars($prevLinked, ENT_QUOTES); ?>'
                                            data-single-linked='[]'
                                            data-bs-toggle="tooltip" title="View Linked Follow-Ups">
                                            <i class="fas fa-link"></i>
                                        </button>
                                    <?php endif; ?>

                                    <!-- View Appt if any -->
                                    <?php if ($apptID > 0): ?>
                                        <a href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&appointments-tab=1&appt_id=<?php echo $apptID; ?>"
                                            class="btn btn-secondary btn-solid-hover-outline btn-sm"
                                            data-bs-toggle="tooltip" title="View Appointment">
                                            <i class="fas fa-calendar-alt"></i>
                                        </a>
                                    <?php endif; ?>

                                    <!-- If grouped => "View Grouped" -->
                                    <?php if ($isGrouped): ?>
                                        <button class="btn btn-dark btn-solid-hover-outline btn-sm"
                                            data-bs-toggle="modal"
                                            data-bs-target="#viewGroupedFollowUpsModal"
                                            data-appointment-id="<?php echo $apptID; ?>"
                                            data-bs-toggle="tooltip" title="View Grouped Follow-Ups">
                                            <i class="fas fa-layer-group"></i>
                                            <?php if ($grpCt > 0): ?>
                                                <span class="badge bg-light text-dark"><?php echo $grpCt; ?></span>
                                            <?php endif; ?>
                                        </button>
                                    <?php endif; ?>

                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- PAGINATION (Same logic if needed) -->
        <?php if ($fuTotalPages > 1): ?>
            <nav class="mt-3">
                <ul class="pagination justify-content-center">
                    <?php if ($fuPg > 1): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&followups-tab=1&fupg=<?php echo ($fuPg - 1); ?>">« Prev</a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">« Prev</span></li>
                    <?php endif; ?>

                    <?php for ($p = 1; $p <= $fuTotalPages; $p++): ?>
                        <li class="page-item <?php if ($p === $fuPg) echo 'active'; ?>">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&followups-tab=1&fupg=<?php echo $p; ?>">
                                <?php echo $p; ?>
                            </a>
                        </li>
                    <?php endfor; ?>

                    <?php if ($fuPg < $fuTotalPages): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&followups-tab=1&fupg=<?php echo ($fuPg + 1); ?>">Next »</a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">Next »</span></li>
                    <?php endif; ?>
                </ul>
            </nav>
        <?php endif; ?>

    <?php else: ?>
        <p>No follow-ups found for this patient.</p>
    <?php endif; ?>
</div>

<!-- ================ ADD Follow-Up MODAL ================ -->
<div class="modal fade" id="addFollowUpModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="followup_action" value="addFollowUp">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

            <div class="modal-header">
                <h5 class="modal-title">Add Follow-Up</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">

                <?php if ($userRole === 'admin'): ?>
                    <div class="mb-3">
                        <label class="form-label">Follow-Up Date/Time</label>
                        <input type="datetime-local" class="form-control" name="followup_datetime">
                        <small class="text-muted">Admin can pick date/time.</small>
                    </div>
                <?php else: ?>
                    <p class="small text-muted">Staff => forced now, hidden input</p>
                    <input type="hidden" name="followup_datetime" value="">
                <?php endif; ?>

                <div class="mb-3">
                    <label class="form-label">Follow-Up Category</label>
                    <select class="form-select" name="followup_category_id" required>
                        <option value="">-- Choose Category --</option>
                        <?php
                        $catQ2 = $conn->query("SELECT id,name FROM followup_categories ORDER BY name");
                        while ($cx = $catQ2->fetch_assoc()) {
                            echo '<option value="' . $cx['id'] . '">' . htmlspecialchars($cx['name']) . '</option>';
                        }
                        ?>
                    </select>
                </div>

                <div class="mb-3">
                    <label class="form-label">Follow-Up Type</label>
                    <select class="form-select" name="followup_type">
                        <option value="Call">Call</option>
                        <option value="Message">Message</option>
                        <option value="In-Person">In-Person</option>
                    </select>
                </div>

                <div class="mb-3">
                    <label class="form-label">Status Update</label>
                    <textarea class="form-control" name="status_update"></textarea>
                </div>

                <div class="mb-3">
                    <label class="form-label">Next Follow-Up Date</label>
                    <input type="date" class="form-control" name="next_followup_date">
                </div>

                <div class="mb-3">
                    <label class="form-label">Remarks</label>
                    <textarea class="form-control" name="remarks"></textarea>
                </div>

                <div class="form-check mb-3">
                    <input class="form-check-input" type="checkbox" name="create_appointment" id="chkCreateAppt">
                    <label class="form-check-label" for="chkCreateAppt">Also Create Appointment?</label>
                </div>
                <div id="apptFields" class="bg-light border rounded p-2" style="display:none;">
                    <label class="form-label">Appointment Date/Time</label>
                    <input type="datetime-local" class="form-control" name="appointment_datetime">
                    <small class="text-muted">If not set => default today 09:00.</small>
                </div>

            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary btn-solid-hover-outline"
                    data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary btn-solid-hover-outline">Add Follow-Up</button>
            </div>
        </form>
    </div>
</div>

<!-- ================ EDIT Follow-Up MODAL ================ -->
<div class="modal fade" id="editFollowUpModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="followup_action" value="editFollowUp">
            <input type="hidden" name="followup_id" id="edit_fu_id">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

            <div class="modal-header">
                <h5 class="modal-title">Edit Follow-Up</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body">

                <div class="mb-3">
                    <label class="form-label">Follow-Up Date/Time</label>
                    <input type="datetime-local" class="form-control" id="edit_fu_datetime" name="followup_datetime">
                    <small class="text-muted">Admin => pick date/time; staff => forced now</small>
                </div>

                <div class="mb-3">
                    <label class="form-label">Follow-Up Type</label>
                    <select class="form-select" name="followup_type" id="edit_fu_type">
                        <option value="Call">Call</option>
                        <option value="Message">Message</option>
                        <option value="In-Person">In-Person</option>
                    </select>
                </div>

                <div class="mb-3">
                    <label class="form-label">Status Update</label>
                    <textarea class="form-control" name="status_update" id="edit_fu_statusupdate"></textarea>
                </div>

                <div class="mb-3" id="edit_nextdate_div">
                    <label class="form-label">Next Follow-Up Date</label>
                    <input type="date" class="form-control" name="next_followup_date" id="edit_fu_nextdate">
                </div>

                <div class="mb-3">
                    <label class="form-label">Remarks</label>
                    <textarea class="form-control" name="remarks" id="edit_fu_remarks"></textarea>
                </div>

                <div class="mb-3">
                    <label class="form-label">Follow-Up Status</label>
                    <select class="form-select" name="followup_status" id="edit_fu_status">
                        <option value="Pending">Pending</option>
                        <option value="Done">Done</option>
                    </select>
                </div>

                <div class="form-check mb-3" id="edit_chkcreateappt_wrapper">
                    <input type="checkbox" class="form-check-input" name="edit_create_appointment" id="editChkCreateAppt">
                    <label class="form-check-label" for="editChkCreateAppt">Also Create Appointment?</label>
                </div>
                <div id="edit_apptFields" class="bg-light border rounded p-2" style="display:none;">
                    <label class="form-label">Appointment Date/Time</label>
                    <input type="datetime-local" class="form-control" name="edit_appointment_datetime">
                    <small class="text-muted">If not set => default = today 09:00.</small>
                </div>

            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary btn-solid-hover-outline"
                    data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-warning btn-solid-hover-outline">Update Follow-Up</button>
            </div>
        </form>
    </div>
</div>

<!-- ================ LINKED Follow-Ups MODAL ================ -->
<div class="modal fade" id="viewLinkedModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-lg">
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Linked Follow-Ups</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body" id="linkedFUContent" style="max-height:400px; overflow-y:auto;">
                <!-- Chat box style => filled by JS below -->
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary btn-solid-hover-outline"
                    data-bs-dismiss="modal">Close</button>
            </div>
        </div>
    </div>
</div>

<!-- ================ GROUPED Follow-Ups MODAL ================ -->
<!-- Note we use "modal-xl" to give more space for action buttons. -->
<div class="modal fade" id="viewGroupedFollowUpsModal" tabindex="-1" aria-hidden="true">
    <div class="modal-dialog modal-xl"> <!-- <-- Use modal-xl for a bigger width -->
        <div class="modal-content">
            <div class="modal-header">
                <h5 class="modal-title">Grouped Appointment Follow-Ups</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
            </div>
            <div class="modal-body" style="max-height:600px; overflow-y:auto;">
                <div id="groupedFUContent">Loading grouped follow-ups...</div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary btn-solid-hover-outline"
                    data-bs-dismiss="modal">Close</button>
            </div>
        </div>
    </div>
</div>

<script>
    /**
     * toggleFollowUpStatus(fuID, patientID, el)
     * => calls toggle_followup_status.php to set Pending/Done.
     */
    function toggleFollowUpStatus(fuID, patientID, el) {
        fetch("<?php echo $baseURL; ?>actions/followups/toggle_followup_status.php", {
                method: "POST",
                headers: {
                    "Content-Type": "application/x-www-form-urlencoded"
                },
                body: "followup_id=" + fuID + "&patient_id=" + patientID
            })
            .then(r => r.json())
            .then(resp => {
                if (!resp.success) {
                    alert(resp.message);
                    return;
                }
                if (resp.new_status === "Done") {
                    el.innerHTML = "<i class='fas fa-check-circle text-success'></i>";
                    el.setAttribute("data-bs-original-title", "Mark as Pending");
                } else {
                    el.innerHTML = "<i class='fas fa-hourglass-half text-warning'></i>";
                    el.setAttribute("data-bs-original-title", "Mark as Done");
                }
                const t = bootstrap.Tooltip.getInstance(el);
                if (t) t.hide();
            })
            .catch(err => {
                console.error("toggleFollowUpStatus error:", err);
                alert("Error toggling status. Check console for details.");
            });
    }

    // ============== ON DOM CONTENT LOADED ==============
    document.addEventListener("DOMContentLoaded", function() {
        // (1) Initialize tooltips
        const tipList = [].slice.call(document.querySelectorAll('[data-bs-toggle="tooltip"]'));
        tipList.forEach(el => new bootstrap.Tooltip(el));

        // (2) Show/hide "create appointment" in "Add" form
        const addChk = document.getElementById("chkCreateAppt");
        const addDiv = document.getElementById("apptFields");
        if (addChk && addDiv) {
            addChk.addEventListener("change", function() {
                addDiv.style.display = this.checked ? "" : "none";
            });
        }

        // (3) Show/hide "create appointment" in "Edit" form
        const editChk = document.getElementById("editChkCreateAppt");
        const editDiv = document.getElementById("edit_apptFields");
        if (editChk && editDiv) {
            editChk.addEventListener("change", function() {
                editDiv.style.display = this.checked ? "" : "none";
            });
        }

        // (4) Fill "Edit" modal => hide "create appointment?" if cat=Appointment or has AppointmentID
        const editFUmodal = document.getElementById("editFollowUpModal");
        if (editFUmodal) {
            editFUmodal.addEventListener("show.bs.modal", function(evt) {
                const btn = evt.relatedTarget;
                if (!btn) return;
                const fuData = JSON.parse(btn.getAttribute("data-followup") || "{}");

                document.getElementById("edit_fu_id").value = fuData.FollowUpID || "";
                document.getElementById("edit_fu_datetime").value = fuData.FollowUpDateTime || "";
                document.getElementById("edit_fu_type").value = fuData.FollowUpType || "Call";
                document.getElementById("edit_fu_statusupdate").value = fuData.StatusUpdate || "";
                document.getElementById("edit_fu_nextdate").value = fuData.NextFollowUpDate || "";
                document.getElementById("edit_fu_remarks").value = fuData.Remarks || "";
                document.getElementById("edit_fu_status").value = fuData.FollowUpStatus || "Pending";

                // Hide alsoCreateAppt if category=Appointment or AppointmentID
                const wrapper = document.getElementById("edit_chkcreateappt_wrapper");
                if (fuData.followup_category && fuData.followup_category.toLowerCase() === "appointment") {
                    wrapper.style.display = "none";
                } else if (fuData.AppointmentID) {
                    wrapper.style.display = "none";
                } else {
                    wrapper.style.display = "";
                }

                // Hide next date if cat=Appointment
                const nxtDiv = document.getElementById("edit_nextdate_div");
                if (fuData.followup_category && fuData.followup_category.toLowerCase() === "appointment") {
                    nxtDiv.style.display = "none";
                } else {
                    nxtDiv.style.display = "";
                }
            });
        }

        // (5) Linked => fill the chat bubble style
        const linkedModal = document.getElementById("viewLinkedModal");
        if (linkedModal) {
            linkedModal.addEventListener("show.bs.modal", function(evt) {
                const btn = evt.relatedTarget;
                if (!btn) return;
                let dataStr = btn.getAttribute("data-linked") || "[]";
                let arr = JSON.parse(dataStr);
                if ((!Array.isArray(arr) || arr.length === 0) && btn.getAttribute("data-single-linked")) {
                    arr = [JSON.parse(btn.getAttribute("data-single-linked"))];
                }
                let html = "";
                if (!Array.isArray(arr) || arr.length === 0) {
                    html = "<p>No linked follow-ups found.</p>";
                } else {
                    html += "<div class='chatbox'>";
                    arr.forEach(item => {
                        html += "<div class='chat-bubble mb-2 p-2 border rounded'>";
                        html += "<strong>ID:</strong> " + (item.FollowUpID || "N/A") + "<br>";
                        if (item.FollowUpDate) {
                            html += "<strong>Date:</strong> " + item.FollowUpDate + "<br>";
                        }
                        if (item.category_name) {
                            html += "<strong>Category:</strong> " + item.category_name + "<br>";
                        }
                        if (item.StatusUpdate) {
                            html += "<strong>Status Update:</strong> " + item.StatusUpdate + "<br>";
                        }
                        if (item.Remarks) {
                            html += "<strong>Remarks:</strong> " + item.Remarks;
                        }
                        html += "</div>";
                    });
                    html += "</div>";
                }
                document.getElementById("linkedFUContent").innerHTML = html;
            });
        }

        // (6) "View Grouped Follow-Ups" => replicate main table columns + actions => in a wider modal (modal-xl)
        const groupedModal = document.getElementById("viewGroupedFollowUpsModal");
        if (groupedModal) {
            groupedModal.addEventListener("show.bs.modal", function(evt) {
                const btn = evt.relatedTarget;
                if (!btn) return;
                const apptID = btn.getAttribute("data-appointment-id");
                const container = document.getElementById("groupedFUContent");
                container.innerHTML = "Loading grouped follow-ups...";

                fetch("<?php echo $baseURL; ?>actions/followups/get_grouped_followups.php?appointment_id=" + apptID)
                    .then(r => r.json())
                    .then(data => {
                        if (!Array.isArray(data) || data.length < 1) {
                            container.innerHTML = "<p>No follow-ups found for this group.</p>";
                            return;
                        }
                        // Build same columns => ID, Date/Time, Category, Type, Status, StatusUpdate, Remarks, Actions
                        let html = `
          <table class="table table-bordered align-middle text-center">
            <thead class="table-light">
              <tr>
                <th>ID</th>
                <th>Date/Time</th>
                <th>Category</th>
                <th>Type</th>
                <th>Status</th>
                <th>Status Update</th>
                <th>Remarks</th>
                <th>Actions</th>
              </tr>
            </thead>
            <tbody>
        `;
                        data.forEach(fu => {
                            const fid = fu.FollowUpID || 0;
                            const dt = fu.FollowUpDate || "";
                            const cName = fu.category_name || "Unknown";
                            const fType = fu.FollowUpType || "Call";
                            const fStat = fu.FollowUpStatus || "Pending";
                            const fUpt = fu.StatusUpdate || "";
                            const fRem = fu.Remarks || "";
                            const lnkID = fu.linked_followup_id || 0;

                            // Build a JSON for edit
                            let fuData = {
                                FollowUpID: fid,
                                FollowUpDateTime: "",
                                FollowUpType: fType,
                                FollowUpStatus: fStat,
                                StatusUpdate: fUpt,
                                NextFollowUpDate: fu.NextFollowUpDate || "",
                                Remarks: fRem,
                                followup_category: cName,
                                AppointmentID: fu.AppointmentID || null
                            };
                            if (dt && dt.includes(" ")) {
                                const [dPart, tPart] = dt.split(" ");
                                fuData.FollowUpDateTime = dPart + "T" + tPart.slice(0, 5);
                            }

                            // Status icon
                            let statIcon = "";
                            let statTitle = (fStat === "Pending") ? "Mark as Done" : "Mark as Pending";
                            if (fStat === "Done") {
                                statIcon = "<i class='fas fa-check-circle text-success'></i>";
                            } else {
                                statIcon = "<i class='fas fa-hourglass-half text-warning'></i>";
                            }

                            // Build actions => toggle, edit, delete(if admin), view linked(if lnkID>0)
                            let actionsHTML = "";
                            actionsHTML += `
            <span class="status-icon me-1" style="cursor:pointer;"
                  data-bs-toggle="tooltip"
                  title="${statTitle}"
                  onclick="toggleFollowUpStatus(${fid}, <?php echo (int)$patient_id; ?>, this)">
              ${statIcon}
            </span>
          `;
                            const fuEncoded = JSON.stringify(fuData).replace(/"/g, "&quot;");
                            actionsHTML += `
            <button class="btn btn-warning btn-sm btn-solid-hover-outline"
                    data-bs-toggle="modal"
                    data-bs-target="#editFollowUpModal"
                    data-followup="${fuEncoded}"
                    data-bs-toggle="tooltip" title="Edit Follow-Up">
              <i class="fas fa-edit"></i>
            </button>
          `;
                            <?php if ($userRole === 'admin'): ?>
                                actionsHTML += `
            <form method="POST" class="d-inline ms-1" onsubmit="return confirm('Delete follow-up #${fid}?');">
              <input type="hidden" name="followup_action" value="deleteFollowUp">
              <input type="hidden" name="followup_id" value="${fid}">
              <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
              <button class="btn btn-danger btn-sm btn-solid-hover-outline" 
                      data-bs-toggle="tooltip" title="Delete Follow-Up">
                <i class="fas fa-trash"></i>
              </button>
            </form>
          `;
                            <?php endif; ?>
                            if (lnkID > 0) {
                                actionsHTML += `
              <button class="btn btn-info btn-sm btn-solid-hover-outline ms-1"
                      data-bs-toggle="modal"
                      data-bs-target="#viewLinkedModal"
                      data-linked="[]"
                      data-single-linked="..."
                      data-bs-toggle="tooltip" title="View Linked Follow-Ups">
                <i class="fas fa-link"></i>
              </button>
            `;
                            }

                            // Format date/time 
                            let dateStr = "-";
                            if (dt) {
                                dateStr = new Date(dt).toLocaleString();
                            }

                            html += `
            <tr>
              <td>${fid}</td>
              <td>${dateStr}</td>
              <td>${cName}</td>
              <td>${fType}</td>
              <td>${fStat}</td>
              <td>${fUpt}</td>
              <td style="white-space:pre-wrap;">${fRem}</td>
              <td>${actionsHTML}</td>
            </tr>
          `;
                        });
                        html += "</tbody></table>";
                        container.innerHTML = html;

                        // Re-init tooltips in new table
                        const newTT = [].slice.call(container.querySelectorAll('[data-bs-toggle="tooltip"]'));
                        newTT.forEach(e => new bootstrap.Tooltip(e));
                    })
                    .catch(err => {
                        console.error("Grouped follow-ups error:", err);
                        container.innerHTML = "<p class='text-danger'>Error loading grouped follow-ups.</p>";
                    });
            });
        }
    });
</script>