<?php
// pages/patient/patientAdd.php

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// Determine if Editing or Adding New
$editMode  = false;
$patientID = null;
$patient   = [];
$address   = [];
$medical   = [];  // medical history row
$vitals    = [];  // vitals row
$hasMedicalHistory = false;
$hasVitals = false;

// If ?id=xxx, load existing
if (isset($_GET['id']) && is_numeric($_GET['id'])) {
    $editMode  = true;
    $patientID = (int) $_GET['id'];

    // Load from patients
    $stmt = $conn->prepare("SELECT * FROM patients WHERE id = ? LIMIT 1");
    $stmt->bind_param("i", $patientID);
    $stmt->execute();
    $res = $stmt->get_result();
    if ($res->num_rows > 0) {
        $patient = $res->fetch_assoc();
    }
    $stmt->close();

    // Load from patient_address
    $stmt = $conn->prepare("SELECT * FROM patient_address WHERE patient_id = ? LIMIT 1");
    $stmt->bind_param("i", $patientID);
    $stmt->execute();
    $res = $stmt->get_result();
    if ($res->num_rows > 0) {
        $address = $res->fetch_assoc();
    }
    $stmt->close();

    // Load from patient_medical_history
    $stmt = $conn->prepare("SELECT * FROM patient_medical_history WHERE patient_id = ? LIMIT 1");
    $stmt->bind_param("i", $patientID);
    $stmt->execute();
    $res = $stmt->get_result();
    if ($res->num_rows > 0) {
        $medical = $res->fetch_assoc();
        $hasMedicalHistory = true;  // There's data => auto-check
    }
    $stmt->close();

    // Load from patient_vitals
    $stmt = $conn->prepare("SELECT * FROM patient_vitals WHERE patient_id = ? LIMIT 1");
    $stmt->bind_param("i", $patientID);
    $stmt->execute();
    $res = $stmt->get_result();
    if ($res->num_rows > 0) {
        $vitals = $res->fetch_assoc();
        $hasVitals = true; // There's data => auto-check
    }
    $stmt->close();
}

// Show error/success messages from session
if (isset($_SESSION['errors']) && !empty($_SESSION['errors'])) {
    echo '<div class="alert alert-danger alert-dismissible fade show" role="alert">';
    foreach ($_SESSION['errors'] as $err) {
        echo '<p class="mb-0">' . htmlspecialchars($err) . '</p>';
    }
    echo '<button type="button" class="btn-close" data-bs-dismiss="alert"></button>';
    echo '</div>';
    unset($_SESSION['errors']);
}

if (isset($_SESSION['success'])) {
    echo '<div class="alert alert-success alert-dismissible fade show" role="alert">';
    echo '<p class="mb-0">' . htmlspecialchars($_SESSION['success']) . '</p>';
    echo '<button type="button" class="btn-close" data-bs-dismiss="alert"></button>';
    echo '</div>';
    unset($_SESSION['success']);
}

// Helper: safely fetch array fields
function fieldValue($arr, $key, $default = '')
{
    return isset($arr[$key]) ? htmlspecialchars($arr[$key]) : $default;
}
function isSelected($optionVal, $dbVal)
{
    return ($optionVal === $dbVal) ? 'selected' : '';
}

// Determine the existing profile image (if any)
$profileImagePath = fieldValue($patient, "profile_image", "");
$displayImage = $profileImagePath
    ? $baseURL . $profileImagePath
    : $baseURL . "assets/img/default_profile.png"; // fallback if none

// Spouse name => empty if not set
$spouseVal = fieldValue($patient, "spouse", "");
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title><?php echo $editMode ? "Edit" : "Add"; ?> Patient | Agasthiar</title>

    <!-- (Optional) If you need Select2, otherwise remove -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.1.0-beta.1/css/select2.min.css" rel="stylesheet" />

    <!-- Bootstrap 5 CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet" />

    <!-- (Optional) Datepicker CSS -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datepicker/1.9.0/css/bootstrap-datepicker.min.css" rel="stylesheet" />

    <!-- Your custom styles -->
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="card mb-4 shadow border-0">
                <div class="card-body text-center bg-primary text-white rounded">
                    <h4 class="card-title mb-1">Patient Management</h4>
                    <p class="mb-0"><?php echo $editMode ? "Edit Patient" : "Add Patient"; ?></p>
                </div>
            </div>

            <div class="container-fluid mt-4">
                <form id="patientForm"
                    action="<?php echo $baseURL; ?>actions/patient/addPatientProcess.php"
                    method="POST"
                    enctype="multipart/form-data">

                    <?php if ($editMode): ?>
                        <input type="hidden" name="patient_id" value="<?php echo $patientID; ?>">
                    <?php endif; ?>

                    <!-- Profile Picture & Modal -->
                    <div class="row mb-3">
                        <div class="col-md-3 text-center">
                            <img
                                id="profilePicPreview"
                                src="<?php echo htmlspecialchars($displayImage); ?>"
                                alt="Profile Picture"
                                class="img-fluid rounded-circle"
                                style="width: 150px; height: 150px; object-fit: cover;">
                        </div>
                        <div class="col-md-9 d-flex align-items-center">
                            <!-- Button to open modal -->
                            <button type="button"
                                class="btn btn-secondary"
                                data-bs-toggle="modal"
                                data-bs-target="#profilePicModal">
                                <?php echo $editMode ? "Change" : "Upload"; ?> Profile Picture
                            </button>
                        </div>
                    </div>

                    <!-- Modal for uploading profile picture -->
                    <div class="modal fade" id="profilePicModal" tabindex="-1" aria-labelledby="profilePicModalLabel" aria-hidden="true">
                        <div class="modal-dialog">
                            <div class="modal-content">
                                <div class="modal-header">
                                    <h5 class="modal-title" id="profilePicModalLabel">Upload Profile Picture</h5>
                                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                                </div>
                                <div class="modal-body">
                                    <input
                                        id="profileImageInput"
                                        type="file"
                                        name="profile_image"
                                        accept="image/*"
                                        class="form-control">
                                    <small class="text-muted">Allowed: PNG/JPG/GIF, auto-resized to 300×300.</small>
                                </div>
                                <div class="modal-footer">
                                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                                </div>
                            </div>
                        </div>
                    </div>
                    <!-- /Profile Pic Modal -->

                    <!-- Checkboxes to include Medical History & Vitals -->
                    <div class="card p-3 mb-3">
                        <h5 class="fw-bold text-primary">Additional Sections</h5>
                        <div class="form-check mb-2">
                            <input class="form-check-input"
                                type="checkbox"
                                id="checkMedHistory"
                                name="include_medical_history"
                                value="1"
                                <?php echo $hasMedicalHistory ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="checkMedHistory">
                                Include Medical History
                            </label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input"
                                type="checkbox"
                                id="checkVitals"
                                name="include_vitals"
                                value="1"
                                <?php echo $hasVitals ? 'checked' : ''; ?>>
                            <label class="form-check-label" for="checkVitals">
                                Include Vitals
                            </label>
                        </div>
                    </div>

                    <div class="row">
                        <div class="col-sm-12">
                            <ul class="nav nav-tabs" id="patientTabNav" role="tablist">
                                <li class="nav-item" role="presentation">
                                    <button
                                        class="nav-link active fw-bold text-primary"
                                        id="overview-tab"
                                        data-bs-toggle="tab"
                                        data-bs-target="#overview"
                                        type="button"
                                        role="tab"
                                        aria-controls="overview"
                                        aria-selected="true">
                                        Overview
                                    </button>
                                </li>
                                <li class="nav-item" role="presentation">
                                    <button
                                        class="nav-link fw-bold text-primary"
                                        id="address-tab"
                                        data-bs-toggle="tab"
                                        data-bs-target="#address"
                                        type="button"
                                        role="tab"
                                        aria-controls="address"
                                        aria-selected="false">
                                        Address
                                    </button>
                                </li>
                                <!-- Medical History Tab (will hide if not chosen) -->
                                <li class="nav-item" role="presentation" id="mhTabNavItem">
                                    <button
                                        class="nav-link fw-bold text-primary"
                                        id="medicalHistory-tab"
                                        data-bs-toggle="tab"
                                        data-bs-target="#medicalHistory"
                                        type="button"
                                        role="tab"
                                        aria-controls="medicalHistory"
                                        aria-selected="false">
                                        Medical History
                                    </button>
                                </li>
                                <!-- Vitals Tab (will hide if not chosen) -->
                                <li class="nav-item" role="presentation" id="vitalsTabNavItem">
                                    <button
                                        class="nav-link fw-bold text-primary"
                                        id="vitals-tab"
                                        data-bs-toggle="tab"
                                        data-bs-target="#vitals"
                                        type="button"
                                        role="tab"
                                        aria-controls="vitals"
                                        aria-selected="false">
                                        Vitals
                                    </button>
                                </li>
                            </ul>

                            <div class="tab-content mt-4" id="patientTabContent">
                                <!-- Overview Tab -->
                                <div
                                    class="tab-pane fade show active"
                                    id="overview"
                                    role="tabpanel"
                                    aria-labelledby="overview-tab">
                                    <div class="card shadow-sm border-0 rounded-4 p-4">
                                        <div class="card-body">
                                            <h4 class="card-title text-primary fw-bold">Overview</h4>
                                            <div class="row g-4">
                                                <div class="col-md-4">
                                                    <label for="patientType" class="form-label">Patient Type</label>
                                                    <select class="form-select" id="patientType" name="patient_type" required>
                                                        <option value="">Select Patient Type</option>
                                                        <option value="Old" <?php echo isSelected("Old",      fieldValue($patient, "patientType")); ?>>Old</option>
                                                        <option value="New" <?php echo isSelected("New",      fieldValue($patient, "patientType")); ?>>New</option>
                                                        <option value="Diseased" <?php echo isSelected("Diseased", fieldValue($patient, "patientType")); ?>>Diseased</option>
                                                    </select>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="patientTitle" class="form-label">Title</label>
                                                    <select class="form-select" id="patientTitle" name="patient_title" required>
                                                        <option value="">Select Title</option>
                                                        <option value="Mr" <?php echo isSelected("Mr",  fieldValue($patient, "title")); ?>>Mr</option>
                                                        <option value="Mrs" <?php echo isSelected("Mrs", fieldValue($patient, "title")); ?>>Mrs</option>
                                                        <option value="Ms" <?php echo isSelected("Ms",  fieldValue($patient, "title")); ?>>Ms</option>
                                                        <option value="Dr" <?php echo isSelected("Dr",  fieldValue($patient, "title")); ?>>Dr</option>
                                                    </select>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="firstName" class="form-label">First Name</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="firstName"
                                                        name="patient_fname"
                                                        value="<?php echo fieldValue($patient, "first_name"); ?>"
                                                        required>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="lastName" class="form-label">Last Name</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="lastName"
                                                        name="patient_lname"
                                                        value="<?php echo fieldValue($patient, "last_name"); ?>"
                                                        required>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="icNumber" class="form-label">IC/Passport Number</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="icNumber"
                                                        name="patient_ic"
                                                        value="<?php echo fieldValue($patient, "identificationNumber"); ?>"
                                                        required>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="age" class="form-label">Age</label>
                                                    <input type="number"
                                                        class="form-control"
                                                        id="age"
                                                        name="patient_age"
                                                        min="0"
                                                        value="<?php echo fieldValue($patient, "age", "0"); ?>"
                                                        required>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="gender" class="form-label">Gender</label>
                                                    <select class="form-select" id="gender" name="patient_gender" required>
                                                        <option value="">Select Gender</option>
                                                        <option value="Male" <?php echo isSelected("Male",   fieldValue($patient, "sex")); ?>>Male</option>
                                                        <option value="Female" <?php echo isSelected("Female", fieldValue($patient, "sex")); ?>>Female</option>
                                                    </select>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="contact" class="form-label">Contact</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="contact"
                                                        name="patient_contact"
                                                        value="<?php echo fieldValue($patient, "contact"); ?>"
                                                        required>
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="occupation" class="form-label">Occupation</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="occupation"
                                                        name="patient_occupation"
                                                        value="<?php echo fieldValue($patient, "occupation"); ?>">
                                                </div>
                                                <!-- Marital Status -->
                                                <div class="col-md-4">
                                                    <label for="maritalStatus" class="form-label">Marital Status</label>
                                                    <select class="form-select"
                                                        id="maritalStatus"
                                                        name="patient_maritalStatus">
                                                        <option value="">Select Marital Status</option>
                                                        <option value="Single" <?php echo isSelected("Single",    fieldValue($patient, "marital_status")); ?>>Single</option>
                                                        <option value="Married" <?php echo isSelected("Married",   fieldValue($patient, "marital_status")); ?>>Married</option>
                                                        <option value="Divorced" <?php echo isSelected("Divorced",  fieldValue($patient, "marital_status")); ?>>Divorced</option>
                                                        <option value="Widowed" <?php echo isSelected("Widowed",   fieldValue($patient, "marital_status")); ?>>Widowed</option>
                                                        <option value="Separated" <?php echo isSelected("Separated", fieldValue($patient, "marital_status")); ?>>Separated</option>
                                                    </select>
                                                </div>
                                                <!-- Spouse -->
                                                <div class="col-md-4" id="groupSpouse">
                                                    <label for="spouseName" class="form-label">Spouse Name</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="spouseName"
                                                        name="patient_spouseName"
                                                        value="<?php echo $spouseVal; ?>">
                                                </div>
                                                <!-- Children -->
                                                <div class="col-md-4" id="groupChildren">
                                                    <label for="noOfChildren" class="form-label">No. of Children</label>
                                                    <input type="number"
                                                        class="form-control"
                                                        id="noOfChildren"
                                                        name="patient_noOfChildren"
                                                        min="0"
                                                        value="<?php echo fieldValue($patient, "no_of_children", "0"); ?>">
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="dor" class="form-label">Date of Registration</label>
                                                    <input type="date"
                                                        class="form-control"
                                                        id="dor"
                                                        name="dor"
                                                        value="<?php echo fieldValue($patient, "date_of_registration"); ?>">
                                                </div>
                                                <div class="col-md-4">
                                                    <label for="remarks" class="form-label">Remarks</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="remarks"
                                                        name="remarks"
                                                        value="<?php echo fieldValue($patient, "remarks", ""); ?>">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <!-- /Overview Tab -->

                                <!-- Address Tab -->
                                <div
                                    class="tab-pane fade"
                                    id="address"
                                    role="tabpanel"
                                    aria-labelledby="address-tab">
                                    <div class="card shadow-sm border-0 rounded-4 p-4">
                                        <div class="card-body">
                                            <h4 class="card-title text-primary fw-bold">Address</h4>
                                            <div class="row g-4">
                                                <div class="col-md-6">
                                                    <label for="address1" class="form-label">Address Line 1</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="address1"
                                                        name="add1"
                                                        value="<?php echo fieldValue($address, "add1"); ?>"
                                                        required>
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="address2" class="form-label">Address Line 2</label>
                                                    <input type="text"
                                                        class="form-control"
                                                        id="address2"
                                                        name="add2"
                                                        value="<?php echo fieldValue($address, "add2"); ?>">
                                                </div>

                                                <!-- State -->
                                                <div class="col-md-6">
                                                    <label for="state" class="form-label">State</label>
                                                    <select class="form-select"
                                                        id="state"
                                                        name="states"
                                                        data-selected-state="<?php echo fieldValue($address, "state"); ?>"
                                                        required>
                                                        <option value="">Select State</option>
                                                        <!-- Populated by AJAX or static data -->
                                                    </select>
                                                </div>

                                                <!-- City -->
                                                <div class="col-md-6">
                                                    <label for="city" class="form-label">City</label>
                                                    <select class="form-select"
                                                        id="city"
                                                        name="cities"
                                                        data-selected-city="<?php echo fieldValue($address, "city"); ?>"
                                                        required>
                                                        <option value="">Select City</option>
                                                        <!-- Populated by AJAX or static data -->
                                                    </select>
                                                </div>

                                                <!-- Postcode -->
                                                <div class="col-md-6">
                                                    <label for="postcode" class="form-label">Postcode</label>
                                                    <select class="form-select"
                                                        id="postcode"
                                                        name="postcodes"
                                                        data-selected-postcode="<?php echo fieldValue($address, "postcode"); ?>"
                                                        required>
                                                        <option value="">Select Postcode</option>
                                                        <!-- Populated by AJAX or static data -->
                                                    </select>
                                                </div>

                                                <!-- Country -->
                                                <div class="col-md-6">
                                                    <label for="country" class="form-label">Country</label>
                                                    <select class="form-select"
                                                        id="country"
                                                        name="countries"
                                                        required>
                                                        <option value="">Select Country</option>
                                                        <option value="Malaysia" <?php echo isSelected("Malaysia",  fieldValue($address, "country", "Malaysia")); ?>>Malaysia</option>
                                                        <option value="Singapore" <?php echo isSelected("Singapore", fieldValue($address, "country")); ?>>Singapore</option>
                                                        <option value="Indonesia" <?php echo isSelected("Indonesia", fieldValue($address, "country")); ?>>Indonesia</option>
                                                        <option value="Others" <?php echo isSelected("Others",    fieldValue($address, "country")); ?>>Others</option>
                                                    </select>
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <!-- /Address Tab -->

                                <!-- Medical History Tab -->
                                <div
                                    class="tab-pane fade"
                                    id="medicalHistory"
                                    role="tabpanel"
                                    aria-labelledby="medicalHistory-tab">
                                    <div class="card shadow-sm border-0 rounded-4 p-4">
                                        <div class="card-body">
                                            <h4 class="card-title text-primary fw-bold">Medical History</h4>
                                            <div class="row g-4">
                                                <div class="col-md-12">
                                                    <label for="historyOfDisease" class="form-label">History of Disease</label>
                                                    <textarea class="form-control"
                                                        id="historyOfDisease"
                                                        rows="3"
                                                        name="history_of_disease"><?php echo fieldValue($medical, "history_of_disease"); ?></textarea>
                                                </div>
                                                <div class="col-md-12">
                                                    <label for="previousMedi" class="form-label">Previous Medication</label>
                                                    <textarea class="form-control"
                                                        id="previousMedi"
                                                        rows="3"
                                                        name="previousmedi"><?php echo fieldValue($medical, "previous_medication"); ?></textarea>
                                                </div>
                                                <!-- LMP hidden if gender=Male -->
                                                <div class="col-md-6" id="groupLmp">
                                                    <label for="dorecord" class="form-label">Date of Record (LMP)</label>
                                                    <input type="date"
                                                        class="form-control"
                                                        id="dorecord"
                                                        name="dorecord"
                                                        value="<?php echo fieldValue($medical, "LMP"); ?>">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <!-- /Medical History Tab -->

                                <!-- Vitals Tab -->
                                <div
                                    class="tab-pane fade"
                                    id="vitals"
                                    role="tabpanel"
                                    aria-labelledby="vitals-tab">
                                    <div class="card shadow-sm border-0 rounded-4 p-4">
                                        <div class="card-body">
                                            <h4 class="card-title text-primary fw-bold">Vitals</h4>
                                            <div class="row g-4">
                                                <div class="col-md-6">
                                                    <label for="dorecordvital" class="form-label">Date of Vital Record</label>
                                                    <input type="date"
                                                        class="form-control"
                                                        id="dorecordvital"
                                                        name="dorecordvital"
                                                        value="<?php echo fieldValue($vitals, "dateOfRecord"); ?>">
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="diabetic" class="form-label">Diabetic (mg/dL)</label>
                                                    <input type="number"
                                                        step="0.01"
                                                        class="form-control"
                                                        id="diabetic"
                                                        name="diabetic"
                                                        min="0"
                                                        value="<?php echo fieldValue($vitals, "diabetic", "0"); ?>">
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="pressure" class="form-label">Pressure (mmHg)</label>
                                                    <input type="number"
                                                        class="form-control"
                                                        id="pressure"
                                                        name="pressure"
                                                        min="0"
                                                        value="<?php echo fieldValue($vitals, "pressure", "0"); ?>">
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="height" class="form-label">Height (cm)</label>
                                                    <input type="number"
                                                        step="0.01"
                                                        class="form-control"
                                                        id="height"
                                                        name="height"
                                                        min="0"
                                                        value="<?php echo fieldValue($vitals, "height", "0"); ?>">
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="weight" class="form-label">Weight (kg)</label>
                                                    <input type="number"
                                                        step="0.01"
                                                        class="form-control"
                                                        id="weight"
                                                        name="weight"
                                                        min="0"
                                                        value="<?php echo fieldValue($vitals, "weight", "0"); ?>">
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="temperature" class="form-label">Temperature (°C)</label>
                                                    <input type="number"
                                                        step="0.1"
                                                        class="form-control"
                                                        id="temperature"
                                                        name="temperature"
                                                        min="0"
                                                        value="<?php echo fieldValue($vitals, "temp", "0"); ?>">
                                                </div>
                                                <div class="col-md-6">
                                                    <label for="pulse" class="form-label">Pulse per Minute</label>
                                                    <input type="number"
                                                        class="form-control"
                                                        id="pulse"
                                                        name="pulse"
                                                        min="0"
                                                        value="<?php echo fieldValue($vitals, "pulse_per_minute", "0"); ?>">
                                                </div>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                                <!-- /Vitals Tab -->

                                <!-- Submit Button -->
                                <div class="text-center mt-4">
                                    <button type="submit" class="btn btn-primary btn-lg rounded-4 px-5">
                                        <?php echo $editMode ? "Update" : "Save"; ?>
                                    </button>
                                </div>
                            </div> <!-- /tab-content -->
                        </div>
                    </div> <!-- /row -->
                </form>
            </div> <!-- /container-fluid -->
        </div> <!-- /page-content-wrapper -->
    </div> <!-- /wrapper -->

    <!-- Modal for "Duplicate Name Found" (from previous logic) -->
    <div class="modal fade" id="duplicateNameModal" tabindex="-1" aria-labelledby="duplicateNameModalLabel" aria-hidden="true">
        <div class="modal-dialog modal-lg">
            <div class="modal-content">
                <div class="modal-header">
                    <h5 class="modal-title" id="duplicateNameModalLabel">Duplicate Name Found</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
                </div>
                <div class="modal-body" id="duplicateNameModalBody">
                    <!-- We'll fill this dynamically with any matched patient details. -->
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary" data-bs-dismiss="modal" id="cancelProceed">No, Cancel</button>
                    <button type="button" class="btn btn-primary" data-bs-dismiss="modal" id="forceProceed">Yes, Proceed</button>
                </div>
            </div>
        </div>
    </div>

    <script>
        let ignoreNameDuplicates = false; // from prior logic
        let icValid = true; // from prior logic

        // Show/hide spouse & children if single
        function toggleSpouseAndChildren() {
            const ms = document.getElementById('maritalStatus').value;
            const spouseGroup = document.getElementById('groupSpouse');
            const childrenGroup = document.getElementById('groupChildren');

            if (ms === 'Single') {
                spouseGroup.style.display = 'none';
                childrenGroup.style.display = 'none';
            } else {
                spouseGroup.style.display = 'block';
                childrenGroup.style.display = 'block';
            }
        }

        // For immediate preview of chosen profile image
        function previewProfileImage(fileInput) {
            const file = fileInput.files[0];
            if (file) {
                const previewImg = document.getElementById('profilePicPreview');
                previewImg.src = URL.createObjectURL(file);
            }
        }

        // Hide or show the "Medical History" tab based on the checkbox
        function toggleMedicalHistoryTab() {
            const cb = document.getElementById('checkMedHistory');
            const mhTabItem = document.getElementById('mhTabNavItem');
            if (cb.checked) {
                mhTabItem.style.display = 'block';
            } else {
                mhTabItem.style.display = 'none';
            }
        }

        // Hide or show the "Vitals" tab based on the checkbox
        function toggleVitalsTab() {
            const cb = document.getElementById('checkVitals');
            const vitalsTabItem = document.getElementById('vitalsTabNavItem');
            if (cb.checked) {
                vitalsTabItem.style.display = 'block';
            } else {
                vitalsTabItem.style.display = 'none';
            }
        }

        // Hide LMP if gender = Male
        function toggleLmp() {
            const gender = document.getElementById('gender').value;
            const lmpGroup = document.getElementById('groupLmp');
            if (gender.toLowerCase() === 'male') {
                lmpGroup.style.display = 'none';
            } else {
                lmpGroup.style.display = 'block';
            }
        }

        // Check duplicates via AJAX (from prior logic)
        async function checkDuplicates() {
            const icNumber = document.getElementById('icNumber').value.trim();
            const firstName = document.getElementById('firstName').value.trim();
            const lastName = document.getElementById('lastName').value.trim();
            const patientId = <?php echo $editMode ? (int)$patientID : 0; ?>; // current patient ID or 0 if new

            if (!icNumber && !firstName && !lastName) {
                return; // nothing to check
            }

            try {
                const resp = await fetch('<?php echo $baseURL; ?>actions/patient/checkDuplicates.php', {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify({
                        icNumber,
                        firstName,
                        lastName,
                        excludePatientId: patientId
                    })
                });
                const data = await resp.json();
                icValid = !data.icExists;
                if (data.icExists) {
                    alert('This IC/Passport Number is already used by another patient. Please change it.');
                }
                if (!ignoreNameDuplicates && data.nameMatches && data.nameMatches.length > 0) {
                    let html = '<p>The following patients have the same full name:</p>';
                    html += '<ul>';
                    data.nameMatches.forEach(m => {
                        html += `<li>ID #${m.id}, IC: ${m.identificationNumber}, Contact: ${m.contact}</li>`;
                    });
                    html += '</ul>';
                    html += '<p>Do you still want to proceed?</p>';

                    document.getElementById('duplicateNameModalBody').innerHTML = html;
                    const dupModal = new bootstrap.Modal(document.getElementById('duplicateNameModal'));
                    dupModal.show();
                }

            } catch (err) {
                console.error('Error checking duplicates:', err);
            }
        }

        function handleForceProceed() {
            ignoreNameDuplicates = true;
        }

        function beforeSubmit(e) {
            if (!icValid) {
                e.preventDefault();
                alert("Please correct the IC Number before submitting.");
                return false;
            }
            return true;
        }

        document.addEventListener('DOMContentLoaded', function() {
            // 1) Spouse & children show/hide
            toggleSpouseAndChildren();
            document.getElementById('maritalStatus').addEventListener('change', toggleSpouseAndChildren);

            // 2) Profile image preview
            document.getElementById('profileImageInput').addEventListener('change', function() {
                previewProfileImage(this);
            });

            // 3) Duplicate checks
            document.getElementById('icNumber').addEventListener('blur', checkDuplicates);
            document.getElementById('firstName').addEventListener('blur', checkDuplicates);
            document.getElementById('lastName').addEventListener('blur', checkDuplicates);
            document.getElementById('forceProceed').addEventListener('click', handleForceProceed);
            document.getElementById('patientForm').addEventListener('submit', beforeSubmit);

            // 4) Medical History / Vitals checkboxes => hide/show tabs
            toggleMedicalHistoryTab();
            toggleVitalsTab();
            document.getElementById('checkMedHistory').addEventListener('change', toggleMedicalHistoryTab);
            document.getElementById('checkVitals').addEventListener('change', toggleVitalsTab);

            // 5) Hide LMP if gender=Male
            toggleLmp();
            document.getElementById('gender').addEventListener('change', toggleLmp);
        });

        // For dynamic state/city/postcode if used
        const baseURL = "<?php echo $baseURL; ?>";
    </script>

    <!-- jQuery -->
    <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
    <!-- Bootstrap 5 JS (with Popper) -->
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    <!-- Your custom JS -->
    <script src="<?php echo htmlspecialchars($baseURL); ?>assets/js/scripts.js"></script>
    <!-- The new populateDropdowns.js if you are using it -->
    <script src="<?php echo htmlspecialchars($baseURL); ?>assets/js/populateDropdowns.js"></script>
</body>

</html>