<?php
// includes/header.php
include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache");

// actions/patientList_config.php

// 1) Retrieve and sanitize GET parameters for filtering
$patient_name = isset($_GET['patient_name']) ? trim($_GET['patient_name']) : '';
$icNum = isset($_GET['icNum']) ? trim($_GET['icNum']) : '';

// 2) Build WHERE clause based on filters
$filters = [];
$params = [];
$types = '';

// Filter by patient name (first_name or last_name)
if (!empty($patient_name)) {
    $filters[] = "(first_name LIKE ? OR last_name LIKE ?)";
    $params[] = '%' . $patient_name . '%';
    $params[] = '%' . $patient_name . '%';
    $types .= 'ss';
}

// Filter by IC Number
if (!empty($icNum)) {
    $filters[] = "identificationNumber LIKE ?";
    $params[] = '%' . $icNum . '%';
    $types .= 's';
}

// Combine filters
$where_clause = '';
if (!empty($filters)) {
    $where_clause = "WHERE " . implode(" AND ", $filters);
}

// 3) Pagination settings
$records_per_page = 10; // Adjust as needed
$current_pg = isset($_GET['pg']) ? (int)$_GET['pg'] : 1;
if ($current_pg < 1) {
    $current_pg = 1;
}
$offset = ($current_pg - 1) * $records_per_page;

// 4) Count total patients for pagination
$count_sql = "SELECT COUNT(id) AS total FROM patients $where_clause";
$count_stmt = $conn->prepare($count_sql);
if (!empty($filters)) {
    $count_stmt->bind_param($types, ...$params);
}
$count_stmt->execute();
$count_result = $count_stmt->get_result();
$total_patients = $count_result->fetch_assoc()['total'] ?? 0;
$total_pages = ceil($total_patients / $records_per_page);
$count_stmt->close();

// 5) Fetch patients with applied filters and pagination
$fetch_sql = "SELECT id, identificationNumber, first_name, last_name, contact, age, sex 
              FROM patients 
              $where_clause 
              ORDER BY date_of_registration DESC 
              LIMIT ? OFFSET ?";
$fetch_stmt = $conn->prepare($fetch_sql);

// Bind parameters
if (!empty($filters)) {
    // Add types for LIMIT and OFFSET
    $types_with_limit = $types . 'ii';
    $params_with_limit = array_merge($params, [$records_per_page, $offset]);
    $fetch_stmt->bind_param($types_with_limit, ...$params_with_limit);
} else {
    // Only LIMIT and OFFSET
    $fetch_stmt->bind_param("ii", $records_per_page, $offset);
}

$fetch_stmt->execute();
$result = $fetch_stmt->get_result();
$fetch_stmt->close();
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>Patient List | Agasthiar</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">

    <!-- Include Select2 CSS -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/select2/4.1.0-beta.1/css/select2.min.css" rel="stylesheet" />

    <!-- Bootstrap CSS -->
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <!-- Font Awesome for Icons -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">

    <!-- Bootstrap Datepicker CSS -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/bootstrap-datepicker/1.9.0/css/bootstrap-datepicker.min.css" rel="stylesheet">

    <!-- Global Custom CSS -->
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">

</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="card mb-4 shadow border-0">
                <div class="card-body text-center bg-primary text-white rounded">
                    <h4 class="card-title mb-1">Patient Management</h4>
                    <p class="mb-0">Patient List</p>
                </div>
            </div>

            <!-- Filter Form -->
            <div class="row g-3 mt-3">
                <form method="GET" action="" class="row g-3">
                    <input type="hidden" name="page" value="patientList">

                    <!-- Filter by Name -->
                    <div class="col-md-4">
                        <label for="patient_name" class="form-label">Patient Name</label>
                        <input type="text" class="form-control" name="patient_name" id="patient_name"
                            value="<?php echo htmlspecialchars($patient_name); ?>" placeholder="Search by name">
                    </div>

                    <!-- Filter by IC Number -->
                    <div class="col-md-4">
                        <label for="icNum" class="form-label">IC Number</label>
                        <input type="text" class="form-control" name="icNum" id="icNum"
                            value="<?php echo htmlspecialchars($icNum); ?>" placeholder="Search by IC Number">
                    </div>

                    <!-- Filter Button -->
                    <div class="col-md-2 d-flex align-items-end">
                        <button type="submit" class="btn btn-success w-100">
                            <i class="fas fa-filter"></i> Filter
                        </button>
                    </div>

                    <!-- Clear Filter -->
                    <div class="col-md-2 d-flex align-items-end">
                        <a href="?page=patientList" class="btn btn-secondary w-100">
                            <i class="fas fa-times"></i> Clear
                        </a>
                    </div>
                </form>
            </div>

            <!-- Patient Table -->
            <div class="table-responsive mt-4">
                <table class="table table-bordered text-center align-middle">
                    <thead class="table-light">
                        <tr>
                            <th>Num</th>
                            <th>Identification Number</th>
                            <th>Name</th>
                            <th>Contact</th>
                            <th>Age</th>
                            <th>Sex</th>
                            <th>Actions</th>
                        </tr>
                    </thead>
                    <tbody>
                        <?php if ($result && $result->num_rows > 0): ?>
                            <?php
                            // Initialize row number
                            $start_num = ($current_pg - 1) * $records_per_page + 1;
                            while ($patient = $result->fetch_assoc()):
                            ?>
                                <tr>
                                    <td><?php echo htmlspecialchars($start_num++); ?></td>
                                    <td><?php echo htmlspecialchars($patient['identificationNumber']); ?></td>
                                    <td><?php echo htmlspecialchars($patient['first_name'] . ' ' . $patient['last_name']); ?></td>
                                    <td><?php echo htmlspecialchars($patient['contact']); ?></td>
                                    <td><?php echo htmlspecialchars($patient['age']); ?></td>
                                    <td><?php echo htmlspecialchars($patient['sex']); ?></td>
                                    <td>
                                        <!-- Direct Action Buttons (Instead of Dropdown) -->
                                        <a class="btn btn-sm btn-primary"
                                            href="<?php echo $baseURL; ?>pages/patient/patientProfile.php?id=<?php echo $patient['id']; ?>">
                                            <i class="fas fa-eye me-1"></i>
                                        </a>
                                        <a class="btn btn-sm btn-warning ms-1"
                                            href="<?php echo $baseURL; ?>pages/patient/patientAdd.php?id=<?php echo $patient['id']; ?>">
                                            <i class="fas fa-edit me-1"></i>
                                        </a>
                                        <a class="btn btn-sm btn-danger ms-1"
                                            href="?page=deletePatient&id=<?php echo $patient['id']; ?>"
                                            onclick="return confirm('Are you sure you want to delete this patient?');">
                                            <i class="fas fa-trash me-1"></i>
                                        </a>
                                    </td>
                                </tr>
                            <?php endwhile; ?>
                        <?php else: ?>
                            <tr>
                                <td colspan="7" class="text-center">No patients found.</td>
                            </tr>
                        <?php endif; ?>
                    </tbody>
                </table>
            </div>

            <!-- Pagination Controls -->
            <nav class="mt-4">
                <ul class="pagination justify-content-center">
                    <!-- Previous -->
                    <?php if ($current_pg > 1): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?page=patientList&pg=<?php echo $current_pg - 1; ?>&patient_name=<?php echo urlencode($patient_name); ?>&icNum=<?php echo urlencode($icNum); ?>">
                                <i class="fas fa-chevron-left"></i>
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled">
                            <a class="page-link"><i class="fas fa-chevron-left"></i></a>
                        </li>
                    <?php endif; ?>

                    <!-- Numbered Pages -->
                    <?php for ($i = 1; $i <= $total_pages; $i++): ?>
                        <?php if ($i == $current_pg): ?>
                            <li class="page-item active"><a class="page-link"><?php echo $i; ?></a></li>
                        <?php else: ?>
                            <li class="page-item">
                                <a class="page-link"
                                    href="?page=patientList&pg=<?php echo $i; ?>&patient_name=<?php echo urlencode($patient_name); ?>&icNum=<?php echo urlencode($icNum); ?>">
                                    <?php echo $i; ?>
                                </a>
                            </li>
                        <?php endif; ?>
                    <?php endfor; ?>

                    <!-- Next -->
                    <?php if ($current_pg < $total_pages): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?page=patientList&pg=<?php echo $current_pg + 1; ?>&patient_name=<?php echo urlencode($patient_name); ?>&icNum=<?php echo urlencode($icNum); ?>">
                                <i class="fas fa-chevron-right"></i>
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled">
                            <a class="page-link"><i class="fas fa-chevron-right"></i></a>
                        </li>
                    <?php endif; ?>
                </ul>
            </nav>

            <script>
                const baseURL = "<?php echo $baseURL; ?>";
            </script>

            <!-- Include jQuery -->
            <script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>

            <!-- Bootstrap JS and dependencies -->
            <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>

            <!-- Custom JS -->
            <script src="<?php echo htmlspecialchars($baseURL); ?>assets/js/scripts.js"></script>
            <script src="<?php echo htmlspecialchars($baseURL); ?>assets/js/populateDropdowns.js"></script>
            <script src="<?php echo htmlspecialchars($baseURL); ?>assets/js/preventMultipleSubmissions.js"></script>

            <?php include ROOT_PATH . 'includes/footer.php'; ?>
        </div>
    </div>
</body>

</html>