<?php

/**
 * pages/patient/reports_fetch.php
 *
 * Fetches a patient's reports for display in `reports_section.php`.
 * Now includes `DiagnosisID` from the `reports` table, and optionally
 * cross-checks that it's valid in `diagnoses`.
 */

// You already have $patient_id defined in `patientProfile.php`
// We'll do the existing filters + pagination, plus a LEFT JOIN on diagnoses.

$rep_start = $_GET['rep_start'] ?? '';
$rep_end   = $_GET['rep_end']   ?? '';
$filterDiagnosisID = isset($_GET['diag_id']) ? (int)$_GET['diag_id'] : 0;

// Build WHERE clauses
$repClauses = ["r.PatientID = $patient_id"];
if ($filterDiagnosisID > 0) {
    $repClauses[] = "r.DiagnosisID = $filterDiagnosisID";
}
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $rep_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $rep_end)) {
    $repClauses[] = "r.ReportDate BETWEEN '$rep_start' AND '$rep_end'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $rep_start)) {
    $repClauses[] = "r.ReportDate >= '$rep_start'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $rep_end)) {
    $repClauses[] = "r.ReportDate <= '$rep_end'";
}
$repWhere = 'WHERE ' . implode(' AND ', $repClauses);

// Sorting
$order_by = $_GET['order_by'] ?? 'ReportDate';
$order    = $_GET['order'] ?? 'desc';
$allowed_order_by = ['ReportDate', 'ReportID'];
if (!in_array($order_by, $allowed_order_by)) {
    $order_by = 'ReportDate';
}
$order = (strtolower($order) === 'asc') ? 'ASC' : 'DESC';

// Pagination
$repPerPage = 5;
$repPg = isset($_GET['repg']) ? max(1, (int)$_GET['repg']) : 1;
$repOffset = ($repPg - 1) * $repPerPage;

// Count total
$sqlCount = "SELECT COUNT(r.ReportID) AS total FROM reports r $repWhere";
$resC = $conn->query($sqlCount);
$repRow = $resC->fetch_assoc();
$resC->close();
$repTotal = (int)($repRow['total'] ?? 0);
$repTotalPages = max(1, ceil($repTotal / $repPerPage));

// Fetch
$sqlRep = "
  SELECT
    r.*,
    d.DiagnosisID AS diagRef,
    u1.username AS created_by_name,
    u2.username AS updated_by_name
  FROM reports r
  LEFT JOIN diagnoses d ON r.DiagnosisID = d.DiagnosisID
  LEFT JOIN users u1 ON r.CreatedBy = u1.id
  LEFT JOIN users u2 ON r.UpdatedBy = u2.id
  $repWhere
  ORDER BY r.$order_by $order, r.ReportID DESC
  LIMIT $repPerPage OFFSET $repOffset
";
$resR = $conn->query($sqlRep);
$reports = [];
if ($resR && $resR->num_rows > 0) {
    while ($rw = $resR->fetch_assoc()) {
        $reports[] = $rw;
    }
}
$resR->close();

// We'll pass $reports, $repPg, $repTotalPages to `reports_section.php`
