<?php

/**
 * reports_section.php
 *
 * Renders the "Reports" tab for patientProfile.php
 * with consistent styling: a card, a top header row with "Reports" + "Add Report" on the right,
 * a table that lists the reports, including "Diagnosis ID" if present, else "N/A".
 * The modals for Add/Edit are placed at the bottom. 
 *
 * We assume:
 *   - $patient_id, $userRole, $reports, $repPg, $repTotalPages are set from `reports_fetch.php`.
 *   - $baseURL is defined so we can link to `reports_logic.php`.
 *   - "Bootstrap 5" is loaded.
 */

// For sorting arrows (like your appointments)
$currentOrder = $_GET['order'] ?? 'desc';
$currentOrder = (strtolower($currentOrder) === 'asc') ? 'asc' : 'desc';
$newOrder = ($currentOrder === 'asc') ? 'desc' : 'asc';
$order_by_param = $_GET['order_by'] ?? 'ReportDate';
$allowed_order_by = ['ReportDate', 'ReportID'];
if (!in_array($order_by_param, $allowed_order_by)) {
    $order_by_param = 'ReportDate';
}

// If you want a “Diagnosis” dropdown in the Add/Edit modals, we can fetch them:
$dxQ = $conn->prepare("SELECT DiagnosisID,DiagnosisDate FROM diagnoses WHERE PatientID=? ORDER BY DiagnosisID DESC");
$dxQ->bind_param('i', $patient_id);
$dxQ->execute();
$resDx = $dxQ->get_result();
$allDiagnoses = $resDx->fetch_all(MYSQLI_ASSOC);
$dxQ->close();
?>
<div class="card p-3 shadow-sm border-0">
    <div class="d-flex justify-content-between align-items-center mb-3">
        <h5 class="mb-0">Reports (Patient #<?php echo (int)$patient_id; ?>)</h5>
        <?php if ($userRole === 'admin'): ?>
            <button class="btn btn-primary btn-action"
                data-bs-toggle="modal"
                data-bs-target="#addReportModal">
                <i class="fas fa-plus"></i> Add Report
            </button>
        <?php endif; ?>
    </div>

    <!-- Filter form if you like (rep_start, rep_end, etc.) -->
    <form class="row g-3 mb-3" method="GET">
        <input type="hidden" name="id" value="<?php echo (int)$patient_id; ?>">
        <input type="hidden" name="reports-tab" value="1">
        <div class="col-md-3">
            <label class="form-label fw-bold">Start Date</label>
            <input type="date" class="form-control" name="rep_start"
                value="<?php echo htmlspecialchars($_GET['rep_start'] ?? ''); ?>">
        </div>
        <div class="col-md-3">
            <label class="form-label fw-bold">End Date</label>
            <input type="date" class="form-control" name="rep_end"
                value="<?php echo htmlspecialchars($_GET['rep_end'] ?? ''); ?>">
        </div>
        <div class="col-md-2 d-flex align-items-end">
            <button class="btn btn-primary w-100 btn-action">
                <i class="fas fa-filter"></i> Filter
            </button>
        </div>
        <div class="col-md-2 d-flex align-items-end">
            <a href="?id=<?php echo (int)$patient_id; ?>&reports-tab=1" class="btn btn-secondary w-100 btn-action">
                <i class="fas fa-times"></i> Clear
            </a>
        </div>
        <!-- Keep the current sort in hidden fields if you want to preserve it -->
        <input type="hidden" name="order_by" value="<?php echo htmlspecialchars($order_by_param); ?>">
        <input type="hidden" name="order" value="<?php echo htmlspecialchars($currentOrder); ?>">
    </form>

    <?php if (!empty($reports)): ?>
        <div class="table-responsive">
            <table class="table table-bordered align-middle text-center">
                <thead class="table-light">
                    <tr>
                        <th>ID</th>
                        <th>Report Type</th>
                        <th>
                            <a href="?id=<?php echo $patient_id; ?>&reports-tab=1&order_by=ReportDate&order=<?php echo $newOrder; ?>"
                                class="text-decoration-none text-dark">
                                Report Date
                                <?php
                                if ($order_by_param === 'ReportDate') {
                                    echo ($currentOrder === 'asc')
                                        ? '<i class="fas fa-arrow-up"></i>'
                                        : '<i class="fas fa-arrow-down"></i>';
                                }
                                ?>
                            </a>
                        </th>
                        <!-- Diagnosis ID if present -->
                        <th>Diagnosis ID</th>
                        <th>File</th>
                        <th>Remarks</th>
                        <th style="width:150px;">Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php foreach ($reports as $r):
                        $repID = (int)$r['ReportID'];
                        $diagID = $r['DiagnosisID'] ?? null;
                        $diagDisplay = !empty($diagID) ? $diagID : 'N/A';
                    ?>
                        <tr>
                            <td><?php echo $repID; ?></td>
                            <td><?php echo htmlspecialchars($r['ReportType'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($r['ReportDate'] ?? ''); ?></td>
                            <td><?php echo $diagDisplay; ?></td>
                            <td>
                                <?php if (!empty($r['ReportPath'])): ?>
                                    <a href="<?php echo $baseURL . 'uploads/' . $r['ReportPath']; ?>"
                                        target="_blank" class="btn btn-info btn-sm btn-action">
                                        <i class="fas fa-file"></i> View
                                    </a>
                                <?php else: ?>
                                    <em class="text-muted">No file</em>
                                <?php endif; ?>
                            </td>
                            <td style="white-space:pre-wrap;">
                                <?php echo nl2br(htmlspecialchars($r['remarks'] ?? '')); ?>
                            </td>
                            <td>
                                <div class="d-flex flex-wrap justify-content-center gap-1">
                                    <?php if ($userRole === 'admin'): ?>
                                        <button class="btn btn-warning btn-sm btn-action"
                                            data-bs-toggle="modal"
                                            data-bs-target="#editReportModal"
                                            data-report='<?php echo json_encode($r, JSON_HEX_TAG | JSON_HEX_APOS | JSON_HEX_QUOT); ?>'>
                                            <i class="fas fa-edit"></i>
                                        </button>
                                        <form method="POST" class="d-inline"
                                            action="<?php echo $baseURL; ?>pages/patient/reports_logic.php"
                                            onsubmit="return confirm('Delete Report #<?php echo $repID; ?>?');">
                                            <input type="hidden" name="report_action" value="deleteReport">
                                            <input type="hidden" name="report_id" value="<?php echo $repID; ?>">
                                            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                                            <button class="btn btn-danger btn-sm btn-action">
                                                <i class="fas fa-trash"></i>
                                            </button>
                                        </form>
                                    <?php endif; ?>
                                </div>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>
        <!-- Pagination -->
        <?php if ($repTotalPages > 1): ?>
            <nav class="mt-3">
                <ul class="pagination justify-content-center">
                    <?php
                    $repPg = (int)$repPg;
                    if ($repPg > 1) {
                        $prev = $repPg - 1;
                        echo '<li class="page-item">
                                <a class="page-link"
                                   href="?id=' . (int)$patient_id . '&reports-tab=1&repg=' . $prev . '">« Prev</a>
                              </li>';
                    } else {
                        echo '<li class="page-item disabled"><span class="page-link">« Prev</span></li>';
                    }
                    for ($i = 1; $i <= $repTotalPages; $i++) {
                        $active = ($i === $repPg) ? 'active' : '';
                        echo '<li class="page-item ' . $active . '">
                                <a class="page-link"
                                   href="?id=' . (int)$patient_id . '&reports-tab=1&repg=' . $i . '">' . $i . '</a>
                              </li>';
                    }
                    if ($repPg < $repTotalPages) {
                        $nx = $repPg + 1;
                        echo '<li class="page-item">
                                <a class="page-link"
                                   href="?id=' . (int)$patient_id . '&reports-tab=1&repg=' . $nx . '">Next »</a>
                              </li>';
                    } else {
                        echo '<li class="page-item disabled"><span class="page-link">Next »</span></li>';
                    }
                    ?>
                </ul>
            </nav>
        <?php endif; ?>
    <?php else: ?>
        <p class="text-muted">No reports found for this patient.</p>
    <?php endif; ?>
</div><!-- end card -->

<!-- ========== ADD REPORT MODAL (admin only) ========== -->
<?php if ($userRole === 'admin'): ?>
    <div class="modal fade" id="addReportModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content"
                method="POST"
                action="<?php echo $baseURL; ?>pages/patient/reports_logic.php"
                enctype="multipart/form-data">
                <input type="hidden" name="report_action" value="addReport">
                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

                <div class="modal-header">
                    <h5 class="modal-title">Add Report</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Optional Appointment ID -->
                    <div class="mb-3">
                        <label class="form-label">Appointment ID (Optional)</label>
                        <input type="number" class="form-control" name="appointment_id" placeholder="Enter Appt ID if relevant">
                    </div>
                    <!-- Optional Diagnosis ID -->
                    <div class="mb-3">
                        <label class="form-label">Diagnosis (Optional)</label>
                        <select class="form-select" name="diagnosis_id">
                            <option value="">-- None --</option>
                            <?php foreach ($allDiagnoses as $dxRow): ?>
                                <option value="<?php echo (int)$dxRow['DiagnosisID']; ?>">
                                    #<?php echo $dxRow['DiagnosisID']; ?> (<?php echo htmlspecialchars($dxRow['DiagnosisDate'] ?? ''); ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Type</label>
                        <select class="form-select" name="report_type">
                            <option value="Lab Test">Lab Test</option>
                            <option value="Imaging">Imaging</option>
                            <option value="Prescription">Prescription</option>
                            <option value="Other">Other</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Date</label>
                        <input type="date" class="form-control" name="report_date" value="<?php echo date('Y-m-d'); ?>">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Upload File (Optional)</label>
                        <input type="file" class="form-control" name="report_file"
                            accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" rows="2"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-primary btn-action">Add Report</button>
                </div>
            </form>
        </div>
    </div>

    <!-- ========== EDIT REPORT MODAL ========== -->
    <div class="modal fade" id="editReportModal" tabindex="-1" aria-hidden="true">
        <div class="modal-dialog">
            <form class="modal-content"
                method="POST"
                action="<?php echo $baseURL; ?>pages/patient/reports_logic.php"
                enctype="multipart/form-data">
                <input type="hidden" name="report_action" value="editReport">
                <input type="hidden" name="report_id" id="report_id_edit">
                <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">

                <div class="modal-header">
                    <h5 class="modal-title">Edit Report</h5>
                    <button type="button" class="btn-close" data-bs-dismiss="modal"></button>
                </div>
                <div class="modal-body">
                    <!-- Appt & Dx optional -->
                    <div class="mb-3">
                        <label class="form-label">Appointment ID (Optional)</label>
                        <input type="number" class="form-control" name="appointment_id" id="edit_appt_id">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Diagnosis (Optional)</label>
                        <select class="form-select" name="diagnosis_id" id="edit_diagnosis_id">
                            <option value="">-- None --</option>
                            <?php foreach ($allDiagnoses as $dxRow2): ?>
                                <option value="<?php echo (int)$dxRow2['DiagnosisID']; ?>">
                                    #<?php echo $dxRow2['DiagnosisID']; ?> (<?php echo htmlspecialchars($dxRow2['DiagnosisDate'] ?? ''); ?>)
                                </option>
                            <?php endforeach; ?>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Type</label>
                        <select class="form-select" name="report_type" id="edit_report_type">
                            <option value="Lab Test">Lab Test</option>
                            <option value="Imaging">Imaging</option>
                            <option value="Prescription">Prescription</option>
                            <option value="Other">Other</option>
                        </select>
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Report Date</label>
                        <input type="date" class="form-control" name="report_date" id="edit_report_date">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Replace File (Optional)</label>
                        <input type="file" class="form-control" name="report_file"
                            accept=".pdf,.jpg,.jpeg,.png,.doc,.docx,.xls,.xlsx">
                    </div>
                    <div class="mb-3">
                        <label class="form-label">Remarks</label>
                        <textarea class="form-control" name="remarks" id="edit_remarks" rows="2"></textarea>
                    </div>
                </div>
                <div class="modal-footer">
                    <button type="button" class="btn btn-secondary btn-action" data-bs-dismiss="modal">Close</button>
                    <button class="btn btn-warning btn-action">Update Report</button>
                </div>
            </form>
        </div>
    </div>
<?php endif; ?>

<script>
    // Populate the Edit Report modal on show
    document.addEventListener("DOMContentLoaded", function() {
        const editReportModal = document.getElementById("editReportModal");
        if (editReportModal) {
            editReportModal.addEventListener("show.bs.modal", function(evt) {
                const btn = evt.relatedTarget;
                if (!btn) return;
                try {
                    const repData = JSON.parse(btn.getAttribute("data-report") || "{}");
                    document.getElementById("report_id_edit").value = repData.ReportID || "";
                    document.getElementById("edit_appt_id").value = repData.AppointmentID || "";
                    document.getElementById("edit_diagnosis_id").value = repData.DiagnosisID || "";
                    document.getElementById("edit_report_type").value = repData.ReportType || "Other";
                    document.getElementById("edit_report_date").value = repData.ReportDate || "";
                    document.getElementById("edit_remarks").value = repData.remarks || "";
                } catch (e) {
                    console.error("editReportModal parse error:", e);
                }
            });
        }
    });
</script>