<?php

/**
 * vitals_fetch.php
 *
 * Fetches vitals records for a specific patient, with optional filters:
 *   - You can add date range or specific vital filters if needed.
 *   - Pagination via vtpg in $_GET
 *
 * Outputs:
 *   - $vitalsList   : an array of vitals records
 *   - $vtPg         : current page
 *   - $vtTotalPages : total pages
 */

// 1) Optionally retrieve filter inputs from $_GET. For example:
//    - vital_param (pressure|diabetic|height|weight|temp)
//    - operator (> < =)
//    - vital_value
$vitalParam = $_GET['vital_param'] ?? '';
$operator   = $_GET['operator']    ?? '';
$vitalValue = $_GET['vital_value'] ?? '';


// 2) Build the WHERE clause
$vitalsClauses = ["v.patient_id = {$patient_id}"];

// Example approach if you want to filter by param + operator:
$allowedParams   = ['pressure', 'diabetic', 'height', 'weight', 'temp'];
$allowedOperators = ['>', '<', '='];

if (in_array($vitalParam, $allowedParams, true) && in_array($operator, $allowedOperators, true) && is_numeric($vitalValue)) {
    // e.g. "v.pressure > 120"
    $vitalsClauses[] = "v.{$vitalParam} {$operator} {$vitalValue}";
}

// If you want a date range, you can add it here, e.g.:
$vitals_start = $_GET['vitals_start'] ?? '';
$vitals_end   = $_GET['vitals_end']   ?? '';
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $vitals_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $vitals_end)) {
    $vitalsClauses[] = "DATE(v.dateOfRecord) BETWEEN '$vitals_start' AND '$vitals_end'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $vitals_start)) {
    $vitalsClauses[] = "DATE(v.dateOfRecord) >= '$vitals_start'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $vitals_end)) {
    $vitalsClauses[] = "DATE(v.dateOfRecord) <= '$vitals_end'";
}

$vitalsWhere = 'WHERE ' . implode(' AND ', $vitalsClauses);

// 3) Pagination
$vtPerPage = 5;
$vtPg = isset($_GET['vtpg']) ? (int)$_GET['vtpg'] : 1;
if ($vtPg < 1) {
    $vtPg = 1;
}
$vtOffset = ($vtPg - 1) * $vtPerPage;

// 4) Count how many total
$countSQL = "SELECT COUNT(v.id) AS total FROM patient_vitals v $vitalsWhere";
$resCnt   = $conn->query($countSQL);
$cntRow   = $resCnt->fetch_assoc();
$resCnt->close();

$vtTotal = (int)($cntRow['total'] ?? 0);
$vtTotalPages = ceil($vtTotal / $vtPerPage);

// 5) Fetch the data
$sqlVt = "
  SELECT
    v.*,
    u1.username AS created_by_name,
    u2.username AS updated_by_name
  FROM patient_vitals v
  LEFT JOIN users u1 ON v.CreatedBy = u1.id
  LEFT JOIN users u2 ON v.UpdatedBy = u2.id
  $vitalsWhere
  ORDER BY v.dateOfRecord DESC, v.id DESC
  LIMIT $vtPerPage OFFSET $vtOffset
";

$resVt = $conn->query($sqlVt);
$vitalsList = $resVt->fetch_all(MYSQLI_ASSOC);
$resVt->close();
