<?php
// Suppose you already have the patient's full name in a variable called $patientFullName.
//$patientFullName = trim($patient['first_name'] . ' ' . $patient['last_name']);

// Also assume you included 'vitals_fetch.php' beforehand, which populates:
//   $vitalsList, $vtPg, $vtTotalPages, etc.
// and possibly uses date filters from $_GET['vitals_start'] and $_GET['vitals_end'].

?>

<div class="card p-3 shadow-sm border-0">
    <!-- Header with Title and Add Vitals Button -->
    <div class="d-flex justify-content-between align-items-center mb-3">
        <!-- Instead of "Vitals for Patient #29", we show the full name -->
        <h5 class="mb-0">Vitals for <?php echo htmlspecialchars($patientFullName); ?></h5>

        <?php if ($userRole === 'admin' || $userRole === 'staff'): ?>
            <button class="btn btn-sm btn-primary" data-bs-toggle="modal" data-bs-target="#addVitalsModal">
                <i class="fas fa-plus"></i> Add Vitals
            </button>
        <?php endif; ?>
    </div>

    <!-- Filter Form (with date range) -->
    <form method="GET" class="row g-3 mb-3">
        <!-- Keep the patient ID and tab so we stay in the Vitals tab -->
        <input type="hidden" name="id" value="<?php echo (int)$patient_id; ?>">
        <input type="hidden" name="vitals-tab" value="1">

        <!-- 1) Vital Parameter dropdown -->
        <div class="col-md-2">
            <label class="form-label fw-bold">Vital Parameter</label>
            <select name="vital_param" class="form-select">
                <option value="pressure" <?php if (($vitalParam ?? '') === 'pressure') echo 'selected'; ?>>Pressure (mmHg)</option>
                <option value="diabetic" <?php if (($vitalParam ?? '') === 'diabetic') echo 'selected'; ?>>Diabetic (mg/dL)</option>
                <option value="height" <?php if (($vitalParam ?? '') === 'height')   echo 'selected'; ?>>Height (cm)</option>
                <option value="weight" <?php if (($vitalParam ?? '') === 'weight')   echo 'selected'; ?>>Weight (kg)</option>
                <option value="temp" <?php if (($vitalParam ?? '') === 'temp')     echo 'selected'; ?>>Temperature (°C)</option>
            </select>
        </div>

        <!-- 2) Operator dropdown -->
        <div class="col-md-2">
            <label class="form-label fw-bold">Operator</label>
            <select name="operator" class="form-select">
                <option value=">" <?php if (($operator ?? '') == '>') echo 'selected'; ?>>More Than</option>
                <option value="<" <?php if (($operator ?? '') == '<') echo 'selected'; ?>>Less Than</option>
                <option value="=" <?php if (($operator ?? '') == '=') echo 'selected'; ?>>Equal To</option>
            </select>
        </div>

        <!-- 3) Value input -->
        <div class="col-md-2">
            <label class="form-label fw-bold">Value</label>
            <input type="number" step="0.1" name="vital_value"
                class="form-control"
                placeholder="Value"
                value="<?php echo htmlspecialchars($vitalValue ?? ''); ?>">
        </div>

        <!-- 4) Date Start -->
        <div class="col-md-2">
            <label class="form-label fw-bold">Start Date</label>
            <input type="date" class="form-control" name="vitals_start"
                value="<?php echo htmlspecialchars($_GET['vitals_start'] ?? ''); ?>">
        </div>

        <!-- 5) Date End -->
        <div class="col-md-2">
            <label class="form-label fw-bold">End Date</label>
            <input type="date" class="form-control" name="vitals_end"
                value="<?php echo htmlspecialchars($_GET['vitals_end'] ?? ''); ?>">
        </div>

        <!-- 6) Filter & Clear Buttons -->
        <div class="col-md-12 d-flex align-items-end mt-2">
            <button type="submit" class="btn btn-primary me-2">
                <i class="fas fa-filter me-1"></i> Filter
            </button>
            <a href="patientProfile.php?id=<?php echo (int)$patient_id; ?>&vitals-tab=1"
                class="btn btn-secondary">
                Clear
            </a>
        </div>
    </form>

    <!-- The rest of your code displaying $vitalsList and pagination, same as before -->
    <?php if (!empty($vitalsList)): ?>
        <div class="table-responsive">
            <table class="table table-bordered align-middle text-center">
                <thead class="table-light">
                    <tr>
                        <th>No</th>
                        <th>ID</th>
                        <th>Pressure (mmHg)</th>
                        <th>Diabetic (mg/dL)</th>
                        <th>Height (cm)</th>
                        <th>Weight (kg)</th>
                        <th>Temp (°C)</th>
                        <th>Pulse</th>
                        <th>Date Of Record</th>
                        <th>Actions</th>
                    </tr>
                </thead>
                <tbody>
                    <?php
                    $vtPerPage = 5; // or from your $vitals_fetch logic
                    $counter = (($vtPg - 1) * $vtPerPage) + 1;
                    foreach ($vitalsList as $vt):
                    ?>
                        <tr>
                            <td><?php echo $counter++; ?></td>
                            <td><?php echo (int)$vt['id']; ?></td>
                            <td><?php echo htmlspecialchars($vt['pressure'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($vt['diabetic'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($vt['height'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($vt['weight'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($vt['temp'] ?? ''); ?></td>
                            <td><?php echo htmlspecialchars($vt['pulse_per_minute'] ?? ''); ?></td>
                            <td>
                                <?php
                                echo !empty($vt['dateOfRecord'])
                                    ? date('d M Y', strtotime($vt['dateOfRecord']))
                                    : '-';
                                ?>
                            </td>
                            <td>
                                <!-- Edit, Delete, etc. -->
                                <?php if ($userRole === 'admin' || $userRole === 'staff'): ?>
                                    <button class="btn btn-sm btn-warning"
                                        data-bs-toggle="modal"
                                        data-bs-target="#editVitalsModal"
                                        data-vitals='<?php echo json_encode($vt); ?>'>
                                        <i class="fas fa-edit"></i>
                                    </button>
                                <?php endif; ?>
                                <?php if ($userRole === 'admin'): ?>
                                    <form method="POST" class="d-inline-block"
                                        onsubmit="return confirm('Delete this vitals record?');">
                                        <input type="hidden" name="vitals_action" value="deleteVitals">
                                        <input type="hidden" name="vitals_id" value="<?php echo (int)$vt['id']; ?>">
                                        <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
                                        <button class="btn btn-sm btn-danger">
                                            <i class="fas fa-trash"></i>
                                        </button>
                                    </form>
                                <?php endif; ?>
                            </td>
                        </tr>
                    <?php endforeach; ?>
                </tbody>
            </table>
        </div>

        <!-- Pagination for Vitals -->
        <?php if (!empty($vtTotalPages) && $vtTotalPages > 1): ?>
            <nav class="mt-3">
                <ul class="pagination justify-content-center">
                    <?php if ($vtPg > 1): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&vitals-tab=1&vtpg=<?php echo ($vtPg - 1); ?>">
                                &laquo; Prev
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                    <?php endif; ?>

                    <?php for ($i = 1; $i <= $vtTotalPages; $i++): ?>
                        <li class="page-item <?php if ($i == $vtPg) echo 'active'; ?>">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&vitals-tab=1&vtpg=<?php echo $i; ?>">
                                <?php echo $i; ?>
                            </a>
                        </li>
                    <?php endfor; ?>

                    <?php if ($vtPg < $vtTotalPages): ?>
                        <li class="page-item">
                            <a class="page-link"
                                href="?id=<?php echo (int)$patient_id; ?>&vitals-tab=1&vtpg=<?php echo ($vtPg + 1); ?>">
                                Next &raquo;
                            </a>
                        </li>
                    <?php else: ?>
                        <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                    <?php endif; ?>
                </ul>
            </nav>
        <?php endif; ?>

    <?php else: ?>
        <p>No vitals found for <?php echo htmlspecialchars($patientFullName); ?>.</p>
    <?php endif; ?>
</div>




<!-- Add Vitals Modal -->
<div class="modal fade" id="addVitalsModal" tabindex="-1" aria-labelledby="addVitalsModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="vitals_action" value="addVitals">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
            <div class="modal-header">
                <h5 class="modal-title" id="addVitalsModalLabel">Add Vitals</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <!-- Pressure -->
                <div class="mb-3">
                    <label class="form-label">Pressure (mmHg)</label>
                    <input type="number" step="0.1" class="form-control" name="pressure" placeholder="e.g. 120">
                </div>
                <!-- Diabetic -->
                <div class="mb-3">
                    <label class="form-label">Diabetic (mg/dL)</label>
                    <input type="number" step="0.1" class="form-control" name="diabetic" placeholder="e.g. 90">
                </div>
                <!-- Height -->
                <div class="mb-3">
                    <label class="form-label">Height (cm)</label>
                    <input type="number" step="0.1" class="form-control" name="height" placeholder="e.g. 170">
                </div>
                <!-- Weight -->
                <div class="mb-3">
                    <label class="form-label">Weight (kg)</label>
                    <input type="number" step="0.1" class="form-control" name="weight" placeholder="e.g. 65">
                </div>
                <!-- Temperature -->
                <div class="mb-3">
                    <label class="form-label">Temperature (°C)</label>
                    <input type="number" step="0.1" class="form-control" name="temp" placeholder="e.g. 36.6">
                </div>
                <!-- Pulse -->
                <div class="mb-3">
                    <label class="form-label">Pulse (bpm)</label>
                    <input type="number" class="form-control" name="pulse_per_minute" placeholder="e.g. 72">
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-primary">Add Vitals</button>
            </div>
        </form>
    </div>
</div>

<!-- Edit Vitals Modal -->
<div class="modal fade" id="editVitalsModal" tabindex="-1" aria-labelledby="editVitalsModalLabel" aria-hidden="true">
    <div class="modal-dialog">
        <form class="modal-content" method="POST">
            <input type="hidden" name="vitals_action" value="editVitals">
            <input type="hidden" name="vitals_id" id="vitals_id_edit">
            <input type="hidden" name="patient_id" value="<?php echo (int)$patient_id; ?>">
            <div class="modal-header">
                <h5 class="modal-title" id="editVitalsModalLabel">Edit Vitals</h5>
                <button type="button" class="btn-close" data-bs-dismiss="modal" aria-label="Close"></button>
            </div>
            <div class="modal-body">
                <!-- Pressure -->
                <div class="mb-3">
                    <label class="form-label">Pressure (mmHg)</label>
                    <input type="number" step="0.1" class="form-control" name="pressure" id="pressure_edit">
                </div>
                <!-- Diabetic -->
                <div class="mb-3">
                    <label class="form-label">Diabetic (mg/dL)</label>
                    <input type="number" step="0.1" class="form-control" name="diabetic" id="diabetic_edit">
                </div>
                <!-- Height -->
                <div class="mb-3">
                    <label class="form-label">Height (cm)</label>
                    <input type="number" step="0.1" class="form-control" name="height" id="height_edit">
                </div>
                <!-- Weight -->
                <div class="mb-3">
                    <label class="form-label">Weight (kg)</label>
                    <input type="number" step="0.1" class="form-control" name="weight" id="weight_edit">
                </div>
                <!-- Temperature -->
                <div class="mb-3">
                    <label class="form-label">Temperature (°C)</label>
                    <input type="number" step="0.1" class="form-control" name="temp" id="temp_edit">
                </div>
                <!-- Pulse -->
                <div class="mb-3">
                    <label class="form-label">Pulse (bpm)</label>
                    <input type="number" class="form-control" name="pulse_per_minute" id="pulse_edit">
                </div>
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-secondary" data-bs-dismiss="modal">Close</button>
                <button type="submit" class="btn btn-warning">Update Vitals</button>
            </div>
        </form>
    </div>
</div>

<!-- JavaScript: jQuery and Bootstrap Bundle -->
<script src="https://code.jquery.com/jquery-3.6.0.min.js"></script>
<script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
<script>
    document.addEventListener("DOMContentLoaded", function() {

        // Conversion functions for metrics
        function convertHeight(cm, unit) {
            if (unit === "cm") {
                return parseFloat(cm).toFixed(1) + " cm";
            } else if (unit === "m") {
                return (cm / 100).toFixed(2) + " m";
            } else if (unit === "ft") {
                return (cm * 0.0328084).toFixed(2) + " ft";
            }
            return cm;
        }

        function convertWeight(kg, unit) {
            if (unit === "kg") {
                return parseFloat(kg).toFixed(1) + " kg";
            } else if (unit === "lb") {
                return (kg * 2.20462).toFixed(1) + " lb";
            }
            return kg;
        }

        function convertTemp(c, unit) {
            if (unit === "C") {
                return parseFloat(c).toFixed(1) + " °C";
            } else if (unit === "F") {
                return (c * 9 / 5 + 32).toFixed(1) + " °F";
            }
            return c;
        }

        function updateMetrics() {
            var heightUnit = document.getElementById("heightUnit").value;
            var weightUnit = document.getElementById("weightUnit").value;
            var tempUnit = document.getElementById("tempUnit").value;

            document.querySelectorAll("td[data-base-height]").forEach(function(td) {
                var base = parseFloat(td.getAttribute("data-base-height"));
                td.textContent = convertHeight(base, heightUnit);
            });
            document.querySelectorAll("td[data-base-weight]").forEach(function(td) {
                var base = parseFloat(td.getAttribute("data-base-weight"));
                td.textContent = convertWeight(base, weightUnit);
            });
            document.querySelectorAll("td[data-base-temp]").forEach(function(td) {
                var base = parseFloat(td.getAttribute("data-base-temp"));
                td.textContent = convertTemp(base, tempUnit);
            });
        }

        var heightUnitElem = document.getElementById("heightUnit");
        var weightUnitElem = document.getElementById("weightUnit");
        var tempUnitElem = document.getElementById("tempUnit");

        if (heightUnitElem) heightUnitElem.addEventListener("change", updateMetrics);
        if (weightUnitElem) weightUnitElem.addEventListener("change", updateMetrics);
        if (tempUnitElem) tempUnitElem.addEventListener("change", updateMetrics);

        // Populate the Edit Vitals Modal with the selected row's data.
        const editVitalsModal = document.getElementById("editVitalsModal");
        if (editVitalsModal) {
            editVitalsModal.addEventListener("show.bs.modal", function(event) {
                const btn = event.relatedTarget;
                if (!btn) return;
                const vtData = JSON.parse(btn.getAttribute("data-vitals") || "{}");
                document.getElementById("vitals_id_edit").value = vtData.id || "";
                document.getElementById("pressure_edit").value = vtData.pressure || "";
                document.getElementById("diabetic_edit").value = vtData.diabetic || "";
                document.getElementById("height_edit").value = vtData.height || "";
                document.getElementById("weight_edit").value = vtData.weight || "";
                document.getElementById("temp_edit").value = vtData.temp || "";
                document.getElementById("pulse_edit").value = vtData.pulse_per_minute || "";
            });
        }
    });
</script>