<?php
// pages/upcoming/all_items.php
// Reuses a design similar to followUps.php / globalFollowUps.php,
// but in a single page with tabs for Appointments, Follow-Ups, & Diagnosis.

include '../../common/url.php';
include ROOT_PATH . 'common/session.php';
include ROOT_PATH . 'common/config.php';

// Prevent caching
header("Cache-Control: no-store, no-cache, must-revalidate, max-age=0");
header("Pragma: no-cache");

// User Session
$currentUserID = $_SESSION['user_id'] ?? null;
$userRole      = $_SESSION['role']    ?? 'staff';
if (!$currentUserID) {
    die("No valid user session. Please log in.");
}

// Flash Messages
if (!isset($_SESSION['error']))   $_SESSION['error']   = '';
if (!isset($_SESSION['success'])) $_SESSION['success'] = '';
$errorMsg   = $_SESSION['error'];
$successMsg = $_SESSION['success'];
$_SESSION['error']   = '';
$_SESSION['success'] = '';

// Decide which tab is active
$allowedTabs = ['appointments', 'followups', 'diagnosis'];
$activeTab   = $_GET['tab'] ?? 'appointments';
if (!in_array($activeTab, $allowedTabs)) {
    $activeTab = 'appointments';
}

// ---------------------------------------------------------
// (A) APPOINTMENTS TAB: Filters + Pagination + Query
// ---------------------------------------------------------
$ap_start     = $_GET['ap_start']   ?? '';  // Start date
$ap_end       = $_GET['ap_end']     ?? '';  // End date
$ap_status    = $_GET['ap_status']  ?? '';  // "Scheduled","Completed","Cancelled"
$ap_name      = $_GET['ap_name']    ?? '';  // Search patient name
$ap_pg        = isset($_GET['ap_pg']) ? max(1, (int)$_GET['ap_pg']) : 1;
$ap_per_page  = 10;
$ap_offset    = ($ap_pg - 1) * $ap_per_page;

$apClauses = [];
$apJoins   = "FROM appointments a
             JOIN patients p ON a.PatientID = p.id";

if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $ap_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $ap_end)) {
    $apClauses[] = "a.AppointmentDate BETWEEN '$ap_start' AND '$ap_end'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $ap_start)) {
    $apClauses[] = "a.AppointmentDate >= '$ap_start'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $ap_end)) {
    $apClauses[] = "a.AppointmentDate <= '$ap_end'";
}

if (in_array($ap_status, ['Scheduled', 'Completed', 'Cancelled'], true)) {
    $apClauses[] = "a.Status = '$ap_status'";
}

if (!empty($ap_name)) {
    $esc = $conn->real_escape_string($ap_name);
    $apClauses[] = "(p.first_name LIKE '%$esc%' OR p.last_name LIKE '%$esc%')";
}

$apWhere = '';
if (!empty($apClauses)) {
    $apWhere = 'WHERE ' . implode(' AND ', $apClauses);
}

// Count how many
$sqlCountAp = "SELECT COUNT(*) as total $apJoins $apWhere";
$resCountAp = $conn->query($sqlCountAp);
$apTotal    = 0;
if ($resCountAp) {
    $countRow = $resCountAp->fetch_assoc();
    $apTotal  = (int)$countRow['total'];
}
$apTotalPages = max(1, ceil($apTotal / $ap_per_page));

// Get actual data
$sqlAp = "
  SELECT
    a.AppointmentID,
    a.PatientID,
    a.AppointmentDate,
    a.AppointmentTime,
    a.Purpose,
    a.Status,
    p.first_name,
    p.last_name
  $apJoins
  $apWhere
  ORDER BY a.AppointmentDate DESC, a.AppointmentTime DESC
  LIMIT $ap_per_page OFFSET $ap_offset
";
$resAp = $conn->query($sqlAp);
$appointments = [];
if ($resAp && $resAp->num_rows > 0) {
    while ($row = $resAp->fetch_assoc()) {
        $appointments[] = $row;
    }
}

// ---------------------------------------------------------
// (B) FOLLOW-UPS TAB: Filters + Pagination + Query
// ---------------------------------------------------------
$fu_start     = $_GET['fu_start']   ?? '';  // Start date
$fu_end       = $_GET['fu_end']     ?? '';  // End date
$fu_status    = $_GET['fu_status']  ?? '';  // "Pending","Done"
$fu_name      = $_GET['fu_name']    ?? '';  // Search patient name
$fu_pg        = isset($_GET['fu_pg']) ? max(1, (int)$_GET['fu_pg']) : 1;
$fu_per_page  = 10;
$fu_offset    = ($fu_pg - 1) * $fu_per_page;

$fuClauses = [];
$fuJoins   = "FROM follow_up f
             JOIN patients p ON f.PatientID = p.id";

// If you want to filter by f.FollowUpDate (and possibly f.NextFollowUpDate)
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_end)) {
    $fuClauses[] = "DATE(f.FollowUpDate) BETWEEN '$fu_start' AND '$fu_end'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_start)) {
    $fuClauses[] = "DATE(f.FollowUpDate) >= '$fu_start'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $fu_end)) {
    $fuClauses[] = "DATE(f.FollowUpDate) <= '$fu_end'";
}

if (in_array($fu_status, ['Pending', 'Done'], true)) {
    $fuClauses[] = "f.FollowUpStatus = '$fu_status'";
}

if (!empty($fu_name)) {
    $esc = $conn->real_escape_string($fu_name);
    $fuClauses[] = "(p.first_name LIKE '%$esc%' OR p.last_name LIKE '%$esc%')";
}

$fuWhere = '';
if (!empty($fuClauses)) {
    $fuWhere = 'WHERE ' . implode(' AND ', $fuClauses);
}

// Count how many
$sqlCountFu = "SELECT COUNT(*) as total $fuJoins $fuWhere";
$resCountFu = $conn->query($sqlCountFu);
$fuTotal    = 0;
if ($resCountFu) {
    $cRow = $resCountFu->fetch_assoc();
    $fuTotal = (int)$cRow['total'];
}
$fuTotalPages = max(1, ceil($fuTotal / $fu_per_page));

// Actual data
$sqlFu = "
  SELECT 
    f.FollowUpID,
    f.PatientID,
    f.FollowUpDate,
    f.NextFollowUpDate,
    f.FollowUpType,
    f.StatusUpdate,
    f.FollowUpStatus,
    p.first_name,
    p.last_name
  $fuJoins
  $fuWhere
  ORDER BY f.FollowUpDate DESC, f.FollowUpID DESC
  LIMIT $fu_per_page OFFSET $fu_offset
";
$resFu = $conn->query($sqlFu);
$followups = [];
if ($resFu && $resFu->num_rows > 0) {
    while ($row = $resFu->fetch_assoc()) {
        $followups[] = $row;
    }
}

// ---------------------------------------------------------
// (C) DIAGNOSIS TAB: Filters + Pagination + Query
// ---------------------------------------------------------
// We'll filter by d.FollowUpDate or d.DiagnosisDate. 
// The user specifically mentioned "diagnosis follow ups" revolve around d.FollowUpDate. 
// Adjust if you want to filter by DiagnosisDate instead.

$diag_start     = $_GET['diag_start']   ?? '';
$diag_end       = $_GET['diag_end']     ?? '';
$diag_name      = $_GET['diag_name']    ?? '';
$diag_pg        = isset($_GET['diag_pg']) ? max(1, (int)$_GET['diag_pg']) : 1;
$diag_per_page  = 10;
$diag_offset    = ($diag_pg - 1) * $diag_per_page;

$diagClauses = [];
$diagJoins   = "FROM diagnoses d
               JOIN patients p ON d.PatientID = p.id";

// We'll assume "d.FollowUpDate" is used for filtering
if (preg_match('/^\d{4}-\d{2}-\d{2}$/', $diag_start) && preg_match('/^\d{4}-\d{2}-\d{2}$/', $diag_end)) {
    $diagClauses[] = "d.FollowUpDate BETWEEN '$diag_start' AND '$diag_end'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $diag_start)) {
    $diagClauses[] = "d.FollowUpDate >= '$diag_start'";
} elseif (preg_match('/^\d{4}-\d{2}-\d{2}$/', $diag_end)) {
    $diagClauses[] = "d.FollowUpDate <= '$diag_end'";
}

// If you want a status filter, you'd need an extra column in diagnoses. 
// For now, we'll omit "status" for diagnoses unless you want to store it.

if (!empty($diag_name)) {
    $esc = $conn->real_escape_string($diag_name);
    $diagClauses[] = "(p.first_name LIKE '%$esc%' OR p.last_name LIKE '%$esc%')";
}

$diagWhere = '';
if (!empty($diagClauses)) {
    $diagWhere = 'WHERE ' . implode(' AND ', $diagClauses);
}

// Count
$sqlCountDiag = "SELECT COUNT(*) AS total $diagJoins $diagWhere";
$resCountDiag = $conn->query($sqlCountDiag);
$diagTotal    = 0;
if ($resCountDiag) {
    $dCountRow = $resCountDiag->fetch_assoc();
    $diagTotal = (int)$dCountRow['total'];
}
$diagTotalPages = max(1, ceil($diagTotal / $diag_per_page));

// Data
$sqlDiag = "
  SELECT
    d.DiagnosisID,
    d.PatientID,
    d.FollowUpDate,
    d.Diagnosis,
    p.first_name,
    p.last_name
  $diagJoins
  $diagWhere
  ORDER BY d.FollowUpDate DESC, d.DiagnosisID DESC
  LIMIT $diag_per_page OFFSET $diag_offset
";
$resDiag = $conn->query($sqlDiag);
$diagnoses = [];
if ($resDiag && $resDiag->num_rows > 0) {
    while ($row = $resDiag->fetch_assoc()) {
        $diagnoses[] = $row;
    }
}

// ---------------------------------------------------------
// (D) OUTPUT HTML
// ---------------------------------------------------------
?>
<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <title>All Items (Appointments, Follow-Ups, Diagnoses)</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <link href="<?php echo $baseURL; ?>assets/css/styles.css" rel="stylesheet">
</head>

<body>
    <div id="wrapper">
        <?php include ROOT_PATH . 'includes/navbar.php'; ?>
        <div id="page-content-wrapper">
            <?php include ROOT_PATH . 'includes/sidebar.php'; ?>

            <div class="container-fluid mt-4">
                <!-- Flash messages -->
                <?php if (!empty($errorMsg)): ?>
                    <div class="alert alert-danger">
                        <i class="fas fa-exclamation-triangle me-1"></i>
                        <?php echo htmlspecialchars($errorMsg); ?>
                    </div>
                <?php endif; ?>
                <?php if (!empty($successMsg)): ?>
                    <div class="alert alert-success">
                        <i class="fas fa-check-circle me-1"></i>
                        <?php echo htmlspecialchars($successMsg); ?>
                    </div>
                <?php endif; ?>

                <!-- Card Header -->
                <div class="card mb-3">
                    <div class="card-body bg-primary text-white text-center rounded">
                        <h4 class="card-title mb-1">All Items</h4>
                        <p class="mb-0">View Upcoming Appointments, Follow-Ups, and Diagnoses</p>
                    </div>
                </div>

                <!-- Nav Tabs -->
                <ul class="nav nav-tabs" id="allItemsTabs" role="tablist">
                    <li class="nav-item">
                        <button class="nav-link <?php echo ($activeTab === 'appointments') ? 'active' : ''; ?>"
                            id="appointments-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#appointmentsTab"
                            type="button"
                            role="tab"
                            aria-controls="appointmentsTab"
                            aria-selected="<?php echo ($activeTab === 'appointments') ? 'true' : 'false'; ?>">
                            Appointments
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php echo ($activeTab === 'followups') ? 'active' : ''; ?>"
                            id="followups-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#followupsTab"
                            type="button"
                            role="tab"
                            aria-controls="followupsTab"
                            aria-selected="<?php echo ($activeTab === 'followups') ? 'true' : 'false'; ?>">
                            Follow-Ups
                        </button>
                    </li>
                    <li class="nav-item">
                        <button class="nav-link <?php echo ($activeTab === 'diagnosis') ? 'active' : ''; ?>"
                            id="diagnosis-tab"
                            data-bs-toggle="tab"
                            data-bs-target="#diagnosisTab"
                            type="button"
                            role="tab"
                            aria-controls="diagnosisTab"
                            aria-selected="<?php echo ($activeTab === 'diagnosis') ? 'true' : 'false'; ?>">
                            Diagnosis
                        </button>
                    </li>
                </ul>

                <div class="tab-content border border-top-0 p-3" id="myTabContent">
                    <!-- TAB 1: APPOINTMENTS -->
                    <div class="tab-pane fade <?php echo ($activeTab === 'appointments') ? 'show active' : ''; ?>"
                        id="appointmentsTab"
                        role="tabpanel"
                        aria-labelledby="appointments-tab">
                        <!-- Filter Form -->
                        <form class="row g-3 mb-3" method="GET">
                            <input type="hidden" name="tab" value="appointments">
                            <div class="col-md-2">
                                <label class="form-label">Start Date</label>
                                <input type="date" class="form-control" name="ap_start"
                                    value="<?php echo htmlspecialchars($ap_start); ?>">
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">End Date</label>
                                <input type="date" class="form-control" name="ap_end"
                                    value="<?php echo htmlspecialchars($ap_end); ?>">
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">Status</label>
                                <select class="form-select" name="ap_status">
                                    <option value="">All</option>
                                    <option value="Scheduled" <?php if ($ap_status === 'Scheduled') echo 'selected'; ?>>Scheduled</option>
                                    <option value="Completed" <?php if ($ap_status === 'Completed') echo 'selected'; ?>>Completed</option>
                                    <option value="Cancelled" <?php if ($ap_status === 'Cancelled') echo 'selected'; ?>>Cancelled</option>
                                </select>
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">Patient Name</label>
                                <input type="text" class="form-control" name="ap_name"
                                    value="<?php echo htmlspecialchars($ap_name); ?>">
                            </div>
                            <div class="col-md-2 d-flex align-items-end">
                                <button class="btn btn-primary w-100">
                                    <i class="fas fa-filter"></i> Filter
                                </button>
                            </div>
                        </form>

                        <!-- Table -->
                        <div class="table-responsive">
                            <table class="table table-striped table-bordered text-center align-middle">
                                <thead class="table-light">
                                    <tr>
                                        <th>ID</th>
                                        <th>Patient</th>
                                        <th>Date</th>
                                        <th>Time</th>
                                        <th>Purpose</th>
                                        <th>Status</th>
                                        <th>View</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (!empty($appointments)): ?>
                                        <?php foreach ($appointments as $ap): ?>
                                            <tr>
                                                <td><?php echo (int)$ap['AppointmentID']; ?></td>
                                                <td>
                                                    <?php
                                                    echo htmlspecialchars($ap['first_name'] . ' ' . $ap['last_name']);
                                                    echo "<br>(ID: {$ap['PatientID']})";
                                                    ?>
                                                </td>
                                                <td><?php echo htmlspecialchars($ap['AppointmentDate']); ?></td>
                                                <td><?php echo substr($ap['AppointmentTime'] ?? '00:00:00', 0, 5); ?></td>
                                                <td><?php echo htmlspecialchars($ap['Purpose'] ?? '-'); ?></td>
                                                <td>
                                                    <?php
                                                    if ($ap['Status'] === 'Completed') {
                                                        echo '<span class="badge bg-success">Completed</span>';
                                                    } elseif ($ap['Status'] === 'Cancelled') {
                                                        echo '<span class="badge bg-danger">Cancelled</span>';
                                                    } else {
                                                        echo '<span class="badge bg-warning text-dark">Scheduled</span>';
                                                    }
                                                    ?>
                                                </td>
                                                <td>
                                                    <a href="<?php echo $baseURL; ?>pages/patient/patientProfile.php?id=<?php echo (int)$ap['PatientID']; ?>&appointments-tab=1&appt_id=<?php echo (int)$ap['AppointmentID']; ?>"
                                                        class="btn btn-sm btn-info"
                                                        target="_blank">
                                                        <i class="fas fa-eye"></i> View
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr>
                                            <td colspan="7">No appointments found.</td>
                                        </tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Pagination -->
                        <?php if ($apTotalPages > 1): ?>
                            <nav>
                                <ul class="pagination justify-content-center flex-wrap">
                                    <!-- Prev -->
                                    <?php if ($ap_pg > 1): ?>
                                        <li class="page-item">
                                            <a class="page-link" href="?tab=appointments&ap_pg=<?php echo $ap_pg - 1; ?>&ap_start=<?php echo urlencode($ap_start); ?>&ap_end=<?php echo urlencode($ap_end); ?>&ap_status=<?php echo urlencode($ap_status); ?>&ap_name=<?php echo urlencode($ap_name); ?>">
                                                &laquo; Prev
                                            </a>
                                        </li>
                                    <?php else: ?>
                                        <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                                    <?php endif; ?>

                                    <?php for ($p = 1; $p <= $apTotalPages; $p++): ?>
                                        <li class="page-item <?php if ($p == $ap_pg) echo 'active'; ?>">
                                            <a class="page-link"
                                                href="?tab=appointments&ap_pg=<?php echo $p; ?>&ap_start=<?php echo urlencode($ap_start); ?>&ap_end=<?php echo urlencode($ap_end); ?>&ap_status=<?php echo urlencode($ap_status); ?>&ap_name=<?php echo urlencode($ap_name); ?>">
                                                <?php echo $p; ?>
                                            </a>
                                        </li>
                                    <?php endfor; ?>

                                    <!-- Next -->
                                    <?php if ($ap_pg < $apTotalPages): ?>
                                        <li class="page-item">
                                            <a class="page-link" href="?tab=appointments&ap_pg=<?php echo $ap_pg + 1; ?>&ap_start=<?php echo urlencode($ap_start); ?>&ap_end=<?php echo urlencode($ap_end); ?>&ap_status=<?php echo urlencode($ap_status); ?>&ap_name=<?php echo urlencode($ap_name); ?>">
                                                Next &raquo;
                                            </a>
                                        </li>
                                    <?php else: ?>
                                        <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                                    <?php endif; ?>
                                </ul>
                            </nav>
                        <?php endif; ?>
                    </div>

                    <!-- TAB 2: FOLLOW-UPS -->
                    <div class="tab-pane fade <?php echo ($activeTab === 'followups') ? 'show active' : ''; ?>"
                        id="followupsTab"
                        role="tabpanel"
                        aria-labelledby="followups-tab">

                        <!-- Filter Form -->
                        <form class="row g-3 mb-3" method="GET">
                            <input type="hidden" name="tab" value="followups">
                            <div class="col-md-2">
                                <label class="form-label">Start Date</label>
                                <input type="date" class="form-control" name="fu_start"
                                    value="<?php echo htmlspecialchars($fu_start); ?>">
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">End Date</label>
                                <input type="date" class="form-control" name="fu_end"
                                    value="<?php echo htmlspecialchars($fu_end); ?>">
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">Status</label>
                                <select class="form-select" name="fu_status">
                                    <option value="">All</option>
                                    <option value="Pending" <?php if ($fu_status === 'Pending') echo 'selected'; ?>>Pending</option>
                                    <option value="Done" <?php if ($fu_status === 'Done') echo 'selected'; ?>>Done</option>
                                </select>
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">Patient Name</label>
                                <input type="text" class="form-control" name="fu_name"
                                    value="<?php echo htmlspecialchars($fu_name); ?>">
                            </div>
                            <div class="col-md-2 d-flex align-items-end">
                                <button class="btn btn-primary w-100">
                                    <i class="fas fa-filter"></i> Filter
                                </button>
                            </div>
                        </form>

                        <!-- Table -->
                        <div class="table-responsive">
                            <table class="table table-striped table-bordered text-center align-middle">
                                <thead class="table-light">
                                    <tr>
                                        <th>ID</th>
                                        <th>Patient</th>
                                        <th>Follow-Up Date</th>
                                        <th>Next Follow-Up</th>
                                        <th>Type</th>
                                        <th>Status Update</th>
                                        <th>Status</th>
                                        <th>View</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (!empty($followups)): ?>
                                        <?php foreach ($followups as $fu): ?>
                                            <tr>
                                                <td><?php echo (int)$fu['FollowUpID']; ?></td>
                                                <td>
                                                    <?php
                                                    echo htmlspecialchars($fu['first_name'] . ' ' . $fu['last_name']);
                                                    echo "<br>(ID: {$fu['PatientID']})";
                                                    ?>
                                                </td>
                                                <td><?php echo htmlspecialchars($fu['FollowUpDate'] ?? ''); ?></td>
                                                <td><?php echo $fu['NextFollowUpDate'] ?? '-'; ?></td>
                                                <td><?php echo htmlspecialchars($fu['FollowUpType'] ?? ''); ?></td>
                                                <td style="white-space: pre-wrap;">
                                                    <?php echo nl2br(htmlspecialchars($fu['StatusUpdate'] ?? '')); ?>
                                                </td>
                                                <td>
                                                    <?php
                                                    if ($fu['FollowUpStatus'] === 'Done') {
                                                        echo '<span class="badge bg-success">Done</span>';
                                                    } else {
                                                        echo '<span class="badge bg-warning text-dark">Pending</span>';
                                                    }
                                                    ?>
                                                </td>
                                                <td>
                                                    <a href="<?php echo $baseURL; ?>pages/patient/patientProfile.php?id=<?php echo (int)$fu['PatientID']; ?>&followups-tab=1"
                                                        class="btn btn-sm btn-info"
                                                        target="_blank">
                                                        <i class="fas fa-eye"></i> View
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr>
                                            <td colspan="8">No follow-ups found.</td>
                                        </tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Pagination -->
                        <?php if ($fuTotalPages > 1): ?>
                            <nav>
                                <ul class="pagination justify-content-center flex-wrap">
                                    <!-- Prev -->
                                    <?php if ($fu_pg > 1): ?>
                                        <li class="page-item">
                                            <a class="page-link" href="?tab=followups&fu_pg=<?php echo $fu_pg - 1; ?>&fu_start=<?php echo urlencode($fu_start); ?>&fu_end=<?php echo urlencode($fu_end); ?>&fu_status=<?php echo urlencode($fu_status); ?>&fu_name=<?php echo urlencode($fu_name); ?>">
                                                &laquo; Prev
                                            </a>
                                        </li>
                                    <?php else: ?>
                                        <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                                    <?php endif; ?>

                                    <?php for ($p = 1; $p <= $fuTotalPages; $p++): ?>
                                        <li class="page-item <?php if ($p == $fu_pg) echo 'active'; ?>">
                                            <a class="page-link"
                                                href="?tab=followups&fu_pg=<?php echo $p; ?>&fu_start=<?php echo urlencode($fu_start); ?>&fu_end=<?php echo urlencode($fu_end); ?>&fu_status=<?php echo urlencode($fu_status); ?>&fu_name=<?php echo urlencode($fu_name); ?>">
                                                <?php echo $p; ?>
                                            </a>
                                        </li>
                                    <?php endfor; ?>

                                    <!-- Next -->
                                    <?php if ($fu_pg < $fuTotalPages): ?>
                                        <li class="page-item">
                                            <a class="page-link" href="?tab=followups&fu_pg=<?php echo $fu_pg + 1; ?>&fu_start=<?php echo urlencode($fu_start); ?>&fu_end=<?php echo urlencode($fu_end); ?>&fu_status=<?php echo urlencode($fu_status); ?>&fu_name=<?php echo urlencode($fu_name); ?>">
                                                Next &raquo;
                                            </a>
                                        </li>
                                    <?php else: ?>
                                        <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                                    <?php endif; ?>
                                </ul>
                            </nav>
                        <?php endif; ?>
                    </div>

                    <!-- TAB 3: DIAGNOSIS -->
                    <div class="tab-pane fade <?php echo ($activeTab === 'diagnosis') ? 'show active' : ''; ?>"
                        id="diagnosisTab"
                        role="tabpanel"
                        aria-labelledby="diagnosis-tab">

                        <!-- Filter Form -->
                        <form class="row g-3 mb-3" method="GET">
                            <input type="hidden" name="tab" value="diagnosis">
                            <div class="col-md-2">
                                <label class="form-label">Start Date</label>
                                <input type="date" class="form-control" name="diag_start"
                                    value="<?php echo htmlspecialchars($diag_start); ?>">
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">End Date</label>
                                <input type="date" class="form-control" name="diag_end"
                                    value="<?php echo htmlspecialchars($diag_end); ?>">
                            </div>
                            <div class="col-md-2">
                                <label class="form-label">Patient Name</label>
                                <input type="text" class="form-control" name="diag_name"
                                    value="<?php echo htmlspecialchars($diag_name); ?>">
                            </div>
                            <div class="col-md-2 d-flex align-items-end">
                                <button class="btn btn-primary w-100">
                                    <i class="fas fa-filter"></i> Filter
                                </button>
                            </div>
                        </form>

                        <!-- Table -->
                        <div class="table-responsive">
                            <table class="table table-striped table-bordered text-center align-middle">
                                <thead class="table-light">
                                    <tr>
                                        <th>ID</th>
                                        <th>Patient</th>
                                        <th>Follow-Up Date</th>
                                        <th>Diagnosis Snippet</th>
                                        <th>View</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    <?php if (!empty($diagnoses)): ?>
                                        <?php foreach ($diagnoses as $dg): ?>
                                            <?php
                                            $diagID = (int)$dg['DiagnosisID'];
                                            $snippet = mb_strimwidth($dg['Diagnosis'] ?? '', 0, 60, '...');
                                            ?>
                                            <tr>
                                                <td><?php echo $diagID; ?></td>
                                                <td>
                                                    <?php
                                                    echo htmlspecialchars($dg['first_name'] . ' ' . $dg['last_name']);
                                                    echo "<br>(ID: {$dg['PatientID']})";
                                                    ?>
                                                </td>
                                                <td><?php echo htmlspecialchars($dg['FollowUpDate'] ?? '-'); ?></td>
                                                <td style="white-space: pre-wrap;">
                                                    <?php echo htmlspecialchars($snippet); ?>
                                                </td>
                                                <td>
                                                    <!-- The user specifically said: 
                                                 "For diagnosis it just have to direct to that patient follow up." 
                                                 but typically you'd link to diagnoses tab. 
                                                 We'll do diagnoses tab by default, as in the dashboard code. 
                                            -->
                                                    <a href="<?php echo $baseURL; ?>pages/patient/patientProfile.php?id=<?php echo (int)$dg['PatientID']; ?>&diagnoses-tab=1&diag_id=<?php echo $diagID; ?>"
                                                        class="btn btn-sm btn-info"
                                                        target="_blank">
                                                        <i class="fas fa-eye"></i> View
                                                    </a>
                                                </td>
                                            </tr>
                                        <?php endforeach; ?>
                                    <?php else: ?>
                                        <tr>
                                            <td colspan="5">No diagnosis records found.</td>
                                        </tr>
                                    <?php endif; ?>
                                </tbody>
                            </table>
                        </div>

                        <!-- Pagination -->
                        <?php if ($diagTotalPages > 1): ?>
                            <nav>
                                <ul class="pagination justify-content-center flex-wrap">
                                    <!-- Prev -->
                                    <?php if ($diag_pg > 1): ?>
                                        <li class="page-item">
                                            <a class="page-link" href="?tab=diagnosis&diag_pg=<?php echo $diag_pg - 1; ?>&diag_start=<?php echo urlencode($diag_start); ?>&diag_end=<?php echo urlencode($diag_end); ?>&diag_name=<?php echo urlencode($diag_name); ?>">
                                                &laquo; Prev
                                            </a>
                                        </li>
                                    <?php else: ?>
                                        <li class="page-item disabled"><span class="page-link">&laquo; Prev</span></li>
                                    <?php endif; ?>

                                    <?php for ($p = 1; $p <= $diagTotalPages; $p++): ?>
                                        <li class="page-item <?php if ($p == $diag_pg) echo 'active'; ?>">
                                            <a class="page-link"
                                                href="?tab=diagnosis&diag_pg=<?php echo $p; ?>&diag_start=<?php echo urlencode($diag_start); ?>&diag_end=<?php echo urlencode($diag_end); ?>&diag_name=<?php echo urlencode($diag_name); ?>">
                                                <?php echo $p; ?>
                                            </a>
                                        </li>
                                    <?php endfor; ?>

                                    <!-- Next -->
                                    <?php if ($diag_pg < $diagTotalPages): ?>
                                        <li class="page-item">
                                            <a class="page-link" href="?tab=diagnosis&diag_pg=<?php echo $diag_pg + 1; ?>&diag_start=<?php echo urlencode($diag_start); ?>&diag_end=<?php echo urlencode($diag_end); ?>&diag_name=<?php echo urlencode($diag_name); ?>">
                                                Next &raquo;
                                            </a>
                                        </li>
                                    <?php else: ?>
                                        <li class="page-item disabled"><span class="page-link">Next &raquo;</span></li>
                                    <?php endif; ?>
                                </ul>
                            </nav>
                        <?php endif; ?>
                    </div><!-- end diagnosisTab -->

                </div><!-- end tab-content -->
            </div><!-- end container-fluid -->
        </div><!-- end page-content-wrapper -->
    </div><!-- end wrapper -->

    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
</body>

</html>